/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  The function contained here processes parameters passed to e6 when it
 *  is initiated from the command line.  These parameters are checked for
 *  correctness before their results are passed to the program.
 *
 *  Coded by:       Ross Maloney
 *  September 2012: Initial code 
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  <unistd.h>      /* for use with access() */
#include  <stdlib.h>      /* for exit() */
#include  <string.h>      /* for strlen() and strcpy() */
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* commpn data for e6 */

int  arguments(int argc,  char *argv[])
{
  int  i, j, request, state;
  void correction(void);     /* this file */

  request = 0;
  i = argc - 1;
  if ( i == 0 )  return(request);
  for (j=1; j<=i; j++)  {
    if ( *argv[j] != '-' )  {
      correction();
      exit(1);
    }
    if ( *argv[j] == '-' )
      switch ( *(argv[j]+1) )  {
      case 'v':
        printf("e6 version 2.3.0\n");
	break;
      case 'a':
	state = access(argv[j+1], F_OK);
	if ( state == -1 )  {
	   printf("file  %s  does not exist\n", argv[j+1]);
	   exit(1);
	}
	state = access(argv[j+1], W_OK);
	if ( state == -1 )  {
	   printf("you are not allowed to write on file  %s\n", argv[j+1]);
	   exit(1);
	}
	strcpy(dataStore[100].array, argv[j+1]);
	dataStore[100].end = strlen(argv[j+1]);
	request = request | 0x1;
	j++;
	break;
      case 'n':
	state = access(argv[j+1], F_OK);
	if ( state == 0 )  {
	   printf("file  %s  already exists\n", argv[j+1]);
	   exit(1);
	}
 	strcpy(dataStore[100].array, argv[j+1]);
	dataStore[100].end = strlen(argv[j+1]);
	request = request | 0x2;
	j++;
	break;
      case 'r':
	state = access(argv[j+1], R_OK);
	if ( state == -1 )  {
	  printf("you are not allowed to read file  %s\n", argv[j+1]);
	  exit(1);
	}
	strcpy(dataStore[105].array, argv[j+1]);
	dataStore[105].end = strlen(argv[j+1]);
	request = request | 0x4;
	j++;
	break;
      case 'h':
      default:
	correction();
      }
  }
  if ( request ) return(request);
  else  exit(1);
}


/*  Function to print the correct call parameters for invoking  e6 */

void  correction()
{
  printf("usage:  e6 [-n \"string\"] [-a \"string\"] [-r \"string\"] [-v] [-h] &\n");
  printf("    -a  \"string\" contains name of file to append references\n");
  printf("    -n  \"string\" contains name of new file to create\n");
  printf("    -r  \"string\" contains name of file for extracting references\n");
  printf("    -v  print version of program\n");
  printf("    -h  print this message\n");
}

