/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains the function to handle a 'commentary' citation type.
 *
 *  Coded by:       Ross Maloney
 *  June 2018:      Initial code 
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  commentary()
{
  extern void showkeysO(void);        /* in utilities.c */
  extern void shownote(void);         /* in utilities.c */
  extern void removeMenus(int);       /* in mouseevent.c */
  extern void error(char *);          /* in error.c */
  extern void zeroall(void);          /* in texting.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 775);
  removeMenus(1);   /* remove the menu train which led to this function */
  who = 86;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);
  XMapWindow(e6display, moduleStore[55].id);  /* commentary Required */

  XReparentWindow(e6display, dataStore[2].id,
         moduleStore[55].id, 60, 47);    /* author */
  XMapWindow(e6display, dataStore[2].id);
  dataStore[2].before = 65;
  dataStore[2].next = 1;
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[55].id, 50, 78);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 2;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[55].id, 725, 78);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 62;
  XReparentWindow(e6display, dataStore[62].id,
         moduleStore[55].id, 60, 110); /* edition */
  XMapWindow(e6display, dataStore[62].id);
  dataStore[62].before = 0;
  dataStore[62].next = 53;
  XReparentWindow(e6display, dataStore[53].id,
         moduleStore[55].id, 380, 110); /* page total */
  XMapWindow(e6display, dataStore[53].id);
  dataStore[53].before = 62;
  dataStore[53].next = 19;
  XReparentWindow(e6display, dataStore[19].id,
         moduleStore[55].id, 62, 142);   /* volume */
  XMapWindow(e6display, dataStore[19].id);
  dataStore[19].before = 53;
  dataStore[19].next = 18;
  XReparentWindow(e6display, dataStore[18].id,
         moduleStore[55].id, 262, 142);   /* number */
  XMapWindow(e6display, dataStore[18].id);
  dataStore[18].before = 19;
  dataStore[18].next = 21;
  XReparentWindow(e6display, dataStore[21].id,
         moduleStore[55].id, 452, 142);   /* pages */
  XMapWindow(e6display, dataStore[21].id);
  dataStore[21].before = 18;
  dataStore[21].next = 56;
  XReparentWindow(e6display, dataStore[56].id,
         moduleStore[55].id, 73, 175);   /* publisher */
  XMapWindow(e6display, dataStore[56].id);
  dataStore[56].before = 21;
  dataStore[56].next = 73;
  XReparentWindow(e6display, dataStore[73].id,
         moduleStore[55].id, 725, 175); /* chapter */
  XMapWindow(e6display, dataStore[73].id);
  dataStore[73].before = 56;
  dataStore[73].next = 22;
  XReparentWindow(e6display, dataStore[22].id,
         moduleStore[55].id, 60, 211);  /* series */
  XMapWindow(e6display, dataStore[22].id);
  dataStore[22].before = 73;
  dataStore[22].next = 96;
  XReparentWindow(e6display, dataStore[96].id,
         moduleStore[55].id, 641, 211);  /* short series */
  XMapWindow(e6display, dataStore[96].id);
  dataStore[96].before = 22;
  dataStore[96].next = 20;
  XReparentWindow(e6display, dataStore[20].id,
         moduleStore[55].id, 55, 246);  /* isbn */
  XMapWindow(e6display, dataStore[20].id);
  dataStore[20].before = 96;
  dataStore[20].next = 55;
  XReparentWindow(e6display, dataStore[55].id,
         moduleStore[55].id, 388, 246);  /* part */
  XMapWindow(e6display, dataStore[55].id);
  dataStore[55].before = 20;
  dataStore[55].next = 60;
  XReparentWindow(e6display, dataStore[60].id,
         moduleStore[55].id, 711, 246);  /* volumes */
  XMapWindow(e6display, dataStore[60].id);
  dataStore[60].before = 55;
  dataStore[60].next = 91;

                        /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 290);
  showkeysO();  /* keys Optional */
  dataStore[91].before = 60;
  dataStore[88].next = 65;
                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 415);
  shownote();

  zeroall();        /* set all input data fields to zero */
}



/*  Function to form the window to contain the minor data fields associated with
 *  a commentary reference type.
 */

void  commentary2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (Commentary)";
  char *icon_name = "e6/2";
  extern void showeditorabcO(void);   /* in utilities.c */
  extern void showlargeO(void);       /* in utilities.c */
  extern void showmainO(void);        /* in utilities.c */
  extern void showorigO(void);        /* in utilities.c */
  extern void showeprintO(void);      /* in utilities.c */
  extern void showlargeO1(void);      /* in utilities.c */
  extern void showissO(void);         /* in utilities.c */
  extern void wordsO(void);           /* in utilities.c */
  extern void showeventsO(void);      /* in utilities.c */
  extern void showwordsO(void);       /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 582);
  XMapWindow(e6display, secondsW);
 
                        /* linking in wordsO */
  XMoveWindow(e6display, moduleStore[9].id, 0, 5);
  dataStore[63].before = 26;
  dataStore[52].next = 42;
  showwordsO();      /* auxiliary information */
                        /* linking in mainO */
  XMoveWindow(e6display, moduleStore[5].id, 0, 95);
  dataStore[42].before = 52;
  dataStore[43].next = 10;
  showmainO();       /* pieces with 'main' in their name */
                        /* linking in editorabcO */
  XMoveWindow(e6display, moduleStore[2].id, 0, 154);
  dataStore[10].before = 43;
  dataStore[15].next = 48;
  showeditorabcO();  /* editor descriptors */
                        /* linking in origO */
  XMoveWindow(e6display, moduleStore[6].id, 0, 244);
  dataStore[48].before = 15;
  dataStore[49].next = 34;
  showorigO();       /* original publication details */
                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 334);
  showeprintO();     /* eprint information */
  XMoveWindow(e6display, moduleStore[7].id, 0, 364);
  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 396);
  showlargeO();      /* large Optionals */
  dataStore[34].before = 49;
  dataStore[26].next = 63;
}
