/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  Contained here is the function which controls the information detail
 *  required for the different citation searches available.
 *
 *  Coded by:       Ross Maloney
 *  January 2013:   Initial code 
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <X11/keysym.h>
#include  <X11/keysymdef.h>
#include  <stdio.h>
#include  <string.h>      /* for strlen() */
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */



                      /* Function to search the citation file and display the
		       * search results appropriate for each search type.  This
		       * function is called when the 'Enter" key on the keyboard
		       * is pressed after a citation search string is entered on
		       * a citation request screen.
		       */

void  searchShow()
{
  int  i, y;
  int extract(char *);         /* in findshow.c */
  void unpackage(void);        /* in findshow.c */
  int strend(char *, char *);  /* in findshow.c */

  rewind(ifp);    /* must start at the beginning of the file to be read */
  XUnmapWindow(e6display, windowStore[9]);
  XMapWindow(e6display, windowStore[9]);
  y = 15;

  switch ( searchType )  {
  case 1:  /* Author/editor citation search */
    XMapWindow(e6display, windowStore[11]);  /* Keyword */
    XMapWindow(e6display, windowStore[12]);  /* Date/Year */
    XResizeWindow(e6display, windowStore[13], 300, 512);
    XMoveWindow(e6display, windowStore[13], 210, 1); /* reposition Author/Editor*/
    XMapWindow(e6display, windowStore[13]);  /* Author/Editor */
    XMoveWindow(e6display, windowStore[14], 515, 1); /* reposition Title */
    XMapWindow(e6display, windowStore[14]);  /* Title */
    while ( extract( citblock ) ) {  /* get fields for all citations present */
      unpackage();
      if ( strend(target, author) != 0 )  {
        XDrawString(e6display, windowStore[11], GC1, 3, y, keywords,
           strlen(keywords));
        XDrawString(e6display, windowStore[12], GC1, 5, y, date, strlen(date));
        XDrawString(e6display, windowStore[13], GC1, 5, y, author,
           strlen(author));
        XDrawString(e6display, windowStore[14], GC1, 5, y, title, strlen(title));
        y = y + 15;
      }
    }
    break;
  case 2:  /* Type citation search */
    XMapWindow(e6display, windowStore[11]);  /* Keyword */
    XMapWindow(e6display, windowStore[12]);  /* Date/Year */
    XResizeWindow(e6display, windowStore[13], 300, 512);
    XMoveWindow(e6display, windowStore[13], 210, 1); /* reposition Author/Editor*/
    XMapWindow(e6display, windowStore[13]);  /* Author/Editor */
    XMoveWindow(e6display, windowStore[14], 515, 1); /* reposition Title */
    XMapWindow(e6display, windowStore[14]);  /* Title */
    while ( extract( citblock ) ) {  /* get fields for all citations present */
      unpackage();
      if ( strend(target, type2) != 0 )  {
        XDrawString(e6display, windowStore[11], GC1, 3, y, keywords,
           strlen(keywords));
        XDrawString(e6display, windowStore[12], GC1, 5, y, date, strlen(date));
        XDrawString(e6display, windowStore[13], GC1, 5, y, author,
           strlen(author));
        XDrawString(e6display, windowStore[14], GC1, 5, y, title, strlen(title));
        y = y + 15;
      }
    }
    break;
  case 3:  /* Date citation search */
    XMapWindow(e6display, windowStore[11]);  /* Keyword */
    XMapWindow(e6display, windowStore[15]);  /* Type */
    XResizeWindow(e6display, windowStore[13], 300, 512);
    XMoveWindow(e6display, windowStore[13], 260, 1); /* reposition Author/Editor*/
    XMapWindow(e6display, windowStore[13]);
    XMoveWindow(e6display, windowStore[14], 565, 1); /* reposition Title */
    XMapWindow(e6display, windowStore[14]);
    while ( extract( citblock ) ) {  /* get fields for all citations present */
      unpackage();
      if ( strend(target, date) != 0 )  {
        XDrawString(e6display, windowStore[11], GC1, 3, y, keywords,
           strlen(keywords));
        XDrawString(e6display, windowStore[15], GC1, 5, y, type2, strlen(type2));
        XDrawString(e6display, windowStore[13], GC1, 5, y, author,
           strlen(author));
        XDrawString(e6display, windowStore[14], GC1, 5, y, title, strlen(title));
        y = y + 15;
      }
    }
    break;
  case 4:  /* Word citation search */
    XMapWindow(e6display, windowStore[11]);  /* Keyword */
    XMapWindow(e6display, windowStore[12]);  /* Date/Year */
    XResizeWindow(e6display, windowStore[13], 300, 512);
    XMoveWindow(e6display, windowStore[13], 210, 1); /* reposition Author/Editor*/
    XMapWindow(e6display, windowStore[13]);  /* Author/Editor */
    XMoveWindow(e6display, windowStore[14], 515, 1); /* reposition Title */
    XMapWindow(e6display, windowStore[14]);  /* Title */
    while ( extract( citblock ) ) {  /* get fields for all citations present */
      if ( strend(target, citblock) != 0 )  {
        unpackage();
        XDrawString(e6display, windowStore[11], GC1, 3, y, keywords,
           strlen(keywords));
        XDrawString(e6display, windowStore[12], GC1, 5, y, date, strlen(date));
        XDrawString(e6display, windowStore[13], GC1, 5, y, author,
           strlen(author));
        XDrawString(e6display, windowStore[14], GC1, 5, y, title, strlen(title));
        y = y + 15;
      }
    }
    break;
    default:
      printf("searchShow: Should never get here\n");
  }
}
