/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains functions called from the pull-down menus and the action
 *  buttons on the various windows which appear.
 *
 *  Coded by:           Ross Maloney
 *  April 2012:      Initial code 
 *  September 2014:  Added handling of minor fields in showMinors()
 *  June 2018:       Improve execution of cleanWindows()
 *  June 2018:       Correct switch code in doRelease() and showMirrors()
 *  March 2022       Database type added
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

  /* All button presses are received here and dispatched for service */

void  doRelease(int signature)
{
  extern void  book(void);         /* book.c */
  extern void  storeReference();   /* in process,c */
  extern void  createnew(void);    /* in filing.c */
  extern void  getnew(void);       /* in filing.c */
  extern void  cancelnew();        /* in filing.c */
  extern void  append(void);       /* in filing.c */
  extern void  openread(void);     /* in filing.c */
  extern void  getread(void);      /* in filing.c */
  extern void  getappend(void);    /* in filing.c */
  extern void  closein(void);      /* in filing.c */
  extern void  closein(void);      /* in filing.c */
  extern void  closeoutput(void);  /* in filing.c */
  extern void  cancelread(void);   /* in filing.c */
  extern void  cancelappend(void); /* in filing.c */
  extern void  docancel(void);     /* this file */
  extern void  openread(void);     /* in filing.c */
  extern void  showAll(void);      /* in findshow.c */
  extern void  showAuthor(void);   /* in findshow.c */
  extern void  showType(void);     /* in findshow.c */
  extern void  showDate(void);     /* in findshow.c */
  extern void  showWord(void);     /* in findshow.c */
  extern void  clearfind(void);    /* in findshow.c */
  extern void  error(char *);      /* in error.c */
  extern void  article(void);      /* in article.c */
  extern void  book(void);         /* in book.c */
  extern void  booklet(void);      /* in booklet.c */
  extern void  online(void);       /* in online.c */
  extern void  mvbook(void);       /* in mvbook.c */
  extern void  inbook(void);       /* in inbook.c */
  extern void  bookinbook(void);   /* in bookinbook.c */
  extern void  suppbook(void);     /* in suppbook.c */
  extern void  incol(void);        /* in incol.c */
  extern void  suppcol(void);      /* in suppcol.c */
  extern void  inproced(void);     /* in inproced.c */
  extern void  inreference(void);  /* in inref.c */
  extern void  inref2(void);       /* in inref.c */
  extern void  manual(void);       /* in manual.c */
  extern void  miscellaneous(void);/* in miscellaneous.c */
  extern void  proceedings(void);  /* in proceedings.c */
  extern void  mvproced(void);     /* in mvproced.c */
  extern void  reference(void);    /* in reference.c */
  extern void  mvref(void);        /* in mvref.c */
  extern void  report(void);       /* in report.c */
  extern void  thesis(void);       /* in thesis.c */
  extern void  unpublished(void);  /* in unpublished.c */
  extern void  collection(void);   /* in collection.c */
  extern void  incol(void);        /* in incol.c */
  extern void  mvcol(void);        /* in mvcol.c */
  extern void  mvcol(void);        /* in mvcol.c */
  extern void  periodical(void);   /* in periodical.c */
  extern void  supperiod(void);    /* in suppperiod.c */
  extern void  patent(void);       /* in patent.c */
  extern void  showMinors(void);   /* this file */
  extern void  removeMinors(void); /* this file */
  extern void  artwork(void);      /* in artwork.c */
  extern void  audio(void);        /* in audio.c */
  //  void  commentary(void);   /* in commentary.c */
  extern void  jurisdiction(void); /* in jurisdiction.c */
  extern void  image(void);        /* in image.c */
  extern void  legislation(void);  /* in legislation.c */
  extern void  legal(void);        /* in legal.c */
  extern void  letter(void);       /* in letter.c */
  extern void  movie(void);        /* in movie.c */
  extern void  music(void);        /* in music.c */
  extern void  performance(void);  /* in performance.c */
  extern void  review(void);       /* in review.c */
  extern void  software(void);     /* in software.c */
  extern void  standard(void);     /* in standard.c */
  extern void  video(void);        /* in video.c */
  extern void  database(void);     /* in database.c */
  int  i, number;

  if ( signature == 3004 )  {    /* OK button pressed on error window */
    XUnmapWindow(e6display, windowStore[4]);
    error_flag = 0;
    return;
  }
  if ( error_flag )  {      /* the error window is still present */
    XBell(e6display, 50);
    return;
  }
  if ( signature > 49 && signature < 100 )  active = signature;
  switch (signature)  {
  case 10:                              /* create a new file */
    getnew();
    break;
  case 11:                              /* open file for reading ONLY */
    getread();
    break;
  case 12:                              /* open file for appending */
    getappend();
    break;
  case 14:                              /* close the reference input file */
    closein();
    break;
  case 15:                              /* close the open file storing data */
    closeoutput();
    break;
  case 16:                              /* quit */
    number = 0;
    for (i=0; i<100; i++)
      if ( dataStore[i].end )  number++;
    if ( number )  error("    Save or Cancel before quiting");
    else  done = 1;
    break;
  case 27:                              /* List all references in open file */
    showAll();
    break;
  case 28:                              /* List all given author references */
    showAuthor();
    break;
  case 29:                              /* List all given type references */
    showType();
    break;
  case 30:                              /* List reference by date file */
    showDate();
    break;
  case 31:                              /* List references by word occurrence */
    showWord();
    break;
  case 32:                              /* List reference by cross-ref word */
    printf("List references matching a given cross-reference word\n");
    break;
  case 33:                              /* List all references in open file */
    printf("List references matching given keyword\n");
    break;
  case 50:                              /* Article citation type */
    article();
    break;
  case 51:                              /* Book citation type */
    book();
    break;
  case 52:                              /* multi-volume Book citation type */
    mvbook();
    break;
  case 53:                              /* Book in Book citation type */
    bookinbook();
    break;
  case 54:                              /* Booklet citation type */
    booklet();
    break;
  case 55:                              /* Collection citation type */
    collection();
    break;
  case 56:                              /* multi-volume Collection citation type */
    mvcol();
    break;
  case 57:                              /* supplemental Collection citation type */
    suppcol();
    break;
  case 58:                              /* inBook citation type */
    inbook();
    break;
  case 59:                              /* in supplemental Book citation type */
    suppbook();
    break;
  case 60:                              /* in Collection citation type */
    incol();
    break;
  case 61:                              /* in Proceedings citation type */
    inproced();
    break;
  case 62:                              /* in Reference citation type */
    inreference();
    break;
  case 63:                              /* Manual citation type */
    manual();
    break;
  case 64:                              /* Miscellaneous citation type */
    miscellaneous();
    break;
  case 65:                              /* Online citation type */
    online();
    break;
  case 66:                              /* Patent citation type */
    patent();
    break;
  case 67:                              /* Periodical citation type */
    periodical();
    break;
  case 68:                              /* supplemental Periodical type */
    supperiod();
    break;
  case 69:                              /* Proceedings citation type */
    proceedings();
    break;
  case 70:                          /* multi-volume Proceedings citation type */
    mvproced();
    break;
  case 71:                              /* Reference citation type */
    reference();
    break;
  case 72:                              /* multi-volume Reference citation type */
    mvref();
    break;
  case 73:                              /* Report citation type */
    report();
    break;
  case 75:                              /* Thesis citation type */
    thesis();
    break;
  case 76:                              /* Unpublished citation type */
    unpublished();
    break;
  case 77:                              /* Conference citation type */
    inproced();
    break;
  case 78:                              /* Electronic citation type */
    online();
    break;
  case 79:                              /* Masters thesis citation type */
    thesis();
    break;
  case 80:                              /* PhD thesis citation type */
    thesis();
    break;
  case 81:                              /* Technical report citation type */
    report();
    break;
  case 82:                              /* World Wide Web citation type */
    online();
    break;
  case 83:                              /* artwork type */
    artwork();
    break;
  case 84:                              /* audio type */
    audio();
    break;
  case 86:                              /* jurisdiction type */
    jurisdiction();
    break;
  case 87:                              /* image type */
    image();
    break;
  case 88:                              /* legislation type */
    legislation();
    break;
  case 89:                              /* legal type */
    legal();
    break;
  case 90:                              /* letter */
    letter();
    break;
  case 91:                              /* movie */
    movie();
    break;
  case 92:                              /* music */
    music();
    break;
  case 93:                              /* performance */
    performance();
    break;
  case 94:                              /* review */
    review();
    break;
  case 95:                              /* software */
    software();
    break;
  case 96:                              /* standard */
    standard();
    break;
  case 97:                              /* video */
    video();
    break;
  case 98:                              /* video */
    database();
    break;
  case 3000:                              /* 'save' button clicked */
    storeReference();
    break;
  case 3001:                              /* 'Do It' button clicked */
    doit_flag = 1;
    break;
  case 3002:                              /* 'cancel' button clicked */
    docancel();
    break;
  case 3003:                              /* 'do' button clicked */
    if ( who == 1 )  createnew();         /* filename given, so open the file */
    if ( who == 2 )  append();            /* filename given, so append file */
    if ( who == 3 )  openread();          /* filename given, so open read file*/
    break;
//  case 3004:                              /* error 'ok' button clicked */
//    printf("ok button clicked\n");
//    XUnmapWindow(e6display, windowStore[4]);
//    error_flag = 0;
//    break;
  case 3005:                             /* 'cancel' with 'do' button clicked */
    if ( who == 1 )  cancelnew();        /* cancel opening new file */
    if ( who == 2 )  cancelappend();     /* cancel opening append file */
    if ( who == 3 )  cancelread();       /* cancel opening append file */
    break;
  case 3006:                             /* 'clear' find citation clicked */
    clearfind();
    break;
  case 3007:                              /* 'minors' button clicked */
    showMinors();
    break;
  case 3008:                              /* minor's 'Do It' button clicked */
    doit_flag = 1;
    break;
  case 3009:                              /* minor's 'cancel' button clicked */
    removeMinors();
    break;
  default:
    if ( signature > 999 )  activeIndex = signature;
  }
  return;
}


/*  This function is called when the cancel button is pressed when a
 *  reference window is open.  It determines which type of reference is
 *  open via the 'who' variable which is assessible by all fuctions in e6.
 */

void docancel()
{
  int   i, number;

  void  clearWindows(void);   /* this file */
  void  error(char *);        /* in error.c */

  number = 0;
  for (i=0; i<100; i++) 
    if ( dataStore[i].end )  number++;
  if ( number > 0 )
    if ( doit_flag == 1 )  {
      clearWindows();
    }
    else
      error(" Entries present, so need over-ride");
  else  {
    clearWindows();
  }
  return;
}


/* This function removes all the reference input fields from the display,
 * and resets to the initial display
 */

void  clearWindows()
{
  int  i;

  //  printf("clearWindow: signature = %d\n", signature);
  for (i=0; i<11; i++)  XUnmapWindow(e6display, moduleStore[i].id);
  for (i=20; i<37; i++)  XUnmapWindow(e6display, moduleStore[i].id);
  for (i=0; i<100; i++)  dataStore[i].end = 0;
  XUnmapWindow(e6display, windowStore[3]);
  XUnmapWindow(e6display, secondsW);  /* added in e6-2.0 */
  XResizeWindow(e6display, baseW, 335, 655);
        /* special cases online & unpubl. reference - restore standard links */
  if ( who == 22 )  dataStore[29].before = 33;
  if ( who == 32 )  dataStore[31].before = 35;
  //  for (i=20; i<50; i++)  XUnmapWindow(e6display, moduleStore[i].id); //additions
  i = 0;  /* some value to bring up an error */
  switch(active)  {
  case 50:    i = 21; break;  /* article */
  case 51:    i = 20; break;  /* book */
  case 65:    i = 22; break;  /* online */
  case 75:    i = 23; break;  /* thesis */
  case 73:    i = 24; break;  /* report */
  case 61:    i = 25; break;  /* in proceedings */
  case 60:    i = 26; break;  /* in collection */
  case 69:    i = 27; break;  /* proceedings */
  case 55:    i = 28; break;  /* collection */
  case 54:    i = 29; break;  /* booklet */
  case 63:    i = 30; break;  /* manual */
  case 64:    i = 31; break;  /* miscellaneous */
  case 76:    i = 32; break;  /* unpublished */
  case 67:    i = 33; break;  /* periodical */
  case 71:    i = 34; break;  /* reference */
  case 62:    i = 35; break;  /* in reference */
  case 53:    i = 47; break;  /* bookinbook */
  case 57:    i = 48; break;  /* supplemental collection */
  case 59:    i = 49; break;  /* supplemental book */
  case 68:    i = 50; break;  /* supplemental periodical */
  case 58:    i = 41; break;  /* in book */
  case 52:    i = 42; break;  /* multi-volume book */
  case 56:    i = 43; break;  /* multi-volume collection */
  case 70:    i = 44; break;  /* multi-volume proceedings */
  case 66:    i = 45; break;  /* patent */
  case 77:    i = 25; break;  /* conference */
  case 78:    i = 22; break;  /* electronic */
  case 79:    i = 23; break;  /* masters thesis */
  case 80:    i = 23; break;  /* PhD thesis */
  case 81:    i = 24; break;  /* technical report */
  case 82:    i = 22; break;  /* World Wide Wed */
  case 72:    i = 51; break;  /* multi-volume reference */
  case 83:    i = 52; break;  /* artwork */
  case 84:    i = 53; break;  /* audio */
  case 85:    i = 54; break;  /* bibnote */
  case 86:    i = 55; break;  /* jurisdiction */
  case 87:    i = 56; break;  /* image */
  case 88:    i = 57; break;  /* legislation */
  case 89:    i = 58; break;  /* legal */
  case 90:    i = 59; break;  /* letter */
  case 91:    i = 60; break;  /* movie */
  case 92:    i = 61; break;  /* music */
  case 93:    i = 62; break;  /* performance */
  case 94:    i = 63; break;  /* review */
  case 95:    i = 64; break;  /* software */
  case 96:    i = 65; break;  /* standard */
  case 97:    i = 66; break;  /* video */
  case 98:    i = 66; break;  /* database */
    //  case 50:    i = ; break;
    //  case 50:    i = ; break;
  default:
    printf("should never get here\n");
  }
  XUnmapWindow(e6display, moduleStore[i].id);
  active = 0;
}


/* Function to display the screen containing the minor fields of the currently
 * selected reference type input.  The currently open reference type is
 * determined via the 'who' variable which is available to all e6 functions.
 */

void  showMinors()
{
  extern void  article2(void);           /* in article.c */
  extern void  book2(void);              /* in book.c */
  extern void  mvbook2(void);            /* in mvbook.c */
  extern void  inbook2(void);            /* in inbook.c */
  extern void  bookinbook2(void);        /* in bookinbook.c */
  extern void  suppbook2(void);          /* in suppbook.c */
  extern void  booklet2(void);           /* in booklet.c */
  extern void  collection2(void);        /* in collection.c */
  extern void  incol2(void);             /* in incol.c */
  extern void  suppcol2(void);           /* in suppcol2.c */
  extern void  mvcol2(void);             /* in mvcol.c */
  extern void  inproced2(void);          /* in inproced.c */
  extern void  mvref2(void);             /* in inref.c */
  extern void  inref2(void);             /* in inref.c */
  extern void  manual2(void);            /* in manual.c */
  extern void  miscellaneous2(void);     /* in miscellaneous.c */
  extern void  online2(void);            /* in online.c */
  extern void  patent2(void);            /* in patent.c */
  extern void  periodical2(void);        /* in periodical.c */
  extern void  supperiod2(void);         /* in suppperiod.c */
  extern void  proceedings2(void);       /* in proceedings.c */
  extern void  mvproced2(void);          /* in mvproced.c */
  extern void  reference2(void);         /* in reference.c */
  extern void  mvref2(void);             /* in mvref.c */
  extern void  report2(void);            /* in report.c */
  extern void  thesis2(void);            /* in thesis.c */
  extern void  unpublished2(void);       /* in unpublished.c */
  extern void  artwork2(void);           /* in artwork.c */
  extern void  audio2(void);             /* in audio.c */
  //  void  commentary2(void);        /* in commentary.c */
  extern void  jurisdiction2(void);      /* in jurisdiction.c */
  extern void  image2(void);             /* in image.c */
  extern void  legislation2(void);       /* in legislation.c */
  extern void  legal2(void);             /* in legal.c */
  extern void  letter2(void);            /* in letter.c */
  extern void  movie2(void);             /* in movie.c */
  extern void  music2(void);             /* in music.c */
  extern void  performance2();           /* in performance.c */
  extern void  review2(void);            /* in review.c */
  extern void  software2(void);          /* in software.c */
  extern void  standard2(void);          /* in standard.c */
  extern void  video2(void);             /* in video.c */
  extern void  database2(void);          /* in database.c */

  switch ( who )  {
  case 50:                              /* Article citation type */
    article2();
    XMapWindow(e6display, secondsW);
    break;
  case 51:                              /* Book citation type */
    book2();
    XMapWindow(e6display, secondsW);
    break;
  case 52:                              /* multi-volume Book citation type */
    mvbook2();
    XMapWindow(e6display, secondsW);
    break;
  case 53:                              /* Book in Book citation type */
    bookinbook2();
    XMapWindow(e6display, secondsW);
    break;
  case 54:                              /* Booklet citation type */
    booklet2();
    XMapWindow(e6display, secondsW);
    break;
  case 55:                              /* Collection citation type */
    collection2();
    XMapWindow(e6display, secondsW);
    break;
  case 56:                              /* multi-volume Collection citation type */
    mvcol2();
    XMapWindow(e6display, secondsW);
    break;
  case 57:                              /* supplemental Collection citation type */
    suppcol2();
    XMapWindow(e6display, secondsW);
    break;
  case 58:                              /* inBook citation type */
    inbook2();
    XMapWindow(e6display, secondsW);
    break;
  case 59:                              /* in supplemental Book citation type */
    suppbook2();
    XMapWindow(e6display, secondsW);
    break;
  case 60:                              /* in Collection citation type */
    incol2();
    XMapWindow(e6display, secondsW);
    break;
  case 61:                              /* in Proceedings citation type */
    inproced2();
    XMapWindow(e6display, secondsW);
    break;
  case 62:                              /* in Reference citation type */
    inref2();
    XMapWindow(e6display, secondsW);
    break;
  case 63:                              /* Manual citation type */
    manual2();
    XMapWindow(e6display, secondsW);
    break;
  case 64:                              /* Miscellaneous citation type */
    miscellaneous2();
    XMapWindow(e6display, secondsW);
    break;
  case 65:                              /* Online citation type */
    online2();
    XMapWindow(e6display, secondsW);
    break;
  case 66:                              /* Patent citation type */
    patent2();
    XMapWindow(e6display, secondsW);
    break;
  case 67:                              /* Periodical citation type */
    periodical2();
    XMapWindow(e6display, secondsW);
    break;
  case 68:                              /* supplemental Periodical type */
    supperiod2();
    XMapWindow(e6display, secondsW);
    break;
  case 69:                              /* Proceedings citation type */
    proceedings2();
    XMapWindow(e6display, secondsW);
    break;
  case 70:                              /* multi-volume Proceedings citation type */
    mvproced2();
    XMapWindow(e6display, secondsW);
    break;
  case 71:                              /* Reference citation type */
    reference2();
    XMapWindow(e6display, secondsW);
    break;
  case 72:                              /* multi-volume Reference citation type */
    mvref2();
    break;
  case 73:                              /* Report citation type */
    report2();
    XMapWindow(e6display, secondsW);
    break;
  case 75:                              /* Thesis citation type */
    thesis2();
    XMapWindow(e6display, secondsW);
    break;
  case 76:                              /* Unpublished citation type */
    unpublished2();
    XMapWindow(e6display, secondsW);
    break;
  case 77:                              /* Conference citation type */
    inproced2();
    XMapWindow(e6display, secondsW);
    break;
  case 78:                              /* Electronic citation type */
    online2();
    XMapWindow(e6display, secondsW);
    break;
  case 79:                              /* Masters thesis citation type */
    thesis2();
    XMapWindow(e6display, secondsW);
    break;
  case 80:                              /* PhD thesis citation type */
    thesis2();
    XMapWindow(e6display, secondsW);
    break;
  case 81:                              /* Technical report citation type */
    report2();
    XMapWindow(e6display, secondsW);
    break;
  case 82:                              /* World Wide Web citation type */
    online2();
    XMapWindow(e6display, secondsW);
    break;
  case 83:                              /* artwork citation type */
    artwork2();
    XMapWindow(e6display, secondsW);
    break;
  case 84:                              /* audio citation type */
    audio2();
    XMapWindow(e6display,secondsW);
    break;
  case 86:                              /* jurisdiction citation type */
    jurisdiction2();
    XMapWindow(e6display, secondsW);
    break;
  case 87:                              /* image citation type */
    image2();
    XMapWindow(e6display, secondsW);
    break;
  case 88:                              /* legislation citation type */
    legislation2();
    XMapWindow(e6display, secondsW);
    break;
  case 89:                              /* legal citation type */
    legal2();
    XMapWindow(e6display, secondsW);
    break;
  case 90:                              /* letter citation type */
    letter2();
    XMapWindow(e6display, secondsW);
    break;
  case 91:                              /* movie citation type */
    movie2();
    XMapWindow(e6display, secondsW);
    break;
  case 92:                              /* music citation type */
    music2();
    XMapWindow(e6display, secondsW);
    break;
  case 93:                              /* performance citation type */
    performance2();
    XMapWindow(e6display, secondsW);
    break;
  case 94:                              /* review citation type */
    review2();
    XMapWindow(e6display, secondsW);
    break;
  case 95:                              /* software citation type */
    software2();
    XMapWindow(e6display, secondsW);
    break;
  case 96:                              /* standard citation type */
    standard2();
    XMapWindow(e6display, secondsW);
    break;
  case 97:                              /* video citation type */
    video2();
    XMapWindow(e6display, secondsW);
    break;
  case 98:                              /* database citation type */
    database2();
    XMapWindow(e6display, secondsW);
    break;
  default:
    printf("showMinors(): this should not be seen\n");
  }
}

/* Function to remove window containing the minor fields of the current
 * reference type being input.  The reference type is determined from the 'who'
 * variable which is available to all e6 functions.
 */

void  removeMinors()
{
  XUnmapWindow(e6display, secondsW);
}
