/*  This file is part of  e6  (EndNote Substitute In Xlib)
 *
 *  The variables defined here are used in multiple routines related to creating
 *  or manipulating a citation entry.
 *
 *  Coded by:       Ross Maloney
 *  April 2011:     Initial code:   
 *  April 2012:     rewriten:       
 *  October 2012:   resize dataStore arrays due to 'misc' font
 *  December 2012:  reshaping dataStore due to testing
 *  June 2018       note/annotation switch over
 */

    /* Strings which contain data parts used to form each citation */

/* Their size */
                                              // dataStore[] index
#define  AD   34       /* address[] */        //  
#define  AA   114      /* addendum[] */       // 24  +
#define  AW   49       /* afterword[] */      // 63  +
#define  AO   125      /* annotation[] */     // 65
#define  AN   52       /* annotator[] */      // 66  +
#define  AU   118      /* author[] */         //  2  +
#define  AT   34       /* authortype[] */     // 67    not used yet
#define  AE   112      /* aued[] */           //  3  +
#define  BB   114      /* bookauthor[] */     // 68
#define  BP   120      /* bookpagination[] */ // 69    not used yet
#define  BT   115      /* booktitle[] */      // 71  +
#define  BS   112      /* booksubtitle[] */   // 70  +
#define  BA   109      /* bookaddon[] */      // 72  +
#define  CH   23       /* chapter[] */        // 73  +
#define  CO   47       /* commentator[] */    // 74  +
#define  CR   46       /* crossref[] */       //
#define  DA   23       /* date[] */           // 0   +
#define  DO   27       /* doi[] */            // 31
#define  EN   29       /* edition[] */        // 62  +
#define  ER   61       /* editor[] */         // 16  +
#define  EQ   41       /* editora[] */        // 10  +
#define  EP   41       /* editorb[] */        // 11  +
#define  EO   41       /* editorc[] */        // 12  +
#define  ET   41       /* editortype[] */     // 17  +
#define  EU   41       /* editoratype[] */    // 13  +
#define  EV   41       /* editorbtype[] */    // 14  +
#define  EW   41       /* editorctype[] */    // 15  +
#define  EI   46       /* eid[] */            // 75  +
#define  EA   37       /* eprint[] */         // 34  +
#define  EC   21       /* eprintclass[] */    // 35  +
#define  EY   26       /* eprinttype[] */     // 36  +
#define  ED   23       /* eventdate[] */      // 76  +
#define  EX   115      /* eventtitle[] */     // 77  +
#define  FI   114      /* file[] */           // 78   not used yet
#define  FW   52       /* foreword[] */       // 64  +
#define  HO   118      /* holder[] */         // 79
#define  HP   34       /* howpublished[] */   // 80
#define  IS   85       /* institution[] */    //  4  +
#define  IX   57       /* indextitle[] */     // 81   not used yet
#define  IT   49       /* introduction[] */   // 82  +
#define  IA   23       /* isan[] */           // 83   not used yet
#define  IB   39       /* isbn[] */           // 20  +
#define  IM   23       /* ismn[] */           // 84   not used yet
#define  IN   46       /* issn[] */           // 87  +
#define  IR   49       /* isrn[] */           // 85  + 
#define  II   31       /* issue[] */          // 88  +
#define  IJ   48       /* issuetitle[] */     // 40  +
#define  IK   48       /* issuesubtitle[] */  // 89  +
#define  JR   113      /* journaltitle[] */   //  5  +
#define  JS   110      /* jsubtitle[] */      //  6  +
#define  KY   23       /* key[] */            //
#define  KW   62       /* keywords[] */       // 86  +
#define  LA   27       /* language[] */       // 25  +
#define  LI   37       /* library[]  */       // 32
#define  LO   32       /* location[] */       // 33
#define  MN   3        /* month[] */          //     +
#define  MA   38       /* maintitleadd[] */   // 43  +
#define  MT   116      /* maintitle[] */      // 42  +
#define  MS   48       /* mainsubtitle[] */   // 41  +
#define  MO   34       /* month[] */          // 44
#define  NA   114      /* nameaddon[] */      // 45
#define  NO   119       /* note[] */          // 26
#define  NU   16       /* number[] */         // 18  +
#define  OR   97       /* organization[] */   // 46  +
#define  OD   23       /* origdate[] */       // 47  +
#define  OL   70       /* origlanguage[] */   // 48  +
#define  OP   39       /* origlocation[] */   // 49  +
#define  OU   51       /* origpublisher[] */  // 50  +
#define  OT   113      /* origtitle[] */      // 51  +
#define  PG   62       /* pages[] */          // 21  +
#define  PN   57       /* pnumber[] */        //
#define  PT   17       /* pagetotal[] */      // 53  +
#define  PA   23       /* paginnation[] */    // 54   not used yet
#define  PR   33       /* part[] */           // 55  +
#define  PU   80       /* publisher[] */      // 56  +
#define  PS   27       /* pubstate[] */       // 23  +
#define  RT   114      /* reprinttitle[] */   // 57   not used yet
#define  SC   57       /* school[] */         //
#define  SE   66       /* series[] */         // 22  +  ?
#define  SK   38       /* sortkey[] */        // 87  +
#define  ST   103      /* subtitle[] */       // 30  +
#define  SA   46       /* shortauthor[] */    //     +
#define  SD   35       /* shorteditor[] */    //     +
#define  SH   49       /* shorthand[] */      //     +
#define  SI   46       /* shorthandintro[] */ //     +
#define  SJ   51       /* shortjournal[] */   //     +
#define  SS   35       /* shortseries[] */    //     +  ?
#define  SL   52       /* shorttitle[] */     //     +
#define  TI   86       /* title[] */          //  1  +
#define  TA   101      /* titleaddon[] */     // 29  +
#define  TR   52       /* translator[] */     // 52  +
#define  TY   20       /* type[] */           // 61  +
#define  TT   40       /* type2[] */          // 97  +
#define  TO   46       /* typeo[] */          //
#define  UR   81       /* url[] */            // 27  +
#define  UD   23       /* urldate[] */        // 28  +
#define  VE   80       /* venue[] */          // 58  +
#define  VO   16       /* volume[] */         // 19  +
#define  VS   25       /* volumes[] */        // 60  +
#define  VR   18       /* version[] */        // 59  +
#define  XR   86       /* xref[] */           // 88  +
//#define  YR   7        /* year[] */           //  NO LONGER NEEDED
//#define  YD   23       /* yeardate[] */       //  0  + NO LONGER NEEDED

#define  FN   41       /* filename[] */       // +
#define  RR   41       /* errortext[] */      // +
#define  FO   38       /* size of window showing file open */


/* The arrays themselves */

extern char addendum[AA];     /* miscellaneous additional information to be printed */
extern char address[AD];      /* location/address of publisher or institution */
extern char authortype[AT];   /* not used yet */
extern char afterword[AW];    /* authors of the afterword */
extern char annotation[AOAO]; /* annotations of the work */
extern char annotator[AN];    /* authors of annotations to the work */
extern char author[AU];       /* name/s of authors of work */
extern char aued[AE];         /* names/s of authors or editors of the work */
extern char bookauthor[BB];   /* names/s of authors of the book */
extern char booktitle[BT];    /* title of book which includes the citation */
extern char bookaddon[BA];    /* an annex to the book title */
extern char booksubtitle[BS]; /* subtitle related to book title */
extern char bookpagination[AT];   /* not used yet */
extern char chapter[CH];      /* chapter or section number */
extern char commentator[CO];  /* authors to a commentary on the work */
extern char crossref[CR];     /* key of another citation related to this one */
extern char date[DA];         /* date */
extern char doi[DO];          /* digital object identifier */
extern char edition[EN];      /* release number of a book */
extern char editor[ER];       /* name/s of editor/s */
extern char editora[ER];      /* name/s of editor/s A */
extern char editorb[EP];      /* name/s of editor/s B */
extern char editorc[EO];      /* name/s of editor/s C */
extern char editortype[ET];   /* function editor's performed */
extern char editoratype[EU];  /* function editor's A performed */
extern char editorbtype[EV];  /* function editor's B performed */
extern char editorctype[EW];  /* function editor's C performed */
extern char eid[EI];          /* electronic identifier */
extern char eprint[EP];       /* online identifier of the publication */
extern char eprintclass[EC];  /* additional information about online identifier */
extern char eprinttype[EY];   /* type of the online publication */
extern char eventtitle[EX];   /* title of the event */
extern char eventdate[ED];    /* date when the eevent occurred */
extern char file[FI];         /* not used yet */
extern char foreword[FW];     /* authors of the foreword */
extern char holder[HO];       /* name of patent holder */
extern char howpublished[HP]; /* anything unusual about method of publication */
extern char indextitle[IX];   /* not used yet */
extern char institution[IS];  /* sponsoring orgainsation */
extern char introduction[IT]; /* authors of the introduction */
extern char isbn[IB];         /* international book number */
extern char ismn[IM];         /* not used yet */
extern char isrn[IR];         /* international report number */
extern char isan[IA];         /* not used yet */
extern char issue[II];        /* issue of a journal */
extern char issuetitle[IJ];   /* title of the specific issue */
extern char issuesubtitle[IK];/* subtitle of the specific issue */
extern char issn[IN];         /* ISSN of journal publication */
extern char journaltitle[JR]; /* name of journal or magazine */
extern char jsubtitle[JS];    /* journal subtitle */
extern char key[KY];          /* for putting reference in place order */
extern char keywords[KW];     /* key words */
extern char language[LA];     /* language */
extern char library[LA];      /* library */
extern char location[LO];     /* location of publication */
extern char maintitle[MT];    /* main title of a book */
extern char mainsubtitle[MS]; /* main sub title of a book */
extern char maintitleadd[MA]; /* main title addon */
extern char month[MN];        /* month of publication */
extern char nameaddon[NA];    /* not used yet */
extern char note[NO];         /* free format note information */
extern char number[NU];       /* sequence number */
extern char origdate[OD];     /* original date */
extern char origlanguage[OL]; /* original language */
extern char origtitle[OT];    /* original title */
extern char origlocation[OP]; /* original location */
extern char origpublisher[OU];/* original publisher */
extern char organization[OR]; /* sponsoring organisation of a conference */
extern char pages[PG];        /* page number/s */
extern char paginnation[PA];  /* not used yet */
extern char part[PR];         /* number of a part of a volume */
extern char pnumber[PN];      /* patent number */
extern char publisher[PU];    /* publisher's name */
extern char pubstate[PS];     /* publication state of the work */
extern char reprinttitle[RT]; /* not used yet */
extern char school[SC];       /* academic institution where thesis was written */
extern char series[SE];       /* name of a series or set of books */
extern char shortauthor[SA];  /* abbreviated authors */
extern char shorteditor[SD];  /* abbreviated editors */
extern char shorthand[SH];    /* citation aliasing */
extern char shorthandintro[SI]; /* citation abbreviated introduction */
extern char shortjournal[SJ]; /* abbreviated name of journal */
extern char shortseries[SS];  /* abbreviated name of the series */
extern char shorttitle[SL];   /* title in abbreviated form */
extern char sortkey[SK];      /* keys for putting the reference in the bib. sort */
extern char subtitle[ST];     /* subtitle of the work */
extern char title[TI];        /* title of the work */
extern char titleaddon[TA];   /* an assex to the title */
extern char pagetotal[PT];    /* total number of pages */
extern char translator[TR];   /* translator of the language */
extern char type[TY];         /* report qualifier */
extern char type2[TT];        /* non-required type */
extern char typeo[TY];        /* optional type field */
extern char url[UR];          /* web address */
extern char urldate[UD];      /* date when web address was accessed */
extern char venue[VE];        /* place where it was held */
extern char version[VR];      /* version number */
extern char volume[VO];       /* collection number */
extern char volumes[VS];      /* number in collection */
extern char xref[XR];         /* cross referencing field */
//char year[YR];         /* year of publication/appearance */  NOT NEEDED
//char yeardate[YD];     /* year/date of publication/appearance */  NOT NEEDED
extern char single[AOAO];     /* storage for a single line of a multi line ref. */

extern char filename[FN+1];   /* name of file containing citation */
extern char readfile[FN+1];   /* name of file containing citation for reading*/
extern FILE *ofp, *ifp, *fopen(); /* output and input reference file descriptors */
extern char errortext[RR];    /* holder for the error message */
extern int  error_flag;       /* indicator that an error message is set */
extern int  doit_flag;        /* indicator that 'Do It' button was pressed */
extern int  request_flag;     /* indicator of a save or cancel request */

#define  SP  2000      /* size of scratchpad */
extern char scratchpad[SP];   /* scratchpad storage for copy/paste operations FUTURE */

struct refStructure  {
  int  size;      /* size of character array to hold the data */
  int  nextArray; /* position of next character to be put into the array */
  int  nextWindow;/* position of next character to be written on input window */
  char *array;    /* charcter array used for storage */
//  char array[];    /* the charcter array itself */
};

//struct refStructure  refFields[2];

#define  CITSIZE  10000   /* size of citation block */
extern char citblock[CITSIZE];   /* storage for 1 citation extracted */
extern char target[20];          /* to contain citation selector string */
extern int  searchType;          /* indicator of citation search type */
extern int  active;              /* citation type being worked upon */
