/*  This file is part of  e6  (EndNote Substitute In Xlib)
 *
 *  The variables defined here are used in multiple routines.
 *
 *  Coded by:       Ross Maloney
 *  January 2011:   Initial code
 *  January 2013:   Space for citation result windows added
 *  July 2014:      Separate window added to contain secondary data fields
 *  July 2020       Created from e6x11.h due to compiler hadling of externals
 */

extern Display               *e6display;
extern Visual                *visualDefault;
extern Window                baseW;
extern Window                secondsW;
//extern XSetWindowAttributes  baseat;
extern Pixmap                mould;    /* use to form background pixmap for a window */
extern Pixmap                insertMarker; /* insertion cursor */
extern GC                    GC1, GC2, GC3, GC4, GC5, GC6, GC7, GC8, GC9;
extern XFontStruct           *font1, *font2;
extern int                   screen_num, depthDefault, done, status;
extern int                   mouseActive;
extern int                   activeIndex;  /* index of citation input */

extern struct chain {
  Window  normal;          /* window to use to show not selected */
  Window  selected;        /* window to use to show selected */
  int     parent;          /* index of this window's parent */
  int     visible;         /* 0 if not visible, 1 if normal, 2 if selected */
  int     depth;           /* depth of menu this window is on */
} menuStore[];  /* stores all the windows which form menu labels */
//extern struct chain  menuStore[100];

extern struct button {
  Window  normal;          /* window to use to show not selected */
  Window  selected;        /* window to use to show selected */
} buttonStore[];  /* stores all the windows which form buttons */
//extern struct button buttonStore[10];

extern struct  views {
  Window  id;              /* handle of the window after it is created */
} moduleStore[]; /* stores all the windows for setting out each citation */
//extern struct views  moduleStore[100];

extern int  colours[10];

extern int  charinc;              /* spacing between characters in input window */
extern int  noFields;             /* total number of input fields in the current ref.*/
extern int  reqFields;            /* number of require input fields in current ref. */
extern int  who;                  /* holds which current service is being done */
extern int  line;                 /* input field current line number (Note uses it) */
extern int  lEnd;                 /* index in data array of left end of current line */
extern int  lineEnd;              /* index in line array of end of line */

#define  BASE_WINDOW  800  /* indicator for the base window (baseW) */
#define  SECONDS_WINDOW  900  /* indicator for the base window (baseW) */
#define  BAR_WIDTH  103    /* width of each menu-bar element */
#define  BAR_HEIGHT  23    /* height of each menu-bar element */
#define  BOTTOM_0     0    /* lowest index of menu level 0 windows */
#define  TOP_0        6    /* upper index of menu level 0 windows */
#define  BOTTOM_1    10    /* lowest index of menu level 1 windows */
#define  TOP_1       34    /* upper index of menu level 1 windows */
#define  BOTTOM_2    50    /* lowest index of menu level 2 windows */
#define  TOP_2       99    /* upper index of menu level 2 windows */
#define  SINGLE      20    /* height of a single-line text window */
#define  MULTIPLE   320    /* height of multiple-line text window */
#define  FIELDS     112    /* Number of reference data fields used */
#define  AOAO      2400    /* Anotation array = NO*20[lines] + 20[lines] */

struct  data {
  Window  id;              /* handle of the window after it is created */
  int   next;              /* index of next data element in cycle */
  int   before;            /* index of preceeding data element in clcle */
  char  *array;            /* pointer to array to contain the element's data */
  int   end;               /* position of last character in 'array' */
  int   size;              /* maximum number of charactes 'array' will hold */
  int   current;           /* position of insertion pointer */
//  int   line;              /* position of character on line */
//  int   lineNo;            /* line number */
};
extern struct data dataStore[FIELDS]; /* storage for data of reference data field */
extern struct data singleLine;    /* a single line of a multi line reference field */

extern Window  windowStore[20];   /* complete windows with bitmap lettering */

#define  XX  0       /* debug border width for module collection windows */
/*`#define  XX  1       /* debug border width for module collection windows */
