/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  Contained here are the functions which are called to perform file-based
 *  input/output required by e6.
 *
 *  Coded by:       Ross Maloney
 *  June 2012:      Initial code
 */


#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"


/* Function to get the filename of a new file to be opened for output. */

void  getnew()
{
  XSetWindowAttributes  dataat;
  unsigned long  valuemask;
  int  i;
  void  error(char *);   /* in error.c */

  dataat.event_mask =  ExposureMask;
  valuemask = CWEventMask;

  if ( who == 1 || who == 2 )  {
    error("   Close the current output file");
    return;
  }
  who = 1;

  XMapWindow(e6display, windowStore[0]);
  XReparentWindow(e6display, buttonStore[5].normal,
                  windowStore[0], 20, 110); /* position button */
  XReparentWindow(e6display, buttonStore[5].selected,
                  windowStore[0], 20, 110); /* position button */
  XMapWindow(e6display, buttonStore[5].normal);   /* show cancel button */
  XReparentWindow(e6display, buttonStore[3].normal,
                  windowStore[0], 200, 110); /* position button */
  XReparentWindow(e6display, buttonStore[3].selected,
                  windowStore[0], 200, 110); /* position button */
  XMapWindow(e6display, buttonStore[3].normal);   /* show do button */
  XReparentWindow(e6display, dataStore[100].id,
                  windowStore[0], 10, 50); /* position filename input window */
  XMapWindow(e6display, dataStore[100].id);  /* show the data window */
}



/* Function opens a window for the used to type in a filename of a file for
 * appending references.  Since the file is assumed to exist, a selection
 * of the file from those available in the directory is used.  This is not
 * implemented correctly here.
 */

void getappend()
{
  void  error(char *);   /* in error.c */

  if ( who == 1 || who == 2 )  {
    error("   Close the current output file");
    return;
  }
  who = 2;
  XMapWindow(e6display, windowStore[2]);
  XReparentWindow(e6display, buttonStore[5].normal,
                  windowStore[2], 20, 110); /* position button */
  XReparentWindow(e6display, buttonStore[5].selected,
                  windowStore[2], 20, 110); /* position button */
  XMapWindow(e6display, buttonStore[5].normal);   /* show cancel button */
  XReparentWindow(e6display, buttonStore[3].normal,
                  windowStore[2], 200, 110); /* position button */
  XReparentWindow(e6display, buttonStore[3].selected,
                  windowStore[2], 200, 110); /* position button */
  XMapWindow(e6display, buttonStore[3].normal);   /* show do button */
  XReparentWindow(e6display, dataStore[100].id,
                  windowStore[2], 10, 50); /* position filename input window */
  XMapWindow(e6display, dataStore[100].id);  /* show the data window */
}


/* Function to open a file for reading only.  The file requested must exist or
 * and error is generated.  Currently this file is not used - but will in the
 * future when manipulation, listing, etc. of references in a file is
 * implemented.
 */

void  getread()
{
  void  error(char *);   /* in error.c */

  who = 3;
  dataStore[105].end = 0;   /* inout filename not to be equal to input */
  XMapWindow(e6display, windowStore[7]);
  XReparentWindow(e6display, buttonStore[5].normal,
                  windowStore[7], 20, 110); /* position button */
  XReparentWindow(e6display, buttonStore[5].selected,
                  windowStore[7], 20, 110); /* position button */
  XMapWindow(e6display, buttonStore[5].normal);   /* show cancel button */
  XReparentWindow(e6display, buttonStore[3].normal,
                  windowStore[7], 200, 110); /* position button */
  XReparentWindow(e6display, buttonStore[3].selected,
                  windowStore[7], 200, 110); /* position button */
  XMapWindow(e6display, buttonStore[3].normal);   /* show do button */
  XReparentWindow(e6display, dataStore[105].id,
                  windowStore[7], 10, 50); /* position filename input window */
  XMapWindow(e6display, dataStore[105].id);  /* show the data window */
}


/* Function to open a new file with the filename that has just been typed in */

void  createnew()
{
  int  i;
  void  error(char *);   /* in error.c */

  if ( ofp != 0 )  {
    error("   An output file is already open");
    return;
  }
  i = dataStore[100].end;
  dataStore[100].array[i] = '\0';  /* terminate filename string */
             /* first check if the requested file exists */
  ofp = fopen(dataStore[100].array, "r");
  if ( ofp )  {
    error("   Requested file already exists");
    ofp = NULL;
    return;
  }
             /* if it does not exist, try creating it */
  else  {
    ofp = fopen(dataStore[100].array, "a");
    if ( ofp == NULL )  {
      error("   Could not create requested file");
      return;
    }
    else  {
         /* this piece is similar to append() */
      XUnmapWindow(e6display, windowStore[0]);
      for (i=0; i<dataStore[100].end; i++)  /* to simplify exposure recovery */
        dataStore[101].array[i] = dataStore[100].array[i];
      dataStore[101].end = dataStore[100].end;
      XMapWindow(e6display, windowStore[5]);    /* show open file's name */
      XReparentWindow(e6display, dataStore[101].id, windowStore[5], 0, 35);
      XMapWindow(e6display, dataStore[101].id);
      XDrawString(e6display, dataStore[101].id, GC1, 0, 15,
                    dataStore[100].array, dataStore[100].end);
    }
  }
}



/* Function to open an existing file to receive more reference data */

void  append()
{
  int  i;
  void  error(char *);   /* in error.c */

  if ( ofp != 0 )  {
    error("   An output file is already open");
    return;
  }
  i = dataStore[100].end;
  dataStore[100].array[i] = '\0';  /* terminate filename string */
  ofp = fopen(dataStore[100].array, "a");
  if ( ofp == NULL )  {
    error("  Could not create requested file");
    return;
  }
  else  {
    XUnmapWindow(e6display, windowStore[2]);
    for (i=0; i<dataStore[100].end; i++)  /* to simplify exposure recovery */
      dataStore[101].array[i] = dataStore[100].array[i];
    dataStore[101].end = dataStore[100].end;
    XMapWindow(e6display, windowStore[1]);    /* show open file's name */
    XReparentWindow(e6display, dataStore[101].id, windowStore[1], 2, 35);
    XMapWindow(e6display, dataStore[101].id);
    XDrawString(e6display, dataStore[101].id, GC1, 0, 15,
                  dataStore[100].array, dataStore[100].end);
  }
}

/* Function to open an existing file for accessing the references it contains */

void  openread()
{
  int  i;
  void  error(char *);   /* in error.c */

  if ( ifp != 0 )  {
    error("   An input file is already open");
    return;
  }
  i = dataStore[105].end;
  dataStore[105].array[i] = '\0';  /* terminate filename string */
  ifp = fopen(dataStore[105].array, "r");
  if ( ifp == NULL )  {
    error("   Requested file does not exist");
    return;
  }
  else  {
    XUnmapWindow(e6display, windowStore[7]);
    for (i=0; i<dataStore[105].end; i++)  /* to simplify exposure recovery */
      dataStore[104].array[i] = dataStore[105].array[i];
    dataStore[104].end = dataStore[105].end;
    XMapWindow(e6display, windowStore[6]);    /* show read file's name */
    XReparentWindow(e6display, dataStore[104].id, windowStore[6], 2, 35);
    XMapWindow(e6display, dataStore[104].id);
    XDrawString(e6display, dataStore[105].id, GC1, 0, 15,
                  dataStore[104].array, dataStore[104].end);
  }
}



/*  The function called to close a currently open output file */

void  closeoutput()
{
  void  error(char *);   /* in error.c */

  if ( ofp == NULL )  {
    error("    No reference storage is open");
    return;
  }
  if ( fclose(ofp) )  {
    error("   Output storage will not close");
    return;
  }
  ofp = NULL;  /* reset the output file handle */
  who = 0;
  XUnmapWindow(e6display, windowStore[1]);  /* window showing append filename */
  XUnmapWindow(e6display, windowStore[5]);  /* window showing write filename */
}


/*  The function called to close a currently open input file */

void  closein()
{
  void  error(char *);   /* in error.c */

  if ( ifp == NULL )  {
    error("    No reference input is open");
    return;
  }
  if ( fclose(ifp) )  {
    error("   Input storage will not close");
    return;
  }
  ifp = NULL;  /* reset the output file handle */
  who = 0;
//  XUnmapWindow(e6display, windowStore[1]);  /* window showing append filename */
  XUnmapWindow(e6display, windowStore[6]);  /* window showing input filename */
}



/*  The function called to cancel an new file creation */

void cancelnew()
{

  XUnmapWindow(e6display, windowStore[0]);    /* remove new name framing */
  if (ofp == NULL )  {
    XUnmapWindow(e6display, windowStore[1]);    /* remove open file's name */
    who = 0;
  }
}


/*  The function called to cancel an new file creation */

void cancelappend()
{

  XUnmapWindow(e6display, windowStore[2]);    /* remove append name framing */
  if (ofp == NULL )  {
    XUnmapWindow(e6display, windowStore[1]);    /* remove open file's name */
    who = 0;
  }
}


/*  The function called to cancel a read file request */

void cancelread()
{

  XUnmapWindow(e6display, windowStore[7]);    /* remove openfile name framing */
  if (ifp == NULL )  {
    XUnmapWindow(e6display, windowStore[6]);    /* remove open file's name */
    who = 0;
  }
}


