/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  Contained here are routines to extract reference information
 *  and display it on the screen.  Different routines perform different manners
 *  to determining the references to display.
 *
 *  Coded by:       Ross Maloney
 *  January 2013:   Initial code
 *  May 2016:       Use editor field if present in showAll()
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <X11/keysym.h>
#include  <X11/keysymdef.h>
#include  <stdio.h>
#include  <string.h>      /* for strlen() */
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

                      /* This routine displays all the references contained in
		       * the file open for reading.
		       */

void  showAll()
{ 
  int   y;
  void  unpackage(void);     /* in this file */
  int   extract(char *);     /* in this file */
  extern void  error(char *);       /* in error.c */

  if ( !ifp )  {
    error("  Sorry: First open a file to read");
    return;
  }

  XResizeWindow(e6display, baseW, 1240, 655);
  XMapWindow(e6display, windowStore[8]);          /* citation display */
  XFlush(e6display);   /* force change so citations will show as found */
  XFlush(e6display);   /* this one makes it work */
  XReparentWindow(e6display, moduleStore[36].id, windowStore[8], 0, 0);
  XMapWindow(e6display, moduleStore[36].id);      /* lettering window */
  XMapWindow(e6display, windowStore[9]);          /* citation data frame */
  XMapWindow(e6display, windowStore[10]);         /* button frame */
  XMapWindow(e6display, buttonStore[6].normal);   /* the 'clear'' button */

  rewind(ifp);    /* must start at the beginning of the file to be read */
  y = 15;
  XMapWindow(e6display, windowStore[11]);  /* Keyword */
  XMapWindow(e6display, windowStore[12]);  /* Date/Year */
  XResizeWindow(e6display, windowStore[13], 300, 512);
  XMoveWindow(e6display, windowStore[13], 210, 1); /* reposition Author/Editor*/
  XMapWindow(e6display, windowStore[13]);  /* Author/Editor */
  XMoveWindow(e6display, windowStore[14], 515, 1); /* reposition Title */
  XMapWindow(e6display, windowStore[14]);  /* Title */
  while ( extract( citblock ) ) {  /* get fields for all citations present */
    unpackage();
    XDrawString(e6display, windowStore[11], GC1, 5, y, keywords,
       strlen(keywords));
    XDrawString(e6display, windowStore[12], GC1, 5, y, date, strlen(date));
    XDrawString(e6display, windowStore[13], GC1, 5, y, author,
       strlen(author));
    XDrawString(e6display, windowStore[14], GC1, 5, y, title, strlen(title));
    y = y + 15;
  }
}


                      /* This routine displays all the references in the file
		       * open for reading which have a given citation author.
		       * Further details are then filled in by the function
		       * 'searchShow().
		       */

void  showAuthor()
{
  void  error(char *);       /* in error.c */

  if ( !ifp )  {
    error("  Sorry: First open a file to read");
    return;
  }

  searchType = 1;   /* a Date citation search */

  XResizeWindow(e6display, baseW, 1240, 655);
  XMapWindow(e6display, windowStore[8]);          /* citation display */
  XReparentWindow(e6display, moduleStore[39].id, windowStore[8], 0, 0);
  XMapWindow(e6display, moduleStore[39].id);      /* lettering window */
  XMapWindow(e6display, windowStore[9]);          /* citation data frame */
  XReparentWindow(e6display, dataStore[106].id, moduleStore[39].id, 180, 30);
  XMapWindow(e6display, dataStore[106].id);        /* selection input window */
  XMapWindow(e6display, windowStore[10]);         /* button frame */
  XMapWindow(e6display, buttonStore[6].normal);   /* the 'clear'' button */
}


                      /* This routine displays all the references in the file
		       * open for reading which have a given citation type.
		       * Further details are then filled in by the function
		       * 'searchShow().
		       */

void  showType()
{
  extern void  error(char *);       /* in error.c */

  if ( !ifp )  {
    error("  Sorry: First open a file to read");
    return;
  }

  searchType = 2;   /* a Date citation search */

  XResizeWindow(e6display, baseW, 1240, 655);
  XMapWindow(e6display, windowStore[8]);          /* citation display */
  XReparentWindow(e6display, moduleStore[37].id, windowStore[8], 0, 0);
  XMapWindow(e6display, moduleStore[37].id);      /* lettering window */
  XMapWindow(e6display, windowStore[9]);          /* citation data frame */
  XReparentWindow(e6display, dataStore[106].id, moduleStore[37].id, 145, 30);
  XMapWindow(e6display, dataStore[106].id);        /* selection input window */
  XMapWindow(e6display, windowStore[10]);         /* button frame */
  XMapWindow(e6display, buttonStore[6].normal);   /* the 'clear'' button */
}


                      /* This routine displays all the references in the file
		       * open for reading which have a given citation year/date.
		       * Further details are then filled in by the function
		       * 'searchShow().
		       */

void  showDate()
{
  void  error(char *);       /* in error.c */

  if ( !ifp )  {
    error("  Sorry: First open a file to read");
    return;
  }

  searchType = 3;   /* a Date citation search */

  XResizeWindow(e6display, baseW, 1240, 655);
  XMapWindow(e6display, windowStore[8]);          /* citation display */
  XReparentWindow(e6display, moduleStore[38].id, windowStore[8], 0, 0);
  XMapWindow(e6display, moduleStore[38].id);      /* lettering window */
  XMapWindow(e6display, windowStore[9]);          /* citation data frame */
  XReparentWindow(e6display, dataStore[106].id, moduleStore[38].id, 145, 30);
  XMapWindow(e6display, dataStore[106].id);        /* selection input window */
  XMapWindow(e6display, windowStore[10]);         /* button frame */
  XMapWindow(e6display, buttonStore[6].normal);   /* the 'clear'' button */
}

                      /* This routine displays all the references in the file
		       * open for reading which contain the given word somewhere
		       * in their content.
		       */

void  showWord()
{
  extern void  error(char *);       /* in error.c */

  if ( !ifp )  {
    error("  Sorry: First open a file to read");
    return;
  }

  searchType = 4;   /* a Date citation search */

  XResizeWindow(e6display, baseW, 1240, 655);
  XMapWindow(e6display, windowStore[8]);          /* citation display */
  XReparentWindow(e6display, moduleStore[40].id, windowStore[8], 0, 0);
  XMapWindow(e6display, moduleStore[40].id);      /* lettering window */
  XMapWindow(e6display, windowStore[9]);          /* citation data frame */
  XReparentWindow(e6display, dataStore[106].id, moduleStore[40].id, 150, 30);
  XMapWindow(e6display, dataStore[106].id);        /* selection input window */
  XMapWindow(e6display, windowStore[10]);         /* button frame */
  XMapWindow(e6display, buttonStore[6].normal);   /* the 'clear'' button */
}


                      /* Function to extract parts of a citation which are then
		       * used by several display routines.
		       */

void  unpackage()
{
  char  c;
  int   i, end, index;
  char  *temp;
  int   extract(char *);   /* in this file */
  int   strend(char *, char *);  /* in this file */
  extern void  error(char *);       /* in error.c */

  author[0] = '\0';
                  /* title */
  index = strend("title        = {", citblock);
  i = 0;
  temp = title;  /* re-use an array */
  while ( citblock[index] != '}' )  {
    temp[i] = citblock[index];
    index++;
    i++;
  }
  temp[i] = '\0';
                  /* author */
  index = strend("author       = {", citblock);
  if ( index == 0 )  {
                  /* author/editor */
    index = strend("authoreditor = {", citblock);
    temp = author;  /* re-use an array */
    i = 0;
    while ( citblock[index] != '}' )  {
      temp[i] = citblock[index];
      index++;
      i++;
    }
    temp[i] = '\0';
  }  else  {
    i = 0;
    temp = author;  /* re-use an array */
    while ( citblock[index] != '}' )  {
      temp[i] = citblock[index];
      index++;
      i++;
    }
    temp[i] = '\0';
  }
  index = strend("editor       = {", citblock);
  if ( index > 0 )  {
    i = 0;
    temp = author;  /* re-use an array */
    while ( citblock[index] != '}' )  {
      temp[i] = citblock[index];
      index++;
      i++;
    }
    temp[i] = '\0';
  }
                 /* date */
  index = strend("date         = {", citblock);
  i = 0;
  temp = date;  /* re-use an array */
  for (i=0; i<4; i++)  {
    temp[i] = citblock[index];
    index++;
  }
  temp[i] = '\0';
                   /* citation type */
  index = 1;
  i = 0;
  temp = type2;  /* re-use an array */
  while ( citblock[index] != '{' )  {
    temp[i] = citblock[index];
    index++;
    i++;
  }
  temp[i] = '\0';
                  /* key word */
  index = strend("{", citblock);
  i = 0;
  temp = keywords;  /* re-use an array */
  while ( citblock[index] != ',' )  {
    temp[i] = citblock[index];
    index++;
    i++;
  }
  temp[i] = '\0';
//  printf("title = %s\n", title);
//  printf("author = %s\n", author);
//  printf("date = %s\n", date);
//  printf("type = %s\n", type2);
//  printf("keyword = %s\n", keywords);
}


                      /* This routine is called to finish displaying citations.
		       * It is called upon clicking the 'clear' button under the
		       * window showing the name of the file being read
		       * (searched).
		       */

void  clearfind()
{
  int  i;

  for (i=10; i<16; i++)  XUnmapWindow(e6display, windowStore[i]);
  XUnmapWindow(e6display, windowStore[8]);     /* remove the window frame */
  XResizeWindow(e6display, baseW, 335, 655);   /* standard window size */
  dataStore[106].end = 0;
  dataStore[106].current = 0;
  for (i=0; i<20; i++) target[i] = 0;  /* must clear this */
}



                      /* This function searches for the occurrence of the first
		       * string in the second string and then returns the index
		       * relative to the second string of the end of the match
		       * to the first string.  That index is the location of the
		       * character one beyond the end of the matching string.
		       * If there is not match NULL is returned.
		       */

int strend(char *find, char *in)
{
  int  index, count, i;
  char  *p;

  index = count = i = 0;
  p = find;
  while ( *in != '\0' )  {
    i++;
    if ( *p == *in )  {
      p++;
      count++;
      if ( *p == '\0' )  return(i);  /* first match found */
    }
    else  {
      index = index + count + 1;
      count = 0;
      p = find;
    }
    ++in;
  }
  return(0);   /* not found */
}


                      /* Function to extract a complete citation from the opened
		       * input file.
		       */

int  extract(char *block)
{
  int  count, flag, started, i;
  char ch;

  count = 10000;  /* set to something large */
  flag = 0;       /* not set */
  started =0;     /* not set */
  i = 0;          /* set to start of block[] */
  while ( ( ch = getc(ifp) ) != EOF )  {
    block[i] = ch;
    i++;
    switch ( ch )  {
    case '@':
//      printf("at\n");
      if ( flag )  {
        started = 1;
        count = 0;
	flag = 0;
      }
      break;
    case '\n':
//      printf("newline\n");
      flag = 1;
      if ( !started )  i = 0;
      break;
    case '{':
      if ( started )  count++;
//      printf("{   count = %d\n", count);
      break;
    case '}':
      if ( started )  count--;
//      printf("}   count = %d\n", count);
      if ( count == 0 )  {
        block[i] = '\0';
	return(1);  /* citation completed */
      }
      break;
    default:
      break;
    }
//    if ( count == 0 && started )  return(1);  /* citation completed */
  }
  return(0);  /* incomplete citation */
}

