/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  The function contained here creates windows, GCs, and fonts which are
 *  subsequently used or referenced by other functions.
 *
 *  Coded by:      Ross Maloney
 *  January 2012:  Initial coding
 *  July 2014:     Secondary data fields containment window added
 *  July 2020      Put window attribute handling in each procedure
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  <stdlib.h>      /* for exit() */
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "../lettering/marker.xbm"

#include  "../composites/createW.xbm"
#include  "../composites/showappW.xbm"
#include  "../composites/showwriteW.xbm"
#include  "../composites/selappW.xbm"
#include  "../composites/showreadW.xbm"
#include  "../composites/openW.xbm"
#include  "../composites/errorW.xbm"

#include  "../composites/clearB.xbm"


int  firstup()
{
  XSetWindowAttributes  frameat, baseat;
  XColor         exact, closest;
  XGCValues      valuesGC;
  Pixmap         mould;
  XFontStruct    *font1;
  unsigned long  valuemask;
  int            status, x, width, i, menuX, menuY;
  int            menu_width, menu_height;


                       /* Colours to be used */
  colours[0] = WhitePixel(e6display, screen_num);   /* white */
  colours[1] = BlackPixel(e6display, screen_num);   /* black */
  XAllocNamedColor(e6display, XDefaultColormap(e6display, screen_num),
                   "Bisque2", &exact, &closest);
  colours[2] = closest.pixel;
  XAllocNamedColor(e6display, XDefaultColormap(e6display, screen_num),
                   "blue", &exact, &closest);
  colours[3] = closest.pixel;
  XAllocNamedColor(e6display, XDefaultColormap(e6display, screen_num),
                   "red", &exact, &closest);   /*selected */
  colours[4] = closest.pixel;
  XAllocNamedColor(e6display, XDefaultColormap(e6display, screen_num),
                   "gray88", &exact, &closest);  /* normal button */
  colours[5] = closest.pixel;
  XAllocNamedColor(e6display, XDefaultColormap(e6display, screen_num),
                   "pink1", &exact, &closest);  /* not implemented yet */
  colours[6] = closest.pixel;
  colours[7] = 0xedfc98;  /* light yellow */
  XAllocNamedColor(e6display, XDefaultColormap(e6display, screen_num),
                   "yellow", &exact, &closest);
  colours[8] = closest.pixel;
  XAllocNamedColor(e6display, XDefaultColormap(e6display, screen_num),
                   "LightSkyBlue1", &exact, &closest);
  colours[9] = closest.pixel;

                       /* Set up the base window */
  valuemask = CWBackPixel | CWBorderPixel | CWEventMask;
  baseat.background_pixel = colours[8];
  baseat.border_pixel = colours[1];
  baseat.event_mask = ButtonPressMask | EnterWindowMask | ButtonReleaseMask |
                      LeaveWindowMask | OwnerGrabButtonMask; /* NO exposure */
//                        100, 0, 1260, 655, 2,
  baseW = XCreateWindow(e6display, RootWindow(e6display, screen_num),
                        100, 0, 335, 655, 2,
			depthDefault, InputOutput, visualDefault,
			valuemask, &baseat);
                       /* Set up the secondary data field window */
  secondsW = XCreateWindow(e6display, RootWindow(e6display, screen_num),
                        200, 200, 900, 645, 2,
			depthDefault, InputOutput, visualDefault,
			valuemask, &baseat);

		       /* Create the GCs to be used */
  valuesGC.foreground = colours[1];  /* menu item not selected */
  valuesGC.background = colours[0];
  GC1 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);
  valuesGC.foreground = colours[1];  /* menubar item selected */
  valuesGC.background = colours[2];
  GC2 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);
  valuesGC.foreground = colours[1];  /* menu item selected */
  valuesGC.background = colours[3];
  GC3 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);
  valuesGC.foreground = colours[1];  /* menu item selected */
  valuesGC.background = colours[4];
  GC4 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);
  valuesGC.foreground = colours[6];  /* button's function NOT implemented yet */
  valuesGC.background = colours[0];
  GC5 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);
  valuesGC.foreground = colours[7];  /* GC of clearing 'required' background */
  valuesGC.background = colours[1];  /* Not used - but set anyway */
  GC6 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);
  valuesGC.foreground = colours[2];  /* GC of clearing 'optional' background */
  valuesGC.background = colours[7];  /* Not used - but set anyway */
  GC7 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);
  valuesGC.foreground = colours[1];  /* GC for showing error messages */
  valuesGC.background = colours[8];
  GC8 = XCreateGC(e6display, baseW,
           ( GCForeground | GCBackground ), &valuesGC);

		       /* Font selection for use in all parts of program */
  if ( ( font1 = XLoadQueryFont(e6display,
             "-misc-fixed-bold-r-*-*-14-*-75-*-*-70-iso8859-1") ) == NULL )  {
    printf("e6: font is unavialable\n");
    exit(1);
  }
  XSetFont(e6display, GC1, font1->fid);
  XSetFont(e6display, GC8, font1->fid);
  charinc = font1->per_char->width; 

		       /* Create the text insertion marker as a pixmap */
  insertMarker = XCreatePixmapFromBitmapData(e6display, baseW,
                      marker_bits, marker_width, marker_height,
		      colours[4], colours[0], depthDefault);




		       /* Complete windows with bitmap backings.  */

		       /* 'create' window */
  frameat.background_pixmap = colours[8];
  frameat.border_pixel = colours[1];
  valuemask = CWBackPixel | CWBorderPixel;

  windowStore[0] = XCreateWindow(e6display, baseW,
                                 10, 170, createW_width, createW_height, 1,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, windowStore[0],
                                 createW_bits, createW_width, createW_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, windowStore[0], mould);

		       /* window to show name of append file */

  windowStore[1] = XCreateWindow(e6display, baseW,
                                 35, 210, showappW_width, showappW_height, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, windowStore[1],
                                 showappW_bits, showappW_width, showappW_height,
				 colours[1], colours[8], depthDefault);
  XSetWindowBackgroundPixmap(e6display, windowStore[1], mould);

		       /* 'append' selection window */

  windowStore[2] = XCreateWindow(e6display, baseW,
                                 12, 170, selappW_width, selappW_height, 1,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, windowStore[2],
                                 selappW_bits, selappW_width, selappW_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, windowStore[2], mould);
 
		       /* button frame window */

  windowStore[3] = XCreateWindow(e6display, baseW,
                                 40, 280, 262, 60, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);

		       /* window to show name of file written from start */

  windowStore[5] = XCreateWindow(e6display, baseW,
                                 35, 170, showwriteW_width, showwriteW_height,
				 XX, depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, windowStore[5],
                                 showwriteW_bits, showwriteW_width,
				 showwriteW_height,
				 colours[1], colours[8], depthDefault);
  XSetWindowBackgroundPixmap(e6display, windowStore[5], mould);
 
		       /* citation window frame */

  windowStore[8] = XCreateWindow(e6display, baseW,
                                 340, 0, 880, 630, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  XSetWindowBackground(e6display, windowStore[8], colours[8]);
 
		       /* citation data frame frame */

  windowStore[9] = XCreateWindow(e6display, windowStore[8],
                                 10, 100, 860, 515, 1,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  XSetWindowBackground(e6display, windowStore[9], colours[0]);
 
		       /* citation data keyword */

  windowStore[11] = XCreateWindow(e6display, windowStore[9],
                                 1, 1, 150, 512, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  XSetWindowBackground(e6display, windowStore[11], colours[0]);

 
		       /* citation data year */

  windowStore[12] = XCreateWindow(e6display, windowStore[9],
                                 155, 1, 50, 512, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  XSetWindowBackground(e6display, windowStore[12], colours[0]);
  
		       /* citation data author/editor */

  windowStore[13] = XCreateWindow(e6display, windowStore[9],
                                 210, 1, 300, 512, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  XSetWindowBackground(e6display, windowStore[13], colours[0]);
  
		       /* citation data title */

  windowStore[14] = XCreateWindow(e6display, windowStore[9],
                                 515, 1, 342, 512, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  XSetWindowBackground(e6display, windowStore[14], colours[0]);
  
		       /* citation data type */

  windowStore[15] = XCreateWindow(e6display, windowStore[9],
                                 155, 1, 100, 512, XX,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  XSetWindowBackground(e6display, windowStore[15], colours[0]);
  

		       /* error window */

  frameat.background_pixel = colours[9];
  windowStore[4] = XCreateWindow(e6display, baseW,
                                  35, 475, errorW_width, errorW_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, windowStore[4],
                                 errorW_bits, errorW_width, errorW_height,
				 colours[4], colours[9], depthDefault);
  XSetWindowBackgroundPixmap(e6display, windowStore[4], mould);

		       /* window to show name of file for reading */

  windowStore[6] = XCreateWindow(e6display, baseW,
                                 35, 340, showreadW_width, showreadW_height,
				 XX, depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, windowStore[6],
                                 showreadW_bits, showreadW_width,
				 showreadW_height,
				 colours[1], colours[8], depthDefault);
  XSetWindowBackgroundPixmap(e6display, windowStore[6], mould);

		       /* 'read' selection window */

  windowStore[7] = XCreateWindow(e6display, baseW,
                                 12, 170, openW_width, openW_height, 1,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, windowStore[7],
                                 openW_bits, openW_width, openW_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, windowStore[7], mould);

		       /* citation button frame window */

  windowStore[10] = XCreateWindow(e6display, baseW,
                                 130, 420, clearB_width+2, clearB_height+2, 0,
				 depthDefault, InputOutput, visualDefault,
				 valuemask, &frameat);

  return(0);
}
