
/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains the function to handle a 'in reference' citation type.
 *  It is treated as being the same, with minor labelling modifications, as the
 *  'in collection' reference type.  In effect, this citation type is taken to
 *  be an alias for the 'collection' citation type.
  *
 *  Coded by:       Ross Maloney
 *  January 2013:   Initial code
 *  September 2014: Minor field handling moved to inref2()
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  inreference()
{
  void showkeysO(void);        /* in utilities.c */
  void showissO(void);         /* in utilities.c */
  void wordsO(void);           /* in utilities.c */
  void showeventsO(void);      /* in utilities.c */
  void shownote(void);         /* in utilities.c */
  void removeMenus(int);       /* in mouseevent.c */
  void error(char *);          /* in error.c */
  void zeroall(void);          /* in texting.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 895);
  removeMenus(1);   /* remove the menu train which led to this function */

  XMapWindow(e6display, moduleStore[35].id);  /* inreference Required */
  who = 62;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);

  XReparentWindow(e6display, dataStore[2].id,
         moduleStore[35].id, 60, 47);    /* author */
  XMapWindow(e6display, dataStore[2].id);
  dataStore[2].before = 65;
  dataStore[2].next = 1;
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[35].id, 50, 78);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 2;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[35].id, 725, 78);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 71;
  XReparentWindow(e6display, dataStore[71].id,
         moduleStore[35].id, 80, 108); /* book title */
  XMapWindow(e6display, dataStore[71].id);
  dataStore[71].before = 0;
  dataStore[71].next = 90;
  XReparentWindow(e6display, dataStore[90].id,
       moduleStore[35].id, 55, 138);  /* editor */
  XMapWindow(e6display, dataStore[90].id);
  dataStore[90].before = 71;
  dataStore[90].next = 92;
  XReparentWindow(e6display, dataStore[92].id,
       moduleStore[35].id, 640, 138);  /* short editor */
  XMapWindow(e6display, dataStore[92].id);
  dataStore[92].before = 90;
  dataStore[92].next = 70;
  XReparentWindow(e6display, dataStore[70].id,
       moduleStore[35].id, 102, 188); /* book subtitle */
  XMapWindow(e6display, dataStore[70].id);
  dataStore[70].before = 92;
  dataStore[70].next = 72;
  XReparentWindow(e6display, dataStore[72].id,
       moduleStore[35].id, 122, 218); /* book title addon */
  XMapWindow(e6display, dataStore[72].id);
  dataStore[72].before = 70;
  dataStore[72].next = 62;
  XReparentWindow(e6display, dataStore[62].id,
       moduleStore[35].id, 62, 248);   /* edition */
  XMapWindow(e6display, dataStore[62].id);
  dataStore[62].before = 72;
  dataStore[62].next = 19;
  XReparentWindow(e6display, dataStore[19].id,
       moduleStore[35].id, 62, 278);   /* volume */
  XMapWindow(e6display, dataStore[19].id);
  dataStore[19].before = 62;
  dataStore[19].next = 18;
  XReparentWindow(e6display, dataStore[18].id,
       moduleStore[35].id, 262, 278);   /* number */
  XMapWindow(e6display, dataStore[18].id);
  dataStore[18].before = 19;
  dataStore[18].next = 21;
  XReparentWindow(e6display, dataStore[21].id,
       moduleStore[35].id, 450, 278);   /* pages */
  XMapWindow(e6display, dataStore[21].id);
  dataStore[21].before = 18;
  dataStore[21].next = 56;
  XReparentWindow(e6display, dataStore[56].id,
       moduleStore[35].id, 73, 308);   /* publisher */
  XMapWindow(e6display, dataStore[56].id);
  dataStore[56].before = 21;
  dataStore[56].next = 73;
  XReparentWindow(e6display, dataStore[73].id,
       moduleStore[35].id, 723, 308); /* chapter */
  XMapWindow(e6display, dataStore[73].id);
  dataStore[73].before = 56;
  dataStore[73].next = 22;
  XReparentWindow(e6display, dataStore[22].id,
       moduleStore[35].id, 60, 338);  /* series */
  XMapWindow(e6display, dataStore[22].id);
  dataStore[22].before = 73;
  dataStore[22].next = 96;
  XReparentWindow(e6display, dataStore[96].id,
       moduleStore[35].id, 640, 338);  /* short series */
  XMapWindow(e6display, dataStore[96].id);
  dataStore[96].before = 22;
  dataStore[96].next = 20;
  XReparentWindow(e6display, dataStore[20].id,
       moduleStore[35].id, 55, 368);  /* isbn */
  XMapWindow(e6display, dataStore[20].id);
  dataStore[20].before = 96;
  dataStore[20].next = 55;
  XReparentWindow(e6display, dataStore[55].id,
       moduleStore[35].id, 388, 368);  /* part */
  XMapWindow(e6display, dataStore[55].id);
  dataStore[55].before = 20;
  dataStore[55].next = 60;
  XReparentWindow(e6display, dataStore[60].id,
       moduleStore[35].id, 710, 368);  /* volumes */
  XMapWindow(e6display, dataStore[60].id);
  dataStore[60].before = 55;
  dataStore[60].next = 91;

                        /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 410);
  dataStore[91].before = 60;
  dataStore[88].next = 65;
  showkeysO();  /* keys Optional */

                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 533);
  shownote();

  zeroall();        /* set all input data fields to zero */
}



/*  Function to form the window to contain the minor data fields associated with
 *  an in reference reference type.
 */

void  inref2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (in Reference)";
  char *icon_name = "e6/2";
  void showeditorabcO(void);   /* in utilities.c */
  void showlargeO(void);       /* in utilities.c */
  void showorigO(void);        /* in utilities.c */
  void showeprintO(void);      /* in utilities.c */
  void showlargeO1(void);      /* in utilities.c */
  void showmainO(void);        /* in utilities.c */
  void showwordsO(void);       /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 580);
  XMapWindow(e6display, secondsW);

                         /* linking in wordsO */
//  XMoveWindow(e6display, moduleStore[9].id, 0, 540);
  XMoveWindow(e6display, moduleStore[9].id, 0, 5);
  dataStore[63].before = 26;
  dataStore[52].next = 42;
  showwordsO();      /* auxiliary information */
                        /* linking in mainO */
  XMoveWindow(e6display, moduleStore[5].id, 0, 96);
  dataStore[42].before = 52;
  dataStore[43].next = 10;
  showmainO();       /* pieces with 'main' in their name */
                        /* linking in editorabcO */
  XMoveWindow(e6display, moduleStore[2].id, 0, 155);
  dataStore[10].before = 43;
  dataStore[15].next = 48;
  showeditorabcO();  /* editor descriptors */
                        /* linking in origO */
  XMoveWindow(e6display, moduleStore[6].id, 0, 245);
  dataStore[48].before = 15;
  dataStore[49].next = 34;
  showorigO();       /* original publication details */
                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 335);
  showeprintO();     /* eprint information */
  XMoveWindow(e6display, moduleStore[7].id, 0, 365);
  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 395);
  showlargeO();      /* large Optionals */
  dataStore[34].before = 49;
  dataStore[26].next = 63;
}
