/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains the functions to handle a 'letter' citation type.
 *
 *  Coded by:       Ross Maloney
 *  June 2018:      Initial code 
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  letter()
{
  extern void showkeysO(void);        /* in utilities.c */
  extern void shownote(void);         /* in utilities.c */
  extern void removeMenus(int);       /* in mouseevent.c */
  extern void error(char *);          /* in error.c */
  extern void zeroall(void);          /* in texting.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 767);
  removeMenus(1);   /* remove the menu train which led to this function */
  who = 90;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);
  XMapWindow(e6display, moduleStore[59].id);  /* letter Required */

  XReparentWindow(e6display, dataStore[2].id,
         moduleStore[59].id, 60, 43);    /* author */
  XMapWindow(e6display, dataStore[2].id);
  dataStore[2].before = 65;
  dataStore[2].next = 1;
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[59].id, 50, 77);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 2;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[59].id, 725, 77);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 111;
  XReparentWindow(e6display, dataStore[111].id,
          moduleStore[59].id, 54, 110);    /* type */
  XMapWindow(e6display, dataStore[111].id);
  dataStore[111].before = 0;
  dataStore[111].next = 19;
  XReparentWindow(e6display, dataStore[19].id,
	moduleStore[59].id, 360, 111);    /* volume */
  XMapWindow(e6display, dataStore[19].id);
  dataStore[19].before = 111;
  dataStore[19].next = 80;
  XReparentWindow(e6display, dataStore[80].id,
	 moduleStore[59].id, 105, 145);    /* how published */
  XMapWindow(e6display, dataStore[80].id);
  dataStore[80].before = 19;
  dataStore[80].next = 21;
  XReparentWindow(e6display, dataStore[21].id,
	moduleStore[59].id, 55, 180);    /* pages */
  XMapWindow(e6display, dataStore[21].id);
  dataStore[21].before = 80;
  dataStore[21].next = 46;
  XReparentWindow(e6display, dataStore[46].id,
	moduleStore[59].id, 95, 215);    /* organization */
  XMapWindow(e6display, dataStore[46].id);
  dataStore[46].before = 21;
  dataStore[46].next = 22;  
  XReparentWindow(e6display, dataStore[22].id,
         moduleStore[59].id, 60, 249);    /* series */
  XMapWindow(e6display, dataStore[22].id);
  dataStore[22].before = 46;
  dataStore[22].next = 91;
                       /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 282);
  showkeysO();  /* keys Optional */
  dataStore[91].before = 22;
  dataStore[88].next = 65;
                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 405);
  shownote();

  zeroall();        /* set all input data fields to zero */
}


/*  Function to form the window to contain the minor data fields associated with
 *  a letter reference type.
 */

void  letter2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (Letter)";
  char *icon_name = "e6/2";
  extern void showeditorabcO(void);   /* in utilities.c */
  extern void showlargeO(void);       /* in utilities.c */
  extern void showmainO(void);        /* in utilities.c */
  extern void showorigO(void);        /* in utilities.c */
  extern void showeprintO(void);      /* in utilities.c */
  extern void showlargeO1(void);      /* in utilities.c */
  extern void showissO(void);         /* in utilities.c */
  extern void wordsO(void);           /* in utilities.c */
  extern void showeventsO(void);      /* in utilities.c */
  extern void showwordsO(void);       /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 233);
  XMapWindow(e6display, secondsW);
  XMoveWindow(e6display, moduleStore[9].id, 0, 5);
  //  showwordsO();      /* auxiliary information */
                       /* linking in wordsO */
  //  dataStore[63].before = 26;
  //  dataStore[52].next = 38;
                        /* linking in issO */
  //  XMoveWindow(e6display, moduleStore[4].id, 0, 95);
  //  dataStore[38].before = 52;
  //  dataStore[39].next = 10;
  //  showissO();        /* issue parts */
                        /* linking in editorabcO */
  //  XMoveWindow(e6display, moduleStore[2].id, 0, 152);
  //  dataStore[10].before = 39;
  //  dataStore[15].next = 48;
  //  showeditorabcO();  /* editor descriptors */
                        /* linking in origO */
  //  XMoveWindow(e6display, moduleStore[6].id, 0, 242);
  //  dataStore[48].before = 15;
  //  dataStore[49].next = 34;
  //  showorigO();       /* original publication details */
                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 3);
  showeprintO();     /* eprint information */
  dataStore[35].next = 29;
  dataStore[29].before = 35;
  //  XMoveWindow(e6display, moduleStore[7].id, 0, 362);
  //  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 39);
  showlargeO();      /* large Optionals */
  dataStore[26].next = 34;
  dataStore[34].before = 26;
}
