/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  The code contained here initiates the operation of n6.
 *
 *  Coded by:       Ross Maloney
 *  January 2011:   Initial code
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  <stdlib.h>      /* for exit() */
#include  "e6x11.h"       /* X11 related common parts of e6 */
#include  "e6data.h"      /* Common parts for processing data */

                  /* Prototypes of all functions called from here */

extern int  firstup(void);      /* in foundations.c */
extern int  findIndex(Window);  /* in mouseevents.c */
extern void menuEntered(int);   /* in mouseevents.c */
extern void menuVacated(int);   /* in mouseevents.c */
extern void doRelease(int);     /* in do.c */
extern void doEnter(int);       /* in do.c */
extern void keyEntry(XKeyEvent *, int);      /* in texting.c */
extern void keyNote(XKeyEvent *, int);       /* in texting.c */
extern void replacetext(int);   /* in texting.c */
extern int  initialize(void);   /* this file */

int  main(int argc, char *argv[])
{
  XSizeHints     wmsize;
  XWMHints       wmhints;
  XTextProperty  mainName, iconName;
  XEvent         e6events;
  XGCValues      e6GCValues;
  char *main_name = "e6 - EndNote Sibling in Xlib (ver 2.3.0)";
  char *icon_name = "e6";
  int            request, i, index, k;
  extern int  arguments(int, char *[]);   /* in commandline.c */
  extern int  allmenus(void);             /* in menus.c */
  extern int  windowModules(void);        /* in modules.c */
  extern int  iowindows(void);            /* in modules.c */
  extern void  buttonEntered(int);        /* in buttons.c */
  extern void  buttonLeave(int);          /* in button.c */

               /* Open connection to the X server */
  e6display = XOpenDisplay("");

	       /* Create a top-level window*/
  screen_num = DefaultScreen(e6display);
  depthDefault = DefaultDepth(e6display, screen_num);
  visualDefault = DefaultVisual(e6display, screen_num);
  status = firstup();
  status = allmenus();
  status = windowModules();
  status = iowindows();

	       /* Give the Window Manager some hints */
  wmsize.flags = USPosition | USSize;
  XSetWMNormalHints(e6display, baseW, &wmsize);
  wmhints.initial_state = NormalState;
  wmhints.flags = StateHint;
  XSetWMHints(e6display, baseW, &wmhints);
  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, baseW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, baseW, &iconName);

	       /* Process the command line arguments */
  request = arguments(argc,  argv);

	       /* Map the initial window onto the display */
  XMapWindow(e6display, baseW);
  for (i=BOTTOM_0; i<TOP_0; i++)  {
    XMapWindow(e6display, menuStore[i].selected);
    XMapWindow(e6display, menuStore[i].normal);
    XRaiseWindow(e6display, menuStore[i].normal);
    menuStore[i].visible = 1;
  }

	       /* Enter the event loop which runs the program from now on */
   done = initialize();
                /* This code is to put commandline info into standard e6 form */
   if ( request & 1 )  {
     who = 2;
     doRelease(3003);   /* append(); */
   }
   if ( request & 2 )  {
     who = 1;
     doRelease(3003);   /* createnew(); */
   }
   if ( request & 4 )  {
     who = 3;
     doRelease(3003);   /* openread(); */
   }
   while ( done == 0 )  {
     XNextEvent(e6display, &e6events);
     switch (e6events.type)  {
     case Expose:
         index = findIndex(e6events.xany.window);
         replacetext(index);
       break;
     case  ButtonPress:
       break;
     case  ButtonRelease:
       index = findIndex(e6events.xany.window);
       doRelease(index);
       break;
     case  EnterNotify:
       index = findIndex(e6events.xany.window);
       if ( index == SECONDS_WINDOW )  break;
       if ( index > 1999 )  {
         buttonEntered(index);
         break;
       }
       if ( index > 999  )  {  /* if it is a data input window */
         break;
       }
       if ( k != index ) 
         if ( index > -1 )  menuEntered(index);
       k = index;
       break;
     case  LeaveNotify:
       if ( index > 2999 )  {
         buttonLeave(index);
         break;
       }
       break; 
     case  KeyPress:
       index = findIndex(e6events.xany.window);
       if ( index == 1065 )
         keyNote(&e6events.xkey, index);
       else
         keyEntry(&e6events.xkey, index);
       break; 
     } 
   }

	       /* Quit given - so cleanup before exiting */
  XUnmapWindow(e6display, baseW);
  XDestroyWindow(e6display, baseW);
  XCloseDisplay(e6display);
}


/*  Routine to set data used in this program to their initial value */

int  initialize()
{
  int   i;

  mouseActive = 0;
  error_flag = doit_flag = request_flag = 0;
  ifp = NULL;   /* initially there is no input of output reference files */
  ofp = NULL;
  who = 0;  /* NO activity */
  for (i=0; i<99; i++)  dataStore[i].end = 0;
  return(0);
}
