/* This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 * This file contains the function which handles a 'manual' citation type
 *
 * Coded by:       Ross Maloney
 * December 2012:  Initial code
 * September 2014: Minor field handling moved to manual2()
 */
#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  manual()
{
  void showkeysO(void);        /* in utilities.c */
  void error(char *);          /* in error.c */
  void removeMenus(int);       /* in mouseevent.c */
  void shownote(void);         /* in utilities.c */
  void zeroall(void);          /* in texting.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 800);
  removeMenus(1);   /* remove the menu train which led to this function */
  who = 63;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, moduleStore[30].id);  /* manual Required */
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);
  
  XReparentWindow(e6display, dataStore[3].id,
         moduleStore[30].id, 102, 47);    /* author/editor */
  XMapWindow(e6display, dataStore[3].id);
  dataStore[3].before = 65;
  dataStore[3].next = 1;
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[30].id, 50, 78);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 3;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[30].id, 725, 78);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 46;
  XReparentWindow(e6display, dataStore[46].id,
         moduleStore[30].id, 95, 126);    /* organization */
  XMapWindow(e6display, dataStore[46].id);
  dataStore[46].before = 0;
  dataStore[46].next = 62;
  XReparentWindow(e6display, dataStore[62].id,
         moduleStore[30].id, 60, 156);    /* edition */
  XMapWindow(e6display, dataStore[62].id);
  dataStore[62].before = 46;
  dataStore[62].next = 53;
  XReparentWindow(e6display, dataStore[53].id,
         moduleStore[30].id, 380, 156);    /* page total */
  XMapWindow(e6display, dataStore[53].id);
  dataStore[53].before = 62;
  dataStore[53].next = 59;
  XReparentWindow(e6display, dataStore[59].id,
         moduleStore[30].id, 725, 156);    /* version */
  XMapWindow(e6display, dataStore[59].id);
  dataStore[59].before = 53;
  dataStore[59].next = 18;
  XReparentWindow(e6display, dataStore[18].id,
         moduleStore[30].id, 65, 186);    /* number */
  XMapWindow(e6display, dataStore[18].id);
  dataStore[18].before = 59;
  dataStore[18].next = 21;
  XReparentWindow(e6display, dataStore[21].id,
         moduleStore[30].id, 255, 186);    /* pages */
  XMapWindow(e6display, dataStore[21].id);
  dataStore[21].before = 18;
  dataStore[21].next = 56;
  XReparentWindow(e6display, dataStore[56].id,
         moduleStore[30].id, 70, 216);    /* pages */
  XMapWindow(e6display, dataStore[56].id);
  dataStore[56].before = 21;
  dataStore[56].next = 73;
  XReparentWindow(e6display, dataStore[73].id,
         moduleStore[30].id, 725, 216);    /* chapter */
  XMapWindow(e6display, dataStore[73].id);
  dataStore[73].before = 56;
  dataStore[73].next = 22;
  XReparentWindow(e6display, dataStore[22].id,
         moduleStore[30].id, 60, 246);  /* series */
  XMapWindow(e6display, dataStore[22].id);
  dataStore[22].before = 73;
  dataStore[22].next = 96;
  XReparentWindow(e6display, dataStore[96].id,
         moduleStore[30].id, 640, 246);  /* short series */
  XMapWindow(e6display, dataStore[96].id);
  dataStore[96].before = 22;
  dataStore[96].next = 20;
  XReparentWindow(e6display, dataStore[20].id,
         moduleStore[30].id, 50, 276);    /* isbn */
  XMapWindow(e6display, dataStore[20].id);
  dataStore[20].before = 96;
  dataStore[20].next = 98;
  XReparentWindow(e6display, dataStore[98].id,
         moduleStore[30].id, 605, 276);    /* type */
  XMapWindow(e6display, dataStore[98].id);
  dataStore[98].before = 20;
  dataStore[98].next = 91;
  
                        /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 315);
  showkeysO();  /* keys Optional */
  dataStore[91].before = 98;
  dataStore[88].next = 65;

                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 440);
  shownote();

  zeroall();        /* set all input data fields to zero */
}



/*  Function to form the window to contain the minor data fields associated with
 *  an manual reference type.
 */

void  manual2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (Manual)";
  char *icon_name = "e6/2";
  void showlargeO(void);       /* in utilities.c */
  void showeprintO(void);      /* in utilities.c */
  void showlargeO1(void);      /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 252);
  XMapWindow(e6display, secondsW);

                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 5);
  showeprintO();     /* eprint information */
  XMoveWindow(e6display, moduleStore[7].id, 0, 35);
  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 65);
  showlargeO();      /* large Optionals */
  dataStore[34].before = 26;
  dataStore[26].next = 34;
}
