/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains one function which creates all the windows used
 *  to form menus.
 *
 *  Coded by:       Ross Maloney
 *  January 2011:   Initial coding
 *  April 2012:     Rewrittem
 *  January 2012:   Window, GC, and font creation moved to support()
 *  March 2014:     Change alignment of menu relative to menu item leadin to it
 *  July 2020       Put window attribute handling in each prodedure
 *  March 2022      Database type added
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  <stdlib.h>      /* for exit() */
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "../composites/fileC.xbm"
#include  "../composites/editC.xbm"
#include  "../composites/citationC.xbm"
#include  "../composites/manageC.xbm"
#include  "../composites/searchC.xbm"
#include  "../composites/helpC.xbm"
#include  "../composites/newC.xbm"
#include  "../composites/openC.xbm"
#include  "../composites/appendC.xbm"
#include  "../composites/readC.xbm"
#include  "../composites/closeinC.xbm"
#include  "../composites/closeoutC.xbm"
#include  "../composites/quitC.xbm"
#include  "../composites/undoC.xbm"
#include  "../composites/copyC.xbm"
#include  "../composites/pasteC.xbm"
#include  "../composites/clearC.xbm"
#include  "../composites/cutC.xbm"
#include  "../composites/removeC.xbm"
#include  "../composites/biblatexAC.xbm"
#include  "../composites/biblatexBC.xbm"
#include  "../composites/aliasesC.xbm"
#include  "../composites/extensionsC.xbm"
#include  "../composites/showallC.xbm"
#include  "../composites/byauthorC.xbm"
#include  "../composites/bytypeC.xbm"
#include  "../composites/bydateC.xbm"
#include  "../composites/bywordC.xbm"
#include  "../composites/byxrefC.xbm"
#include  "../composites/bykeyC.xbm"
#include  "../composites/articleC.xbm"
#include  "../composites/bookC.xbm"
#include  "../composites/mvbookC.xbm"
#include  "../composites/bookinbookC.xbm"
#include  "../composites/bookletC.xbm"
#include  "../composites/collectionC.xbm"
#include  "../composites/mvcollectionC.xbm"
#include  "../composites/suppcollectionC.xbm"
#include  "../composites/inbookC.xbm"
#include  "../composites/suppbookC.xbm"
#include  "../composites/incollectionC.xbm"
#include  "../composites/inproceedingsC.xbm"
#include  "../composites/inreferenceC.xbm"
#include  "../composites/manualC.xbm"
#include  "../composites/miscC.xbm"
#include  "../composites/onlineC.xbm"
#include  "../composites/patentC.xbm"
#include  "../composites/periodicalC.xbm"
#include  "../composites/suppperiodicalC.xbm"
#include  "../composites/proceedingsC.xbm"
#include  "../composites/mvproceedingsC.xbm"
#include  "../composites/referenceC.xbm"
#include  "../composites/mvreferenceC.xbm"
#include  "../composites/reportC.xbm"
#include  "../composites/setC.xbm"
#include  "../composites/thesisC.xbm"
#include  "../composites/unpublishedC.xbm"
#include  "../composites/conferenceC.xbm"
#include  "../composites/electronicC.xbm"
#include  "../composites/mastersthesisC.xbm"
#include  "../composites/phdthesisC.xbm"
#include  "../composites/techreportC.xbm"
#include  "../composites/wwwC.xbm"
#include  "../composites/artworkC.xbm"
#include  "../composites/audioC.xbm"
#include  "../composites/bibnoteC.xbm"
//#include  "../composites/commentaryC.xbm"
#include  "../composites/imageC.xbm"
#include  "../composites/jurisdictionC.xbm"
#include  "../composites/legislationC.xbm"
#include  "../composites/legalC.xbm"
#include  "../composites/letterC.xbm"
#include  "../composites/movieC.xbm"
#include  "../composites/musicC.xbm"
#include  "../composites/performanceC.xbm"
#include  "../composites/reviewC.xbm"
#include  "../composites/softwareC.xbm"
#include  "../composites/standardC.xbm"
#include  "../composites/videoC.xbm"
#include  "../composites/databaseC.xbm"

int  allmenus()
{
  int            status, position, x, width, i, menuX, menuY;
  int            menu_width, menu_height;
  unsigned long  valuemask;
  XSetWindowAttributes  baseat;

		       /* Create all pixmaps for building menu item labels */
		       /* Menu Depth 0 */
  position = 0;

		       /* Common variables used with all menus */
  baseat.background_pixel = colours[0];
  baseat.border_pixel = colours[1];
  baseat.event_mask = ButtonPressMask | EnterWindowMask | ButtonReleaseMask |
                      LeaveWindowMask | OwnerGrabButtonMask;  /* No exposure */
  valuemask = CWBackPixel | CWBorderPixel | CWEventMask;

		       /* Create all windows used to make the menu bar */
  for (i=BOTTOM_0; i<TOP_0; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  0, position, BAR_WIDTH, BAR_HEIGHT, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  0, position, BAR_WIDTH, BAR_HEIGHT, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &baseat);
    position += BAR_HEIGHT;
    menuStore[i].visible = 1;  /* all menu-bar entries are visible */
    menuStore[i].depth = 0;    /* menu depth 0 */
    menuStore[i].parent = 0;   /* their parent is the baseW window (0) */
  }
		       /* Menu Depth 1 */
		       /* Create all File link menu label windows */
  menu_height = newC_height;
  menu_width = newC_width;
  position = 0;
  for (i=BOTTOM_1; i<17; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 1;    /* menu depth 1 */
    menuStore[i].parent = 0;   /* their parent is File [0] */
  }
		       /* Create all Edit link menu label windows */
  position = 0 + fileC_height;
  menu_width = undoC_width;
  for (i=17; i<23; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 1;    /* menu depth 1 */
    menuStore[i].parent = 1;   /* their parent is Edit [1] */
  }
                       /* Create all Citating link menu label windows */
  position = 0 + 2*fileC_height;
  menu_width = 103;
  for (i=23; i<27; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 1;    /* menu depth 1 */
    menuStore[i].parent = 2;   /* their parent is Citating [2] */
  }
                        /* Create all Use link menu label windows */
  position = 0 + 3*fileC_height;
  menu_width = 110;
  for (i=27; i<34; i++)  {  /* all the Search sub-menus */
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  99, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 1;    /* menu depth 1 */
    menuStore[i].parent = 3;   /* their parent is Search [3] */
  }
                        /* Create all Manage link menu label windows */
                        /* Create all Help link menu label windows */
 
        	        /* Menu Depth 2 */
                        /* Create all BibLatex A link menu label windows */
  position = 2*fileC_height;
  menu_width = 130;
  for (i=BOTTOM_2; i<64; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 2;    /* menu depth 2 */
    menuStore[i].parent = 23;   /* their parent is BibLatex A [23] */
  }
                        /* Create all BibLatex B link menu label windows */
  position = 2*fileC_height + biblatexAC_height;
  menu_width = 130;
  for (i=64; i<77; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 2;    /* menu depth 2 */
    menuStore[i].parent = 24;   /* their parent is BibLatex A [24] */
  }
                         /* Create all Aliases link menu label windows */
  position = 2*fileC_height + 2*biblatexAC_height;
  menu_width = 132;
  for (i=77; i<83; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 2;    /* menu depth 2 */
    menuStore[i].parent = 25;   /* their parent is Aliases [25] */
  }
                         /* Create all Extension link menu label windows */
  position = 2*fileC_height + 3*biblatexAC_height;
  menu_width = 130;
  for (i=83; i<99; i++)  {
    menuStore[i].normal = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    menuStore[i].selected = XCreateWindow(e6display, baseW,
                                  198, position, menu_width, menu_height, 1,
        			  depthDefault, InputOutput, visualDefault,
        			  valuemask, &baseat);
    position += menu_height;
    menuStore[i].visible = 0;  /* initially not visible */
    menuStore[i].depth = 2;    /* menu depth 2 */
    menuStore[i].parent = 26;   /* their parent is Extensions [26] */
  }
        	       /* Menu Depth 1 menu items */

		       /* File menubar label */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[0].normal,
                                 fileC_bits, fileC_width, fileC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[0].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[0].selected,
                                 fileC_bits, fileC_width, fileC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[0].selected, mould);

		       /* Edit menubar label */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[1].normal,
                                 editC_bits, editC_width, editC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[1].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[1].selected,
                                 editC_bits, editC_width, editC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[1].selected, mould);

		       /* Citating menubar label */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[2].normal,
                                 citationC_bits, citationC_width, citationC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[2].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[2].selected,
                                 citationC_bits, citationC_width, citationC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[2].selected, mould);

        	       /* Search menubar label */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[3].normal,
                                 searchC_bits, searchC_width, searchC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[3].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[3].selected,
                                 searchC_bits, searchC_width, searchC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[3].selected, mould);

        	       /* Manage menubar label */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[4].normal,
                                 manageC_bits, manageC_width, manageC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[4].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[4].selected,
                                 manageC_bits, manageC_width, manageC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[4].selected, mould);

        	       /* Help menubar label */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[5].normal,
                                 helpC_bits, helpC_width, helpC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[5].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[5].selected,
                                 helpC_bits, helpC_width, helpC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[5].selected, mould);

        	       /* Menu Depth 2 menu items */

       /* Buttons of the primary File pull-down menu */

        	       /* New button of File pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[10].normal,
                                 newC_bits, newC_width, newC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[10].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[10].selected,
                                 newC_bits, newC_width, newC_height,
 				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[10].selected, mould);

        	       /* Read File button of pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[11].normal,
                                 readC_bits, readC_width, readC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[11].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[11].selected,
                                 readC_bits, readC_width, readC_height,
				 colours[1], colours[4], depthDefault);
 XSetWindowBackgroundPixmap(e6display, menuStore[11].selected, mould);

        	       /* Append button of File pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[12].normal,
                                 appendC_bits, appendC_width, appendC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[12].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[12].selected,
                                 appendC_bits, appendC_width, appendC_height,
				 colours[1], colours[4], depthDefault);
 XSetWindowBackgroundPixmap(e6display, menuStore[12].selected, mould);

        	       /* Read button of File pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[13].normal,
                                 openC_bits, openC_width, openC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[13].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[13].selected,
                                 openC_bits, openC_width, openC_height,
				 colours[1], colours[6], depthDefault);
 XSetWindowBackgroundPixmap(e6display, menuStore[13].selected, mould);

        	       /* Close-in button of File pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[14].normal,
                                 closeinC_bits, closeinC_width, closeinC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[14].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[14].selected,
                                 closeinC_bits, closeinC_width, closeinC_height,
				 colours[1], colours[4], depthDefault);
 XSetWindowBackgroundPixmap(e6display, menuStore[14].selected, mould);

        	       /* Close-out button of File pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[15].normal,
                                 closeoutC_bits, closeoutC_width, closeoutC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[15].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[15].selected,
                                 closeoutC_bits, closeoutC_width, closeoutC_height,
				 colours[1], colours[4], depthDefault);
 XSetWindowBackgroundPixmap(e6display, menuStore[15].selected, mould);

        	       /* Quit button of File pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[16].normal,
                                 quitC_bits, quitC_width, quitC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[16].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[16].selected,
                                 quitC_bits, quitC_width, quitC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[16].selected, mould);

       /* Buttons of the primary Edit pull-down menu */

        	       /* Undo button of Edit pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[17].normal,
                                 undoC_bits, undoC_width, undoC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[17].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[17].selected,
                                 undoC_bits, undoC_width, undoC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[17].selected, mould);

        	       /* Copy button of Edit pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[18].normal,
                                 copyC_bits, copyC_width, copyC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[18].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[18].selected,
                                 copyC_bits, copyC_width, copyC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[18].selected, mould);

        	       /* Paste button of Edit pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[19].normal,
                                 pasteC_bits, pasteC_width, pasteC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[19].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[19].selected,
                                 pasteC_bits, pasteC_width, pasteC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[19].selected, mould);

        	       /* Clear button of Edit pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[20].normal,
                                 clearC_bits, clearC_width, clearC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[20].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[20].selected,
                                 clearC_bits, clearC_width, clearC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[20].selected, mould);

        	       /* Cut button of Edit pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[21].normal,
                                 cutC_bits, cutC_width, cutC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[21].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[21].selected,
                                 cutC_bits, cutC_width, cutC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[21].selected, mould);

        	       /* Remove button of Edit pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[22].normal,
                                 removeC_bits, removeC_width, removeC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[22].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[22].selected,
                                 removeC_bits, removeC_width, removeC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[22].selected, mould);

        /* Buttons of the primary Citating pull-down menu */

        	       /* BibLatex A button of Citating pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[23].normal,
                                 biblatexAC_bits, biblatexAC_width, biblatexAC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[23].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[23].selected,
                                 biblatexAC_bits, biblatexAC_width, biblatexAC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[23].selected, mould);

        	       /* BibLatex B button of Citating pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[24].normal,
                                 biblatexBC_bits, biblatexBC_width, biblatexBC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[24].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[24].selected,
                                 biblatexBC_bits, biblatexBC_width, biblatexBC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[24].selected, mould);

        	       /* Aliases button of Citating pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[25].normal,
                                 aliasesC_bits, aliasesC_width, aliasesC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[25].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[25].selected,
                                 aliasesC_bits, aliasesC_width, aliasesC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[25].selected, mould);

        	       /* Extensions button of Citating pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[26].normal,
                                 extensionsC_bits, extensionsC_width, extensionsC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[26].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[26].selected,
                                 extensionsC_bits, extensionsC_width, extensionsC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[26].selected, mould);

       /* Buttons of the primary Use pull-down menu */

        	       /* All button of Search pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[27].normal,
                                 showallC_bits, showallC_width, showallC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[27].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[27].selected,
                                 showallC_bits, showallC_width, showallC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[27].selected, mould);

        	       /* By author button of Search pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[28].normal,
                                 byauthorC_bits, byauthorC_width,
				 byauthorC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[28].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[28].selected,
                                 byauthorC_bits, byauthorC_width,
				 byauthorC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[28].selected, mould);

        	       /* By type button of Search pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[29].normal,
                                 bytypeC_bits, bytypeC_width, bytypeC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[29].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[29].selected,
                                 bytypeC_bits, bytypeC_width, bytypeC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[29].selected, mould);

        	       /* By date button of Search pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[30].normal,
                                 bydateC_bits, bydateC_width, bydateC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[30].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[30].selected,
                                 bydateC_bits, bydateC_width, bydateC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[30].selected, mould); 

        	       /* By word button of Search pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[31].normal,
                                 bywordC_bits, bywordC_width, bywordC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[31].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[31].selected,
                                 bywordC_bits, bywordC_width, bywordC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[31].selected, mould); 

        	       /* By xref button of Search pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[32].normal,
                                 byxrefC_bits, byxrefC_width, byxrefC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[32].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[32].selected,
                                 byxrefC_bits, byxrefC_width, byxrefC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[32].selected, mould); 

        	       /* By keyword button of Search pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[33].normal,
                                 bykeyC_bits, bykeyC_width, bykeyC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[33].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[33].selected,
                                 bykeyC_bits, bykeyC_width, bykeyC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[33].selected, mould); 

        	       /* Menu Depth 3 menu items */

        	       /* Article button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[50].normal,
                                 articleC_bits, articleC_width, articleC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[50].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[50].selected,
                                 articleC_bits, articleC_width, articleC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[50].selected, mould);

        	       /* Book button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[51].normal,
                                 bookC_bits, bookC_width, bookC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[51].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[51].selected,
                                 bookC_bits, bookC_width, bookC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[51].selected, mould);

        	       /* mv Book button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[52].normal,
                                 mvbookC_bits, mvbookC_width, mvbookC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[52].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[52].selected,
                                 mvbookC_bits, mvbookC_width, mvbookC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[52].selected, mould);

        	       /* Book in Book button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[53].normal,
                                 bookinbookC_bits, bookinbookC_width, bookinbookC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[53].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[53].selected,
                                 bookinbookC_bits, bookinbookC_width, bookinbookC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[53].selected, mould);

        	       /* Booklet button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[54].normal,
                                 bookletC_bits, bookletC_width, bookletC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[54].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[54].selected,
                                 bookletC_bits, bookletC_width, bookletC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[54].selected, mould);

        	       /* Collection button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[55].normal,
                                 collectionC_bits, collectionC_width, collectionC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[55].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[55].selected,
                                 collectionC_bits, collectionC_width, collectionC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[55].selected, mould);

        	       /* mv Collection button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[56].normal,
                                 mvcollectionC_bits, mvcollectionC_width,
				 mvcollectionC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[56].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[56].selected,
                                 mvcollectionC_bits, mvcollectionC_width,
				 mvcollectionC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[56].selected, mould);

        	       /* supp Collection button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[57].normal,
                                 suppcollectionC_bits, suppcollectionC_width,
				 suppcollectionC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[57].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[57].selected,
                                 suppcollectionC_bits, suppcollectionC_width,
				 suppcollectionC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[57].selected, mould);

        	       /* Inbook button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[58].normal,
                                 inbookC_bits, inbookC_width, inbookC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[58].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[58].selected,
                                 inbookC_bits, inbookC_width, inbookC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[58].selected, mould);

        	       /* supp Book button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[59].normal,
                                 suppbookC_bits, suppbookC_width, suppbookC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[59].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[59].selected,
                                 suppbookC_bits, suppbookC_width, suppbookC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[59].selected, mould);

        	       /* Incollection button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[60].normal,
                                 incollectionC_bits, incollectionC_width,
				 incollectionC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[60].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[60].selected,
                                 incollectionC_bits, incollectionC_width,
				 incollectionC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[60].selected, mould);

        	       /* Inproceedings button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[61].normal,
                                 inproceedingsC_bits, inproceedingsC_width,
				 inproceedingsC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[61].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[61].selected,
                                 inproceedingsC_bits, inproceedingsC_width,
				 inproceedingsC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[61].selected, mould);

        	       /* Inreference button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[62].normal,
                                 inreferenceC_bits, inreferenceC_width,
				 inreferenceC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[62].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[62].selected,
                                 inreferenceC_bits, inreferenceC_width,
				 inreferenceC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[62].selected, mould);

        	       /* Manual button of BibLatex A pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[63].normal,
                                 manualC_bits, manualC_width, manualC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[63].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[63].selected,
                                 manualC_bits, manualC_width, manualC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[63].selected, mould);

        	       /* Misc button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[64].normal,
                                 miscC_bits, miscC_width, miscC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[64].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[64].selected,
                                 miscC_bits, miscC_width, miscC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[64].selected, mould);

        	       /* Online button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[65].normal,
                                 onlineC_bits, onlineC_width, onlineC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[65].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[65].selected,
                                 onlineC_bits, onlineC_width, onlineC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[65].selected, mould);

        		       /* Patent button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[66].normal,
                                 patentC_bits, patentC_width, patentC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[66].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[66].selected,
                                 patentC_bits, patentC_width, patentC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[66].selected, mould);

       		     /* Periodical button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[67].normal,
                                 periodicalC_bits, periodicalC_width, periodicalC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[67].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[67].selected,
                                 periodicalC_bits, periodicalC_width, periodicalC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[67].selected, mould);

       		 /*supp Periodical button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[68].normal,
                                 suppperiodicalC_bits, suppperiodicalC_width,
				 suppperiodicalC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[68].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[68].selected,
                                 suppperiodicalC_bits, suppperiodicalC_width,
				 suppperiodicalC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[68].selected, mould);

        	       /* Proceedings button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[69].normal,
                                 proceedingsC_bits, proceedingsC_width,
				 proceedingsC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[69].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[69].selected,
                                 proceedingsC_bits, proceedingsC_width,
				 proceedingsC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[69].selected, mould);

        	       /*mv Proceedings button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[70].normal,
                                 mvproceedingsC_bits, mvproceedingsC_width,
				 mvproceedingsC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[70].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[70].selected,
                                 mvproceedingsC_bits, mvproceedingsC_width,
				 mvproceedingsC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[70].selected, mould);

        	       /* Reference button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[71].normal,
                                 referenceC_bits, referenceC_width,
				 referenceC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[71].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[71].selected,
                                 referenceC_bits, referenceC_width,
				 referenceC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[71].selected, mould);

        	       /*mv Reference button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[72].normal,
                                 mvreferenceC_bits, mvreferenceC_width,
				 mvreferenceC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[72].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[72].selected,
                                 mvreferenceC_bits, mvreferenceC_width,
				 mvreferenceC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[72].selected, mould);

        		       /* Report button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[73].normal,
                                 reportC_bits, reportC_width,
				 reportC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[73].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[73].selected,
                                 reportC_bits, reportC_width,
				 reportC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[73].selected, mould);

        		       /* Set button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[74].normal,
                                 setC_bits, setC_width, setC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[74].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[74].selected,
                                 setC_bits, setC_width, setC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[74].selected, mould);

        		       /* Thesis button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[75].normal,
                                 thesisC_bits, thesisC_width, thesisC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[75].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[75].selected,
                                 thesisC_bits, thesisC_width, thesisC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[75].selected, mould);

        	       /* Unpublished button of BibLatex B pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[76].normal,
                                 unpublishedC_bits, unpublishedC_width,
				 unpublishedC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[76].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[76].selected,
                                 unpublishedC_bits, unpublishedC_width,
				 unpublishedC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[76].selected, mould); 

        	       /* Conference button of Aliases pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[77].normal,
                                 conferenceC_bits, conferenceC_width,
				 conferenceC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[77].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[77].selected,
                                 conferenceC_bits, conferenceC_width,
				 conferenceC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[77].selected, mould);

        	       /* Electronic button of Aliases pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[78].normal,
                                 electronicC_bits, electronicC_width,
				 electronicC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[78].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[78].selected,
                                 electronicC_bits, electronicC_width,
				 electronicC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[78].selected, mould); 

               /* Masters Thesis button of Aliases pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[79].normal,
                                 mastersthesisC_bits, mastersthesisC_width,
				 mastersthesisC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[79].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[79].selected,
                                 mastersthesisC_bits, mastersthesisC_width,
				 mastersthesisC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[79].selected, mould); 

        	       /* PhD thesis button of Aliases pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[80].normal,
                                 phdthesisC_bits, phdthesisC_width,
				 phdthesisC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[80].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[80].selected,
                                 phdthesisC_bits, phdthesisC_width,
				 phdthesisC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[80].selected, mould); 

        	       /* Tech Report button of Aliases pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[81].normal,
                                 techreportC_bits, techreportC_width,
				 techreportC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[81].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[81].selected,
                                 techreportC_bits, techreportC_width,
				 techreportC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[81].selected, mould); 

        	       /* Web resource button of Aliases pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[82].normal,
                                 wwwC_bits, wwwC_width, wwwC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[82].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[82].selected,
                                 wwwC_bits, wwwC_width, wwwC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[82].selected, mould); 

        	       /* Artwork button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[83].normal,
                                 artworkC_bits, artworkC_width, artworkC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[83].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[83].selected,
                                 artworkC_bits, artworkC_width, artworkC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[83].selected, mould); 

        	       /* Audio button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[84].normal,
                                 audioC_bits, audioC_width, audioC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[84].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[84].selected,
                                 audioC_bits, audioC_width, audioC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[84].selected, mould); 

        	       /* Bibnote button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[85].normal,
                                 bibnoteC_bits, bibnoteC_width, bibnoteC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[85].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[85].selected,
                                 bibnoteC_bits, bibnoteC_width, bibnoteC_height,
				 colours[1], colours[6], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[85].selected, mould); 

        	       /* Jurisdiction button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[86].normal,
                                 jurisdictionC_bits, jurisdictionC_width,
				 jurisdictionC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[86].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[86].selected,
                                 jurisdictionC_bits, jurisdictionC_width,
				 jurisdictionC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[86].selected, mould); 

        	       /* Image button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[87].normal,
                                 imageC_bits, imageC_width, imageC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[87].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[87].selected,
                                 imageC_bits, imageC_width, imageC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[87].selected, mould); 

        	       /* Jurisdiction button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[88].normal,
                                 jurisdictionC_bits, jurisdictionC_width,
				 jurisdictionC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[88].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[88].selected,
                                 jurisdictionC_bits, jurisdictionC_width,
				 jurisdictionC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[88].selected, mould); 

        	       /* Legislation button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[88].normal,
                                 legislationC_bits, legislationC_width,
				 legislationC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[88].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[88].selected,
                                 legislationC_bits, legislationC_width,
				 legislationC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[88].selected, mould); 

        	       /* Legal button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[89].normal,
                                 legalC_bits, legalC_width, legalC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[89].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[89].selected,
                                 legalC_bits, legalC_width, legalC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[89].selected, mould); 

        	       /* Letter button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[90].normal,
                                 letterC_bits, letterC_width, letterC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[90].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[90].selected,
                                 letterC_bits, letterC_width, letterC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[90].selected, mould); 

        	       /* Movie button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[91].normal,
                                 movieC_bits, movieC_width, movieC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[91].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[91].selected,
                                 movieC_bits, movieC_width, movieC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[91].selected, mould); 

        	       /* Music button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[92].normal,
                                 musicC_bits, musicC_width, musicC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[92].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[92].selected,
                                 musicC_bits, musicC_width, musicC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[92].selected, mould); 

        	       /* Performance button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[93].normal,
                                 performanceC_bits, performanceC_width,
				 performanceC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[93].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[93].selected,
                                 performanceC_bits, performanceC_width,
				 performanceC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[93].selected, mould); 

        	       /* Review button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[94].normal,
                                 reviewC_bits, reviewC_width, reviewC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[94].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[94].selected,
                                 reviewC_bits, reviewC_width, reviewC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[94].selected, mould); 

        	       /* Software button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[95].normal,
                                 softwareC_bits, softwareC_width, softwareC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[95].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[95].selected,
                                 softwareC_bits, softwareC_width, softwareC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[95].selected, mould); 

        	       /* Standard button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[96].normal,
                                 standardC_bits, standardC_width, standardC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[96].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[96].selected,
                                 standardC_bits, standardC_width, standardC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[96].selected, mould); 

        	       /* Video button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[97].normal,
                                 videoC_bits, videoC_width, videoC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[97].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[97].selected,
                                 videoC_bits, videoC_width, videoC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[97].selected, mould); 


        	       /* Database button of Unsupported pull-down menu */
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[98].normal,
                                 databaseC_bits, databaseC_width, databaseC_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[98].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, menuStore[98].selected,
                                 databaseC_bits, databaseC_width, databaseC_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, menuStore[98].selected, mould); 

  return(1);
}
