/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains functions which produce and handle common window parts
 *  used to collect and display information related to different reference
 *  types.  This includes labelling windows, data input windows, and button
 *  windows.
 *
 *  Coded by:       Ross Maloney
 *  April 2012:     Initial code
 *  December 2012:  Place changes
 *  January 2013:   Search result windows added
 *  July 2014:      Forming of scratchpad note module
 *  September 2014  SingleLine variable added
 *  June 2018       Note/annotation switch over
 *  July 2020       Put window attributes into each procedure
 *  March 2022      Database type added
 */


#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"
#include  "../composites/largeO.xbm"
#include  "../composites/largeO1.xbm"
#include  "../composites/eprintO.xbm"
#include  "../composites/editorabcO.xbm"
//#include  "../composites/vnpsiO1.xbm"
//#include  "../composites/vnpsiO2.xbm"
#include  "../composites/issO.xbm"
#include  "../composites/mainO.xbm"
#include  "../composites/origO.xbm"
#include  "../composites/keysO.xbm"
#include  "../composites/wordsO.xbm"
#include  "../composites/eventO.xbm"

#include  "../composites/bookR.xbm"
#include  "../composites/suppbookR.xbm"
#include  "../composites/articleR.xbm"
#include  "../composites/onlineR.xbm"
#include  "../composites/thesisR.xbm"
#include  "../composites/reportR.xbm"
#include  "../composites/inprocedR.xbm"
#include  "../composites/incolR.xbm"
#include  "../composites/proceedingsR.xbm"
#include  "../composites/collectionR.xbm"
#include  "../composites/suppcollR.xbm"
#include  "../composites/bookletR.xbm"
#include  "../composites/manualR.xbm"
#include  "../composites/miscellaneousR.xbm"
#include  "../composites/unpublishedR.xbm"
#include  "../composites/periodicalR.xbm"
#include  "../composites/referenceR.xbm"
#include  "../composites/mvreferenceR.xbm"
#include  "../composites/inrefR.xbm"
#include  "../composites/inbookR.xbm"
#include  "../composites/bookinbookR.xbm"
#include  "../composites/suppperiodR.xbm"
#include  "../composites/mvbookR.xbm"
#include  "../composites/mvcolR.xbm"
#include  "../composites/mvprocedR.xbm"
#include  "../composites/patentR.xbm"
#include  "../composites/scratchpad.xbm"
#include  "../composites/artworkR.xbm"
#include  "../composites/audioR.xbm"
//#include  "../composites/commentaryR.xbm"
#include  "../composites/jurisdictionR.xbm"
#include  "../composites/imageR.xbm"
#include  "../composites/legislationR.xbm"
#include  "../composites/legalR.xbm"
#include  "../composites/letterR.xbm"
#include  "../composites/movieR.xbm"
#include  "../composites/musicR.xbm"
#include  "../composites/performanceR.xbm"
#include  "../composites/reviewR.xbm"
#include  "../composites/softwareR.xbm"
#include  "../composites/standardR.xbm"
#include  "../composites/videoR.xbm"
#include  "../composites/databaseR.xbm"

#include  "../composites/saveB.xbm"
#include  "../composites/doitB.xbm"
#include  "../composites/cancelB.xbm"
#include  "../composites/minorsB.xbm"
#include  "../composites/doB.xbm"
#include  "../composites/okB.xbm"
#include  "../composites/clearB.xbm"

#include  "../composites/citall.xbm"
#include  "../composites/citauthor.xbm"
#include  "../composites/cittype.xbm"
#include  "../composites/citdate.xbm"
#include  "../composites/citword.xbm"



void  windowModules()
{
  Pixmap     mould;
  XSetWindowAttributes  activeat, frameat;
  unsigned long  opmask;
  unsigned long  valuemask;
  
  activeat.background_pixel = colours[0];
  activeat.border_pixel = colours[1];
  opmask = CWBackPixel | CWBorderPixel;
  frameat.background_pixmap = colours[8];
  frameat.border_pixel = colours[1];
  valuemask = CWBackPixel | CWBorderPixel;

                 /* Option 'largeO' module */

  moduleStore[0].id = XCreateWindow(e6display, secondsW,
		               215, 700, largeO_width, largeO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[0].id,
			       largeO_bits, largeO_width,
			       largeO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[0].id, mould);

                 /* Option 'eprintO' module */

  moduleStore[1].id = XCreateWindow(e6display, secondsW,
                               290, 200, eprintO_width, eprintO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[1].id,
			       eprintO_bits, eprintO_width,
			       eprintO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[1].id, mould);

                 /* Option 'editorabcO' module */

  moduleStore[2].id = XCreateWindow(e6display, secondsW,
                               290, 440, editorabcO_width, editorabcO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[2].id,
			       editorabcO_bits, editorabcO_width,
			       editorabcO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[2].id, mould);

                 /* Option 'vnpsiO1' module */

  moduleStore[3].id = moduleStore[2].id;    /* dummy id */

                 /* Option 'issO' module */

  moduleStore[4].id = XCreateWindow(e6display, secondsW,
                               292, 130, issO_width, issO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[4].id,
			       issO_bits, issO_width,
			       issO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[4].id, mould);

                 /* Option 'mainO' module */

  moduleStore[5].id = XCreateWindow(e6display, secondsW,
                               290, 575, mainO_width, mainO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[5].id,
			       mainO_bits, mainO_width,
			       mainO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[5].id, mould);

                 /* Option 'origO' module */

  moduleStore[6].id = XCreateWindow(e6display, secondsW,
                               290, 645, origO_width, origO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[6].id,
			       origO_bits, origO_width,
			       origO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[6].id, mould);

                 /* Option 'largeO' module */

  moduleStore[7].id = XCreateWindow(e6display, secondsW,
		               290, 130, largeO1_width, largeO1_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[0].id,
			       largeO1_bits, largeO1_width,
			       largeO1_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[7].id, mould);

                 /* Option 'keysO' module */

  moduleStore[8].id = XCreateWindow(e6display, baseW,
		               290, 200, keysO_width, keysO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[0].id,
			       keysO_bits, keysO_width,
			       keysO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[8].id, mould);


                 /* Option 'wordsO' module */

  moduleStore[9].id = XCreateWindow(e6display, secondsW,
		               340, 270, wordsO_width, wordsO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[0].id,
			       wordsO_bits, wordsO_width,
			       keysO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[9].id, mould);


                 /* Option 'eventO' module */

  moduleStore[10].id = XCreateWindow(e6display, secondsW,
		               290, 130, eventO_width, eventO_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[0].id,
			       eventO_bits, eventO_width,
			       keysO_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[10].id, mould);

                 /* Lead 'book' module */

  moduleStore[20].id = XCreateWindow(e6display, baseW,
                               340, 0, bookR_width, bookR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[20].id,
			       bookR_bits, bookR_width,
			       bookR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[20].id, mould);

                 /* Lead 'article' module */

  moduleStore[21].id = XCreateWindow(e6display, baseW,
                               340, 0, articleR_width, articleR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[21].id,
			       articleR_bits, articleR_width,
			       articleR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[21].id, mould);

                 /* Lead 'online' module */

  moduleStore[22].id = XCreateWindow(e6display, baseW,
                               340, 0, onlineR_width, onlineR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[22].id,
			       onlineR_bits, onlineR_width,
			       onlineR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[22].id, mould);

                 /* Lead 'thesis' module */

  moduleStore[23].id = XCreateWindow(e6display, baseW,
                               340, 0, thesisR_width, thesisR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[23].id,
			       thesisR_bits, thesisR_width,
			       thesisR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[23].id, mould);

                 /* Lead 'report' module */

  moduleStore[24].id = XCreateWindow(e6display, baseW,
                               340, 0, reportR_width, reportR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[24].id,
			       reportR_bits, reportR_width,
			       reportR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[24].id, mould);

                 /* Lead 'in proceedings' module */

  moduleStore[25].id = XCreateWindow(e6display, baseW,
                               340, 0, inprocedR_width, inprocedR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[25].id,
			       inprocedR_bits, inprocedR_width,
			       inprocedR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[25].id, mould);

                 /* Lead 'in collection' module */

  moduleStore[26].id = XCreateWindow(e6display, baseW,
                               340, 0, incolR_width, incolR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[26].id,
			       incolR_bits, incolR_width,
			       incolR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[26].id, mould);

                 /* Lead 'proceedings' module */

  moduleStore[27].id = XCreateWindow(e6display, baseW,
                               340, 0, proceedingsR_width,
			       proceedingsR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[27].id,
			       proceedingsR_bits, proceedingsR_width,
			       proceedingsR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[27].id, mould);

                 /* Lead 'collection' module */

  moduleStore[28].id = XCreateWindow(e6display, baseW,
                               340, 0, collectionR_width,
			       collectionR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[28].id,
			       collectionR_bits, collectionR_width,
			       collectionR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[28].id, mould);

                 /* Lead 'booklet' module */

  moduleStore[29].id = XCreateWindow(e6display, baseW,
                               340, 0, bookletR_width,
			       bookletR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[29].id,
			       bookletR_bits, bookletR_width,
			       bookletR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[29].id, mould);

                 /* Lead 'manual' module */

  moduleStore[30].id = XCreateWindow(e6display, baseW,
                               340, 0, manualR_width,
			       manualR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[30].id,
			       manualR_bits, manualR_width,
			       manualR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[30].id, mould);

                 /* Lead 'miscellaneous' module */

  moduleStore[31].id = XCreateWindow(e6display, baseW,
                               340, 0, miscellaneousR_width,
			       miscellaneousR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[31].id,
			       miscellaneousR_bits, miscellaneousR_width,
			       miscellaneousR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[31].id, mould);

                 /* Lead 'unpublished' module */

  moduleStore[32].id = XCreateWindow(e6display, baseW,
                               340, 0, unpublishedR_width,
			       unpublishedR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[32].id,
			       unpublishedR_bits, unpublishedR_width,
			       unpublishedR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[32].id, mould);

                 /* Lead 'periodical' module */

  moduleStore[33].id = XCreateWindow(e6display, baseW,
                               340, 0, periodicalR_width,
			       periodicalR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[33].id,
			       periodicalR_bits, periodicalR_width,
			       periodicalR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[33].id, mould);

                 /* Lead 'reference' module */

  moduleStore[34].id = XCreateWindow(e6display, baseW,
                               340, 0, referenceR_width,
			       referenceR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[34].id,
			       referenceR_bits, referenceR_width,
			       referenceR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[34].id, mould);

                 /* Lead 'in reference' module */

  moduleStore[35].id = XCreateWindow(e6display, baseW,
                               340, 0, inrefR_width,
			       inrefR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[35].id,
			       inrefR_bits, inrefR_width,
			       inrefR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[35].id, mould);

                 /* 'All Citations present' label */

  moduleStore[36].id = XCreateWindow(e6display, baseW,
                               0, 0, citall_width,
			       citall_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[36].id,
			       citall_bits, citall_width,
			       citall_height, colours[1], colours[8],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[36].id, mould);


                 /* 'By type Citations present' label */

  moduleStore[37].id = XCreateWindow(e6display, baseW,
                               0, 0, cittype_width,
			       cittype_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[37].id,
			       cittype_bits, cittype_width,
			       cittype_height, colours[1], colours[8],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[37].id, mould);

                 /* 'By date/year Citations present' label */

  moduleStore[38].id = XCreateWindow(e6display, baseW,
                               0, 0, citdate_width,
			       citdate_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[38].id,
			       citdate_bits, citdate_width,
			       citdate_height, colours[1], colours[8],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[38].id, mould);

                 /* 'By author/editor Citations present' label */

  moduleStore[39].id = XCreateWindow(e6display, baseW,
                               0, 0, citauthor_width,
			       citauthor_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[39].id,
			       citauthor_bits, citauthor_width,
			       citauthor_height, colours[1], colours[8],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[39].id, mould);

                 /* 'By word Citations present' label */

  moduleStore[40].id = XCreateWindow(e6display, baseW,
                               0, 0, citword_width,
			       citword_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[40].id,
			       citword_bits, citword_width,
			       citword_height, colours[1], colours[8],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[40].id, mould);

                 /* Lead 'in book' module */

  moduleStore[41].id = XCreateWindow(e6display, baseW,
                               340, 0, inbookR_width,
			       inbookR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[41].id,
			       inbookR_bits, inbookR_width,
			       inbookR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[41].id, mould);

                 /* Lead 'multi-volume book' module */

  moduleStore[42].id = XCreateWindow(e6display, baseW,
                               340, 0, mvbookR_width,
			       mvbookR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[42].id,
			       mvbookR_bits, mvbookR_width,
			       mvbookR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[42].id, mould);

                 /* Lead 'multi-volume collection' module */

  moduleStore[43].id = XCreateWindow(e6display, baseW,
                               340, 0, mvcolR_width,
			       mvcolR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[43].id,
			       mvcolR_bits, mvcolR_width,
			       mvcolR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[43].id, mould);

                 /* Lead 'multi-volume proceedings' module */

  moduleStore[44].id = XCreateWindow(e6display, baseW,
                               340, 0, mvprocedR_width,
			       mvprocedR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[44].id,
			       mvprocedR_bits, mvprocedR_width,
			       mvprocedR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[44].id, mould);

                 /* Lead 'patent' module */

  moduleStore[45].id = XCreateWindow(e6display, baseW,
                               340, 0, patentR_width,
			       patentR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[45].id,
			       patentR_bits, patentR_width,
			       patentR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[45].id, mould);

                 /* Option 'scratchpad' module */

  moduleStore[46].id = XCreateWindow(e6display, baseW,
		               290, 200, scratchpad_width, scratchpad_height,XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[46].id,
			       scratchpad_bits, scratchpad_width,
			       scratchpad_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[46].id, mould);

                 /* Lead 'bookinbook' module */

  moduleStore[47].id = XCreateWindow(e6display, baseW,
                               340, 0, bookinbookR_width,
			       bookinbookR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[47].id,
			       bookinbookR_bits, bookinbookR_width,
			       bookinbookR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[47].id, mould);

                 /* Lead 'supplemental collection' module */

  moduleStore[48].id = XCreateWindow(e6display, baseW,
                               340, 0, suppcollR_width,
			       suppcollR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[48].id,
			       suppcollR_bits, suppcollR_width,
			       suppcollR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[48].id, mould);


                 /* Lead 'supplemental book' module */

  moduleStore[49].id = XCreateWindow(e6display, baseW,
                               340, 0, suppbookR_width,
			       suppbookR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[49].id,
			       suppbookR_bits, suppbookR_width,
			       suppbookR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[49].id, mould);


                 /* Lead 'supplemental periodical' module */

  moduleStore[50].id = XCreateWindow(e6display, baseW,
                               340, 0, suppperiodR_width,
			       suppperiodR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[50].id,
			       suppperiodR_bits, suppperiodR_width,
			       suppperiodR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[50].id, mould);


                 /* Lead 'multi-volume reference' module */

  moduleStore[51].id = XCreateWindow(e6display, baseW,
                               340, 0, mvreferenceR_width,
			       mvreferenceR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[51].id,
			       mvreferenceR_bits, mvreferenceR_width,
			       mvreferenceR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[51].id, mould);

  
                 /* Lead 'artwork' module */

  moduleStore[52].id = XCreateWindow(e6display, baseW,
                               340, 0, artworkR_width,
			       artworkR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[52].id,
			       artworkR_bits, artworkR_width,
			       artworkR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[52].id, mould);

  
                 /* Lead 'audio' module */

  moduleStore[53].id = XCreateWindow(e6display, baseW,
                               340, 0, audioR_width,
			       audioR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[53].id,
			       audioR_bits, audioR_width,
			       audioR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[53].id, mould);


                 /* Lead 'jurisdiction' module */

  moduleStore[55].id = XCreateWindow(e6display, baseW,
                               340, 0, jurisdictionR_width,
			       jurisdictionR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[55].id,
			       jurisdictionR_bits, jurisdictionR_width,
			       jurisdictionR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[55].id, mould);
  

                 /* Lead 'image' module */

  moduleStore[56].id = XCreateWindow(e6display, baseW,
                               340, 0, imageR_width,
			       imageR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[56].id,
			       imageR_bits, imageR_width,
			       imageR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[56].id, mould);
  

                 /* Lead 'legislation' module */

  moduleStore[57].id = XCreateWindow(e6display, baseW,
                               340, 0, legislationR_width,
			       legislationR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[57].id,
			       legislationR_bits, legislationR_width,
			       legislationR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[57].id, mould);


                 /* Lead 'legal' module */

  moduleStore[58].id = XCreateWindow(e6display, baseW,
                               340, 0, legalR_width,
			       legalR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[58].id,
			       legalR_bits, legalR_width,
			       legalR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[58].id, mould);


                 /* Lead 'letter' module */

  moduleStore[59].id = XCreateWindow(e6display, baseW,
                               340, 0, letterR_width,
			       letterR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[59].id,
			       letterR_bits, letterR_width,
			       letterR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[59].id, mould);

 
                 /* Lead 'movie' module */

  moduleStore[60].id = XCreateWindow(e6display, baseW,
                               340, 0, movieR_width,
			       movieR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[60].id,
			       movieR_bits, movieR_width,
			       movieR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[60].id, mould);

 
                 /* Lead 'music' module */

  moduleStore[61].id = XCreateWindow(e6display, baseW,
                               340, 0, musicR_width,
			       musicR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[61].id,
			       musicR_bits, musicR_width,
			       musicR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[61].id, mould);

 
                 /* Lead 'performance' module */

  moduleStore[62].id = XCreateWindow(e6display, baseW,
                               340, 0, performanceR_width,
			       performanceR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[62].id,
			       performanceR_bits, performanceR_width,
			       performanceR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[62].id, mould);

 
                 /* Lead 'review' module */

  moduleStore[63].id = XCreateWindow(e6display, baseW,
                               340, 0, reviewR_width,
			       reviewR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[63].id,
			       reviewR_bits, reviewR_width,
			       reviewR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[63].id, mould);
  

 
                 /* Lead 'software' module */

  moduleStore[64].id = XCreateWindow(e6display, baseW,
                               340, 0, softwareR_width,
			       softwareR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[64].id,
			       softwareR_bits, softwareR_width,
			       softwareR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[64].id, mould);


                 /* Lead 'standard' module */

  moduleStore[65].id = XCreateWindow(e6display, baseW,
                               340, 0, standardR_width,
			       standardR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[65].id,
			       standardR_bits, standardR_width,
			       standardR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[65].id, mould);


                 /* Lead 'video' module */

  moduleStore[66].id = XCreateWindow(e6display, baseW,
                               340, 0, videoR_width,
			       videoR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[66].id,
			       videoR_bits, videoR_width,
			       videoR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[66].id, mould); 
  
/*  moduleStore[66].id = XCreateWindow(e6display, baseW,
                               340, 0, databaseR_width,
			       databaseR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[66].id,
			       databaseR_bits, databaseR_width,
			       databaseR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[66].id, mould); */
 
                 /* Lead 'database' module */

  moduleStore[67].id = XCreateWindow(e6display, baseW,
                               340, 0, databaseR_width,
			       databaseR_height, XX,
			       depthDefault, InputOutput, visualDefault,
			       valuemask, &frameat);
  mould = XCreatePixmapFromBitmapData(e6display, moduleStore[67].id,
			       databaseR_bits, databaseR_width,
			       databaseR_height, colours[1], colours[7],
			       depthDefault);
  XSetWindowBackgroundPixmap(e6display, moduleStore[67].id, mould);
   
		       /* Buttons */

		       /* 'save' button */

  activeat.event_mask = EnterWindowMask | LeaveWindowMask | ButtonReleaseMask;
  valuemask = CWBackPixel | CWBorderPixel | CWEventMask ;
  buttonStore[0].normal = XCreateWindow(e6display, windowStore[3],
                                  0, 0, saveB_width, saveB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[0].selected = XCreateWindow(e6display, windowStore[3],
                                  0, 0, saveB_width, saveB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[0].normal,
                                 saveB_bits, saveB_width, saveB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[0].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[0].selected,
                                 saveB_bits, saveB_width, saveB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[0].selected, mould);

		       /* 'do it' button */

  buttonStore[1].normal = XCreateWindow(e6display, windowStore[3],
                                  87, 0, doitB_width, doitB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[1].selected = XCreateWindow(e6display, windowStore[3],
                                  87, 0, doitB_width, doitB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[1].normal,
                                 doitB_bits, doitB_width, doitB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[1].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[1].selected,
                                 doitB_bits, doitB_width, doitB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[1].selected, mould);

		       /* 'cancel' button */

  buttonStore[2].normal = XCreateWindow(e6display, windowStore[3],
                                  174, 0, cancelB_width, cancelB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[2].selected = XCreateWindow(e6display, windowStore[3],
                                  174, 0, cancelB_width, cancelB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[2].normal,
                                 cancelB_bits, cancelB_width, cancelB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[2].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[2].selected,
                                 cancelB_bits, cancelB_width, cancelB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[2].selected, mould);

		       /* 'do' button */

  buttonStore[3].normal = XCreateWindow(e6display, baseW,
                                  20, 260, doB_width, doB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[3].selected = XCreateWindow(e6display, baseW,
                                  20, 260, doB_width, doB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[3].normal,
                                 doB_bits, doB_width, doB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[3].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[3].selected,
                                 doB_bits, doB_width, doB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[3].selected, mould);

		       /* 'ok' button */

  buttonStore[4].normal = XCreateWindow(e6display, windowStore[4],
                                  90, 110, okB_width, okB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[4].selected = XCreateWindow(e6display, windowStore[4],
                                  90, 110, okB_width, okB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[4].normal,
                                 okB_bits, okB_width, okB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[4].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[4].selected,
                                 okB_bits, okB_width, okB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[4].selected, mould);

		       /* 'cancel' button accompaning 'do' button */

  buttonStore[5].normal = XCreateWindow(e6display, baseW,
                                  120, 260, cancelB_width, cancelB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[5].selected = XCreateWindow(e6display, baseW,
                                  120, 260, cancelB_width, cancelB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[5].normal,
                                 cancelB_bits, cancelB_width, cancelB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[5].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[5].selected,
                                 cancelB_bits, cancelB_width, cancelB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[5].selected, mould); 

		       /* 'clear' button associated with displaying citations */

  buttonStore[6].normal = XCreateWindow(e6display, windowStore[10],
                                  0, 0, clearB_width, clearB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[6].selected = XCreateWindow(e6display, windowStore[10],
                                  0, 0, clearB_width, clearB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[6].normal,
                                 clearB_bits, clearB_width, clearB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[6].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[6].selected,
                                 clearB_bits, clearB_width, clearB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[6].selected, mould);

		       /* 'minor' button */

  buttonStore[7].normal = XCreateWindow(e6display, windowStore[3],
                                  0, 31, minorsB_width, minorsB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[7].selected = XCreateWindow(e6display, windowStore[3],
                                  0, 31, minorsB_width, minorsB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[7].normal,
                                 minorsB_bits, minorsB_width, minorsB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[7].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[7].selected,
                                 minorsB_bits, minorsB_width, minorsB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[7].selected, mould);

		       /* 'do it' button accompaning 'minor' button */

  buttonStore[8].normal = XCreateWindow(e6display, windowStore[3],
                                  87, 31, doitB_width, doitB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[8].selected = XCreateWindow(e6display, windowStore[3],
                                  87, 31, doitB_width, doitB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[8].normal,
                                 doitB_bits, doitB_width, doitB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[8].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[8].selected,
                                 doitB_bits, doitB_width, doitB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[8].selected, mould);


		       /* 'cancel' button accompaning 'minor' button */

  buttonStore[9].normal = XCreateWindow(e6display, windowStore[3],
                                  174, 31, cancelB_width, cancelB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  buttonStore[9].selected = XCreateWindow(e6display, windowStore[3],
                                  174, 31, cancelB_width, cancelB_height, 1,
				  depthDefault, InputOutput, visualDefault,
				  valuemask, &activeat);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[9].normal,
                                 cancelB_bits, cancelB_width, cancelB_height,
				 colours[1], colours[5], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[9].normal, mould);
  mould = XCreatePixmapFromBitmapData(e6display, buttonStore[9].selected,
                                 cancelB_bits, cancelB_width, cancelB_height,
				 colours[1], colours[4], depthDefault);
  XSetWindowBackgroundPixmap(e6display, buttonStore[9].selected, mould);
}


void  iowindows()
{
  XSetWindowAttributes  dataat;
  unsigned long  opmask;

  dataat.background_pixel = colours[0];
  dataat.border_pixel = colours[4];
  dataat.event_mask = EnterWindowMask | LeaveWindowMask | KeyPressMask |
                      ButtonReleaseMask | ExposureMask;
  opmask = CWBackPixel | CWBorderPixel | CWEventMask;

              /* All the following windows contain REQUIRED data only */

                 /* year/date window */  /* changed to date window */

  dataStore[0].id = XCreateWindow(e6display, baseW,
                               930, 78, charinc*DA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[0].array = date;
  dataStore[0].size = DA;

                 /* title window */

  dataStore[1].id = XCreateWindow(e6display, baseW,
                               200, 78, charinc*TI, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[1].array = title;
  dataStore[1].size = TI;

                 /* author window */

  dataStore[2].id = XCreateWindow(e6display, baseW,
                               210, 45, charinc*AU, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[2].array = author;
  dataStore[2].size = AU;

                 /* author/editor windows */

  dataStore[3].id = XCreateWindow(e6display, baseW,
                               258, 47, charinc*AE, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[3].array = aued;
  dataStore[3].size = AE;

                 /* institution window */

  dataStore[4].id = XCreateWindow(e6display, baseW,
                               60, 45, IS*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[4].array = institution;
  dataStore[4].size = IS;

                 /* journal title window */

  dataStore[5].id = XCreateWindow(e6display, baseW,
                               242, 110, JR*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[5].array = journaltitle;
  dataStore[5].size = JR;
  dataStore[5].before = 0;
  dataStore[5].next = 6;

                 /* these are dummy fill-ins */

  dataStore[7].array = type;
  dataStore[7].size = TY;
  dataStore[7].before = 0;
  dataStore[7].next = 6;

  dataStore[8].array = type;
  dataStore[8].size = TY;
  dataStore[8].before = 0;
  dataStore[8].next = 6;

  dataStore[9].array = type;
  dataStore[9].size = TY;
  dataStore[9].before = 0;
  dataStore[9].next = 6;
  
                 /* type window */

  dataStore[61].id = XCreateWindow(e6display, baseW,
                               600, 2, TY*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[61].array = type;
  dataStore[61].size = TY;

                 /* editor window */

  dataStore[90].id = XCreateWindow(e6display, baseW,
                               68, 2, charinc*ER, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[90].array = editor;
  dataStore[90].size = ER;

                 /* book title window */

  dataStore[71].id = XCreateWindow(e6display, baseW,
                               600, 2, BT*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[71].array = booktitle;
  dataStore[71].size = BT;

                 /* keywords window */  /* this window needs a red border */

  dataStore[86].id = XCreateWindow(e6display, moduleStore[8].id,
                               80, 62, charinc*KW, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[86].array = keywords;
  dataStore[86].size = KW;
  dataStore[86].before = 94;
  dataStore[86].next = 87; 



              /* All the following windows contain OPTIONAL data only */

  dataat.border_pixel = colours[3];

                 /* journal subtitle window */

  dataStore[6].id = XCreateWindow(e6display, baseW,
                               266, 160, JS*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[6].array = jsubtitle;
  dataStore[6].size = JS;
  dataStore[6].before = 5;
  dataStore[6].next = 19;

                 /* editor A window */

  dataStore[10].id = XCreateWindow(e6display, moduleStore[2].id,
                               68, 5, charinc*EQ, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[10].array = editora;
  dataStore[10].size = EQ;
  dataStore[10].before = 1001;
  dataStore[10].next = 13;

                 /* editor B window */

  dataStore[11].id = XCreateWindow(e6display, moduleStore[2].id,
                               68, 32, charinc*EP, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[11].array = editorb;
  dataStore[11].size = EP;
  dataStore[11].before = 13;
  dataStore[11].next = 14;

                 /* editor C window */

  dataStore[12].id = XCreateWindow(e6display, moduleStore[2].id,
                               68, 62, charinc*EO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[12].array = editorc;
  dataStore[12].size = EO;
  dataStore[12].before = 14;
  dataStore[12].next = 15;

                 /* editor A type window */

  dataStore[13].id = XCreateWindow(e6display, moduleStore[2].id,
                               500, 5, charinc*EU, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[13].array = editoratype;
  dataStore[13].size = EU;
  dataStore[13].before = 10;
  dataStore[13].next = 11;

                 /* editor B type window */

  dataStore[14].id = XCreateWindow(e6display, moduleStore[2].id,
                               500, 32, charinc*EV, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[14].array = editorbtype;
  dataStore[14].size = EV;
  dataStore[14].before = 11;
  dataStore[14].next = 12;

                 /* editor C type window */

  dataStore[15].id = XCreateWindow(e6display, moduleStore[2].id,
                               500, 62, charinc*EW, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[15].array = editorctype;
  dataStore[15].size = EW;
  dataStore[15].before = 12;
  dataStore[15].next = 1001;

                 /* editor window */

  dataStore[16].id = XCreateWindow(e6display, baseW,
                               68, 2, charinc*ER, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[16].array = editor;
  dataStore[16].size = ER;
  dataStore[16].before = 10001;
  dataStore[16].next = 17;

                 /* editor type window */

  dataStore[17].id = XCreateWindow(e6display, baseW,
                               500, 2, charinc*ET, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[17].array = editortype;
  dataStore[17].size = ET;

                 /* number window */

  dataStore[18].id = XCreateWindow(e6display, baseW,
                               260, 2, charinc*NU, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[18].array = number;
  dataStore[18].size = NU;

                 /* volume window */

  dataStore[19].id = XCreateWindow(e6display, baseW,
                               60, 2, charinc*VO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[19].array = volume;
  dataStore[19].size = VO;

                 /* ISBN window */

  dataStore[20].id = XCreateWindow(e6display, baseW,
                               540, 32, charinc*IB, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[20].array = isbn;
  dataStore[20].size = IB;

                 /* pages window */

  dataStore[21].id = XCreateWindow(e6display, baseW,
                               452, 2, charinc*PG, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[21].array = pages;
  dataStore[21].size = PG;

                 /* series window */

  dataStore[22].id = XCreateWindow(e6display, baseW,
                               60, 62, charinc*SE, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[22].array = series;
  dataStore[22].size = SE;

                 /* pubstate  window */

  dataStore[23].id = XCreateWindow(e6display, moduleStore[0].id,
                               68, 92, charinc*PS, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[23].array = pubstate;
  dataStore[23].size = PS;
  dataStore[23].before = 28;
  dataStore[23].next = 25;

                 /* addendum window */

  dataStore[24].id = XCreateWindow(e6display, moduleStore[0].id,
                               85, 122, charinc*AA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[24].array = addendum;
  dataStore[24].size = AA;
  dataStore[24].before = 25;
  dataStore[24].next = 26;

                 /* language window */

  dataStore[25].id = XCreateWindow(e6display, moduleStore[0].id,
                               370, 92, charinc*LA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[25].array = language;
  dataStore[25].size = LA;
  dataStore[25].before = 23;
  dataStore[25].next = 24;

                 /* note window */

//                               52, 5, charinc*NO, 8*SINGLE, 1,
  dataStore[26].id = XCreateWindow(e6display, moduleStore[0].id,
                               50, 152, charinc*NO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[26].array = note;
  dataStore[26].size = NO;
  dataStore[26].before = 24;
  dataStore[26].next = 25;

                 /* url window */

  dataStore[27].id = XCreateWindow(e6display, moduleStore[0].id,
                               45, 62, charinc*UR, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[27].array = url;
  dataStore[27].size = UR;
  dataStore[27].before = 30;
  dataStore[27].next = 28;

                 /* url date window */

  dataStore[28].id = XCreateWindow(e6display, moduleStore[0].id,
                               722, 62, charinc*UD, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[28].array = urldate;
  dataStore[28].size = UD;
  dataStore[28].before = 27;
  dataStore[28].next = 23;

                 /* title addon window */

  dataStore[29].id = XCreateWindow(e6display, moduleStore[0].id,
                               88, 2, charinc*TA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[29].array = titleaddon;
  dataStore[29].size = TA;
  dataStore[29].before = 33;  /* out link to 'location' */
  dataStore[29].next = 30;

                 /* subtitle window */

  dataStore[30].id = XCreateWindow(e6display, moduleStore[0].id,
                               65, 32, charinc*ST, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[30].array = subtitle;
  dataStore[30].size = ST;
  dataStore[30].before = 29;
  dataStore[30].next = 27;

                 /* DOI window */

  dataStore[31].id = XCreateWindow(e6display, moduleStore[7].id,
                               40, 2, charinc*DO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[31].array = doi;
  dataStore[31].size = DO;
  dataStore[31].before = 35;   /* out link to 'eprintclass' */
  dataStore[31].next = 32;

                 /* library window */

  dataStore[32].id = XCreateWindow(e6display, moduleStore[7].id,
                               305, 2, charinc*LI, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[32].array = library;
  dataStore[32].size = LI;
  dataStore[32].before = 31;
  dataStore[32].next = 33;

                 /* location window */

  dataStore[33].id = XCreateWindow(e6display, moduleStore[7].id,
                               661, 2, charinc*LO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[33].array = location;
  dataStore[33].size = LO;
  dataStore[33].before = 32;
  dataStore[33].next = 29;   /* out link to 'titleaddon' */

                 /* eprint window */

  dataStore[34].id = XCreateWindow(e6display, moduleStore[1].id,
                               60, 2, charinc*EA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[34].array = eprint;
  dataStore[34].size = EA;
  dataStore[34].before = 1001;
  dataStore[34].next = 36;

                 /* eprintclass window */

  dataStore[35].id = XCreateWindow(e6display, moduleStore[1].id,
                               738, 2, charinc*EC, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[35].array = eprintclass;
  dataStore[35].size = EC;
  dataStore[35].before = 36;
  dataStore[35].next = 31;   /* out link to 'doi' */

                 /* eprinttype window */

  dataStore[36].id = XCreateWindow(e6display, moduleStore[1].id,
                               435, 2, charinc*EY, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[36].array = eprinttype;
  dataStore[36].size = EY;
  dataStore[36].before = 34;
  dataStore[36].next = 35;

                 /* ISSN window */

  dataStore[37].id = XCreateWindow(e6display, moduleStore[4].id,
                               340, 2, charinc*IN, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[37].array = issn;
  dataStore[37].size = IN;
  dataStore[37].before = 38;
  dataStore[37].next = 40;

                 /* issue window */

  dataStore[38].id = XCreateWindow(e6display, moduleStore[4].id,
                               60, 2, charinc*II, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[38].array = issue;
  dataStore[38].size = II;
  dataStore[38].before = 1001;
  dataStore[38].next = 37;

                 /* issue subtitle window */

  dataStore[39].id = XCreateWindow(e6display, moduleStore[4].id,
                               549, 32, charinc*IK, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[39].array = issuesubtitle;
  dataStore[39].size = IK;
  dataStore[39].before = 40;
  dataStore[39].next = 1001;

                 /* issue title window */

  dataStore[40].id = XCreateWindow(e6display, moduleStore[4].id,
                               80, 32, charinc*IJ, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[40].array = issuetitle;
  dataStore[40].size = IJ;
  dataStore[40].before = 37;
  dataStore[40].next = 39;

                 /* main subtitle window */

  dataStore[41].id = XCreateWindow(e6display, moduleStore[5].id,
                               95, 32, charinc*MS, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[41].array = mainsubtitle;
  dataStore[41].size = MS;
  dataStore[41].before = 42;
  dataStore[41].next = 43;

                 /* main title window */

  dataStore[42].id = XCreateWindow(e6display, moduleStore[5].id,
                               73, 2, charinc*MT, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[42].array = maintitle;
  dataStore[42].size = MT;
  dataStore[42].before = 1001;
  dataStore[42].next = 41;

                 /* main title addon window */

  dataStore[43].id = XCreateWindow(e6display, moduleStore[5].id,
                               618, 32, charinc*MA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[43].array = mainsubtitle;
  dataStore[43].size = MA;
  dataStore[43].before = 41;
  dataStore[43].next = 1001;

                 /* month window */

  dataStore[44].id = XCreateWindow(e6display, baseW,
                               600, 2, MN*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[44].array = month;
  dataStore[44].size = MN;

                 /* name addon window */

  dataStore[45].id = XCreateWindow(e6display, baseW,
                               600, 2, NA*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[45].array = nameaddon;
  dataStore[45].size = NA;

                 /* organization window */

  dataStore[46].id = XCreateWindow(e6display, baseW,
                               600, 2, OR*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[46].array = organization;
  dataStore[46].size = OR;

                 /* original date window */

  dataStore[47].id = XCreateWindow(e6display, moduleStore[6].id,
                               725, 2, charinc*OD, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[47].array = origdate;
  dataStore[47].size = OD;
  dataStore[47].before = 48;
  dataStore[47].next = 51;

                 /* original language window */

  dataStore[48].id = XCreateWindow(e6display, moduleStore[6].id,
                               120, 2, charinc*OL, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[48].array = origlanguage;
  dataStore[48].size = OL;
  dataStore[48].before = 1001;
  dataStore[48].next = 47;

                 /* original location window */

  dataStore[49].id = XCreateWindow(e6display, moduleStore[6].id,
                               613, 62, charinc*OP, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[49].array = origlocation;
  dataStore[49].size = OP;
  dataStore[49].before = 50;
  dataStore[49].next = 1001;

                 /* original publisher window */

  dataStore[50].id = XCreateWindow(e6display, moduleStore[6].id,
                               120, 62, charinc*OU, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[50].array = origpublisher;
  dataStore[50].size = OU;
  dataStore[50].before = 51;
  dataStore[50].next = 49;

                 /* original title window */

  dataStore[51].id = XCreateWindow(e6display, moduleStore[6].id,
                               94, 32, charinc*OT, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[51].array = origtitle;
  dataStore[51].size = OT;
  dataStore[51].before = 47;
  dataStore[51].next = 50;

                 /* page total window */

  dataStore[53].id = XCreateWindow(e6display, baseW,
                               530, 128, PT*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[53].array = pagetotal;
  dataStore[53].size = PT;
  dataStore[53].before = 62;
  dataStore[53].next = 73;

                 /* pagination window */

  dataStore[54].id = XCreateWindow(e6display, baseW,
                               530, 128, PA*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[54].array = paginnation;
  dataStore[54].size = PA;

                 /* part window */

  dataStore[55].id = XCreateWindow(e6display, baseW,
                               540, 62, charinc*PR, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[55].array = part;
  dataStore[55].size = PR;

                 /* publisher window */

  dataStore[56].id = XCreateWindow(e6display, baseW,
                               75, 32, charinc*PU, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[56].array = publisher;
  dataStore[56].size = PU;

                 /* reprint title window */

  dataStore[57].id = XCreateWindow(e6display, baseW,
                               75, 32, charinc*RT, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[57].array = reprinttitle;
  dataStore[57].size = RT;

                 /* venue window */

  dataStore[58].id = XCreateWindow(e6display, moduleStore[10].id,
                               53, 32, charinc*VE, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[58].array = venue;
  dataStore[58].size = VE;
  dataStore[58].before = 77;
  dataStore[58].next = 76;

                 /* version window */

  dataStore[59].id = XCreateWindow(e6display, baseW,
                               600, 2, VR*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[59].array = version;
  dataStore[59].size = VR;

                 /* volumes window */

  dataStore[60].id = XCreateWindow(e6display, baseW,
                               763, 62, charinc*VS, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[60].array = volumes;
  dataStore[60].size = VS;

                 /* edition window */

  dataStore[62].id = XCreateWindow(e6display, baseW,
                               210, 128, EN*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[62].array = edition;
  dataStore[62].size = EN;
  dataStore[62].before = 1001;
  dataStore[62].next = 53;

                 /* afterword window */

  dataStore[63].id = XCreateWindow(e6display, moduleStore[9].id,
                               80, 2, charinc*AW, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[63].array = afterword;
  dataStore[63].size = AW;
  dataStore[63].before = 26;
  dataStore[63].next = 66;

                 /* foreword window */

  dataStore[64].id = XCreateWindow(e6display, moduleStore[9].id,
                               521, 32, charinc*FW, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[64].array = foreword;
  dataStore[64].size = FW;
  dataStore[64].before = 74;
  dataStore[64].next = 82;

                 /* annotation window - note this window is formed different to others */

  dataStore[65].id = XCreateWindow(e6display, moduleStore[46].id,
//                               85, 182, charinc*AO, SINGLE, 1,
                               12, 29, charinc*AO, MULTIPLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[65].array = annotation;
  dataStore[65].size = AOAO;
  dataStore[65].before = 24;
  dataStore[65].next = 65;

                 /* annotator window */

  dataStore[66].id = XCreateWindow(e6display, moduleStore[9].id,
                               521, 2, charinc*AN, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[66].array = annotator;
  dataStore[66].size = AN;
  dataStore[66].before = 63;
  dataStore[66].next = 74;

                 /* annotator A window */

  dataStore[89].id = XCreateWindow(e6display, baseW,
                               520, 2, charinc*AN, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[89].array = annotator;
  dataStore[89].size = AN;

                 /* author type window */

  dataStore[67].id = XCreateWindow(e6display, baseW,
                               520, 2, charinc*AT, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[67].array = authortype;
  dataStore[67].size = AT;

                 /* book author window */

  dataStore[68].id = XCreateWindow(e6display, baseW,
                               520, 2, charinc*BB, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[68].array = bookauthor;
  dataStore[68].size = BB;

                 /* book pagination window */

  dataStore[69].id = XCreateWindow(e6display, baseW,
                               520, 2, charinc*BP, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[69].array = bookpagination;
  dataStore[69].size = BP;

                 /* book subtitle window */

  dataStore[70].id = XCreateWindow(e6display, baseW,
                               600, 2, charinc*BS, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[70].array = booksubtitle;
  dataStore[70].size = BS;

                 /* book title addon window */

  dataStore[72].id = XCreateWindow(e6display, baseW,
                               600, 2, BA*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[72].array = booksubtitle;
  dataStore[72].size = BA;

                 /* chapter window */

  dataStore[73].id = XCreateWindow(e6display, baseW,
                               820, 128, CH*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[73].array = chapter;
  dataStore[73].size = CH;
  dataStore[73].before = 53;
  dataStore[73].next = 74;

                 /* commentator window */

//  dataStore[74].id = XCreateWindow(e6display, moduleStore[12].id,
//                               100, 160, CO*charinc, SINGLE, 1,
  dataStore[74].id = XCreateWindow(e6display, moduleStore[9].id,
                               95, 32, charinc*CO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[74].array = commentator;
  dataStore[74].size = CO;
  dataStore[74].before = 66;
  dataStore[74].next = 64;

                 /* EID window */

  dataStore[75].id = XCreateWindow(e6display, baseW,
                               600, 2, EI*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[75].array = eid;
  dataStore[75].size = EI;

                 /* event date window */

  dataStore[76].id = XCreateWindow(e6display, moduleStore[10].id,
                               724, 32, charinc*ED, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[76].array = eventdate;
  dataStore[76].size = ED;
  dataStore[76].before = 58;
  dataStore[76].next = 1001;

                 /* event title window */

  dataStore[77].id = XCreateWindow(e6display, moduleStore[10].id,
                               80, 2, charinc*EX, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[77].array = eventtitle;
  dataStore[77].size = EX;
  dataStore[77].before = 1001;
  dataStore[77].next = 58;

                 /* file window */

  dataStore[78].id = XCreateWindow(e6display, moduleStore[10].id,
                               82, 2, charinc*FI, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[78].array = file;
  dataStore[78].size = FI;

                 /* holder window */

  dataStore[79].id = XCreateWindow(e6display, moduleStore[10].id,
                               82, 2, charinc*HO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[79].array = holder;
  dataStore[79].size = HO;

                 /* how published window */

  dataStore[80].id = XCreateWindow(e6display, moduleStore[10].id,
                               82, 2, charinc*HP, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[80].array = howpublished;
  dataStore[80].size = HP;

                 /* index title window */

  dataStore[81].id = XCreateWindow(e6display, moduleStore[10].id,
                               82, 2, charinc*IX, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[81].array = indextitle;
  dataStore[81].size = IX;

                 /* introduction window */

  dataStore[82].id = XCreateWindow(e6display, moduleStore[9].id,
                               90, 62, charinc*IT, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[82].array = introduction;
  dataStore[82].size = IT;
  dataStore[82].before = 64;
  dataStore[82].next = 52;

                 /* translator window */

  dataStore[52].id = XCreateWindow(e6display, moduleStore[9].id,
                               521, 62, charinc*TR, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[52].array = translator;
  dataStore[52].size = TR;
  dataStore[52].before = 82;
  dataStore[52].next = 1001;

                 /* ISAN window */

  dataStore[83].id = XCreateWindow(e6display, moduleStore[9].id,
                               90, 62, charinc*IA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[83].array = isan;
  dataStore[83].size = IA;

                 /* ISMN window */

  dataStore[84].id = XCreateWindow(e6display, moduleStore[9].id,
                               90, 62, charinc*IM, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[84].array = ismn;
  dataStore[84].size = IM;

                 /* ISRN window */

  dataStore[85].id = XCreateWindow(e6display, baseW,
                               600, 2, IR*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[85].array = isrn;
  dataStore[85].size = IR;

                 /* keywords window */  /* this window needs a red border */

/*  dataStore[86].id = XCreateWindow(e6display, moduleStore[8].id,
                               80, 62, charinc*KW, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[86].array = keywords;
  dataStore[86].size = KW;
  dataStore[86].before = 94;
  dataStore[86].next = 87; */

                 /* sortkey window */

  dataStore[87].id = XCreateWindow(e6display, moduleStore[8].id,
                               620, 62, charinc*SK, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[87].array = sortkey;
  dataStore[87].size = SK;
  dataStore[87].before = 86;
  dataStore[87].next = 88;

                 /* xref window */

  dataStore[88].id = XCreateWindow(e6display, moduleStore[8].id,
                               50, 92, charinc*XR, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[88].array = xref;
  dataStore[88].size = XR;
  dataStore[88].before = 87;
  dataStore[88].next = 1001;

                 /* short author window */

  dataStore[91].id = XCreateWindow(e6display, moduleStore[8].id,
                               95, 2, charinc*SA, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[91].array = shortauthor;
  dataStore[91].size = SA;
  dataStore[91].before = 1001;
  dataStore[91].next = 97;

                 /* short editor window */

  dataStore[92].id = XCreateWindow(e6display, baseW,
                               60, 32, charinc*SD, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[92].array = shorteditor;
  dataStore[92].size = SD;
  dataStore[92].before = 87;
  dataStore[92].next = 1001;

                 /* shorthand window */

  dataStore[93].id = XCreateWindow(e6display, moduleStore[8].id,
                               83, 32, charinc*SH, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[93].array = shorthand;
  dataStore[93].size = SH;
  dataStore[93].before = 97;
  dataStore[93].next = 94;

                 /* shorthand intro window */

  dataStore[94].id = XCreateWindow(e6display, moduleStore[8].id,
                               564, 32, charinc*SI, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[94].array = shorthandintro;
  dataStore[94].size = SI;
  dataStore[94].before = 93;
  dataStore[94].next = 86;

                 /* short journal window */

  dataStore[95].id = XCreateWindow(e6display, baseW,
                               60, 32, charinc*SJ, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[95].array = shortjournal;
  dataStore[95].size = SJ;
  dataStore[95].before = 87;
  dataStore[95].next = 1001;

                 /* short series window */

  dataStore[96].id = XCreateWindow(e6display, baseW,
                               60, 32, charinc*SS, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[96].array = shortseries;
  dataStore[96].size = SS;
  dataStore[96].before = 87;
  dataStore[96].next = 1001;

                 /* short title window */

  dataStore[97].id = XCreateWindow(e6display, moduleStore[8].id,
                               522, 2, charinc*SL, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[97].array = shorttitle;
  dataStore[97].size = SL;
  dataStore[97].before = 91;
  dataStore[97].next = 93;

                 /* type(2) window */

  dataStore[98].id = XCreateWindow(e6display, moduleStore[8].id,
                               522, 2, charinc*TT, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[98].array = type2;
  dataStore[98].size = TT;
  dataStore[98].before = 91;
  dataStore[98].next = 93;


                 /* filename input window */

  dataat.event_mask = EnterWindowMask | LeaveWindowMask | KeyPressMask |
                      ButtonReleaseMask | ExposureMask;
  dataStore[100].id = XCreateWindow(e6display, baseW,
                               50, 2, charinc*FN, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[100].array = filename;
  dataStore[100].size = FN;

                 /* displaying append filename window */

  dataStore[101].id = XCreateWindow(e6display, windowStore[1],
                               1, 30, charinc*FO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[101].array = filename;
  dataStore[101].size = FO;

                 /* window to show the text of an error message */

  dataStore[102].id = XCreateWindow(e6display, windowStore[4],
                               10, 60, charinc*RR, SINGLE, XX,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[102].array = errortext;
  dataStore[102].size = RR;
  XSetWindowBackground(e6display, dataStore[102].id, colours[9]);

                 /* displaying write filename window */

  dataStore[103].id = XCreateWindow(e6display, windowStore[5],
                               1, 30, charinc*FO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[103].array = filename;
  dataStore[103].size = FO;

                 /* window for obtaining read filename */

  dataStore[104].id = XCreateWindow(e6display, windowStore[7],
                               1, 30, charinc*FO, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[104].array = readfile;
  dataStore[104].size = FO;

                 /* window for showing read filename */
  dataStore[105].id = XCreateWindow(e6display, baseW,
                               50, 2, charinc*FN, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[105].array = readfile;
  dataStore[105].size = FN;

		       /* window for input of citation selection */
  dataStore[106].id = XCreateWindow(e6display, baseW,
                                 140, 40, charinc*20, SINGLE, 1,
				 depthDefault, InputOutput, visualDefault,
				 opmask, &dataat);

		       /* window for input of citation selection */
  dataStore[106].array = target;
  dataStore[106].size = 20;

		       /* for a single line of a multi line reference */
  singleLine.array = single;
  singleLine.size = NO;


              /* All the following windows are repeats of a previous window
               * but with the opposite border colouring
               */

  
		       /* window for input of author OPTIONAL citation */
  dataat.border_pixel = colours[3]; /* blue */

                       /* window for input of author OPTIONAL */

  dataStore[107].id = XCreateWindow(e6display, baseW,
                               210, 45, charinc*AU, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[107].array = author;
  dataStore[107].size = AU;

  
		       /* window for input of booktitle OPTIONAL citation */

  dataStore[108].id = XCreateWindow(e6display, baseW,
                               600, 2, BT*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[108].array = booktitle;
  dataStore[108].size = BT;

  
		       /* window for input of type OPTIONAL citation */

  dataStore[111].id = XCreateWindow(e6display, baseW,
                                 140, 40, charinc*20, SINGLE, 1,
				 depthDefault, InputOutput, visualDefault,
				 opmask, &dataat);

  dataStore[111].id = XCreateWindow(e6display, baseW,
                               600, 2, TY*charinc, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[111].array = type;
  dataStore[111].size = TY;
  
  
		       /* window for input of editor REQUIRED citation */
  dataat.border_pixel = colours[4]; /* red */

  dataStore[109].id = XCreateWindow(e6display, baseW,
                               68, 2, charinc*ER, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[109].array = editor;
  dataStore[109].size = ER;
  dataStore[109].before = 10001;
  dataStore[109].next = 17;
  
		       /* window for input of number REQUIRED citation */

  dataStore[110].id = XCreateWindow(e6display, baseW,
                               260, 2, charinc*NU, SINGLE, 1,
			       depthDefault, InputOutput, visualDefault,
			       opmask, &dataat);
  dataStore[110].array = number;
  dataStore[110].size = NU;

 
}
