/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  The functions here control actions following from mouse actions.
 *
 *  Coded by:      Ross Maloney
 *  April 2011:    Initial coding
 *  July 2014:     Handling of seconds window added
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  <stdlib.h>     /* For exit() */
#include  "e6x11Ext.h"      /* X11 related common parts of e6 */
#include  "e6dataExt.h"     /* Common parts for processing data */

                         /* Prototypes of all functiond called from here */

void  showmenu()
{
  int   i;

  for (i=23; i<27; i++)
    XMapWindow(e6display, menuStore[i].selected);
  for (i=83; i<99; i++)
    XMapWindow(e6display, menuStore[i].selected);
}



/* Given the window id, this routine determines the index to the information
 * stored about that window.
 */

int  findIndex(Window id)
{
  int   i;

  if ( id == baseW )  return(BASE_WINDOW); /* window is baseW */
  if ( id == secondsW )  return(SECONDS_WINDOW); /* added in e6-2.0 */
  for (i=BOTTOM_0; i<TOP_0; i++)  {        /* window is in menu depth 1 */
    if ( id == menuStore[i].normal )  return(i);
    if ( id == menuStore[i].selected ) return(i);
  }
  for (i=BOTTOM_1; i<TOP_1; i++)  {        /* window is in menu depth 2 */
    if ( id == menuStore[i].normal )  return(i);
    if ( id == menuStore[i].selected ) return(i);
  }
  for (i=BOTTOM_2; i<TOP_2; i++)  {        /* window is in menu depth 3 */
    if ( id == menuStore[i].normal )  return(i);
    if ( id == menuStore[i].selected ) return(i);
  }
  for (i=0; i<FIELDS; i++) 
    if ( id == dataStore[i].id )  {
      return(i + 1000);  /* input window */
    }
  for (i=0; i<10; i++)  {
    if ( id == buttonStore[i].normal )  return(i + 2000);
    if ( id == buttonStore[i].selected )  return(i + 3000);
  }
  printf("Should never get this message\n");
  return(-1);
}


/* This function is called with a menu window is entered.  It shows on the
 * screen the window selected and puts onto the screen all tne menu
 * windows connected to this selection.  First, it determines whether any window
 * in its menu depth is shown as selected.  If this is so, then that window is
 * shown as 'normal' and all windows connected to it are removed from the
 * screen.
 */

void  menuEntered(int  index)
{
  int  i, level, j, top, bottom;
  int  lower[] = {BOTTOM_0, BOTTOM_1, BOTTOM_2};
  int  upper[] = {TOP_0, TOP_1, TOP_2};
  void  removeMenus(int);   /* in this file */


		/* treat the baseW window as a special case */
  if ( index == BASE_WINDOW )  {
    for (i=BOTTOM_0; i<TOP_0; i++)
      if ( menuStore[i].visible == 2 )  {
	XRaiseWindow(e6display, menuStore[i].normal);
        menuStore[i].visible = 1;
      }
    removeMenus(1);
    return;
  }
		/* first remove all menus leading from the 'deselected item */
  level = menuStore[index].depth;
  if ( level < 2 )  removeMenus(level+1);
                /* now show this menu item as being selected */
  top = upper[level];
  bottom = lower[level];
  for (i=bottom; i<top; i++)
    if ( menuStore[i].visible == 2 )  {
      XRaiseWindow(e6display, menuStore[i].normal);
      menuStore[i].visible = 1;
    }
  XRaiseWindow(e6display, menuStore[index].selected);
  menuStore[index].visible = 2;
		/* show the menu items connected to this selection */
  top = upper[level+1];
  bottom = lower[level+1];
  for (i=bottom; i<top; i++)
    if ( menuStore[i].parent == index )  {
      XMapWindow(e6display, menuStore[i].selected);
      XMapWindow(e6display, menuStore[i].normal);
      XRaiseWindow(e6display, menuStore[i].normal);
      menuStore[i].visible = 1;
    }
}



/*  All menus shown on the screen with depth at or greater than the depth
 *  paramter supplied to this function are removed from the screen.
 */

void  removeMenus(int  depth)
{
  int  i;

  switch (depth)  {
  case 0:   /* menu bar */
    break;
  case 1:   /* menus of depth 1 */
    for (i=BOTTOM_1; i<TOP_1; i++)  {
      XUnmapWindow(e6display, menuStore[i].selected);
      XUnmapWindow(e6display, menuStore[i].normal);
      menuStore[i].visible = 0;
    }   /* the 'break' is deliberately left out */
  case 2:   /* menus of depth 2 */
    for (i=BOTTOM_2; i<TOP_2; i++)  {
      XUnmapWindow(e6display, menuStore[i].selected);
      XUnmapWindow(e6display, menuStore[i].normal);
      menuStore[i].visible = 0;
    }
    break;
  default:
    printf(" depth %d should not call removeMenu()\n", depth);
  }
}
