/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains the function to handle a 'mvbook' citation type.
 *
 *  Coded by:       Ross Maloney
 *  April 2013      Initial code 
 *  September 2014  Minor field handline moved to mvbook2()
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  mvbook()
{
  void showkeysO(void);        /* in utilities.c */
  void showmainO(void);        /* in utilities.c */
  void showissO(void);         /* in utilities.c */
  void wordsO(void);           /* in utilities.c */
  void showeventsO(void);      /* in utilities.c */
  void removeMenus(int);       /* in mouseevent.c */
  void error(char *);          /* in error.c */
  void shownote(void);         /* in utilities.c */
  void zeroall(void);          /* in texting.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 765);
  removeMenus(1);   /* remove the menu train which led to this function */
  XMapWindow(e6display, moduleStore[42].id);  /* multi-volume book Required */
  who = 52;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);
//  XMapWindow(e6display, moduleStore[37].id);  /* multi volume book required */

  XReparentWindow(e6display, dataStore[2].id,
         moduleStore[42].id, 60, 47);    /* author */
  XMapWindow(e6display, dataStore[2].id);
  dataStore[2].before = 65;
  dataStore[2].next = 1;
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[42].id, 50, 78);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 2;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[42].id, 725, 78);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 62;
  XReparentWindow(e6display, dataStore[62].id,
       moduleStore[42].id, 60, 128); /* edition */
  XMapWindow(e6display, dataStore[62].id);
  dataStore[62].before = 0;
  dataStore[62].next = 53;
  XReparentWindow(e6display, dataStore[53].id,
       moduleStore[42].id, 380, 128); /* page total */
  XMapWindow(e6display, dataStore[53].id);
  dataStore[53].before = 62;
  dataStore[53].next = 18;
  XReparentWindow(e6display, dataStore[18].id,
         moduleStore[42].id, 613, 128);   /* number */
  XMapWindow(e6display, dataStore[18].id);
  dataStore[18].before = 53;
  dataStore[18].next = 56;
  XReparentWindow(e6display, dataStore[56].id,
         moduleStore[42].id, 73, 158);   /* publisher */
  XMapWindow(e6display, dataStore[56].id);
  dataStore[56].before = 18;
  dataStore[56].next = 22;
  XReparentWindow(e6display, dataStore[22].id,
         moduleStore[42].id, 60, 188);  /* series */
  XMapWindow(e6display, dataStore[22].id);
  dataStore[22].before = 56;
  dataStore[22].next = 96;
  XReparentWindow(e6display, dataStore[96].id,
         moduleStore[42].id, 641, 188);  /* short series */
  XMapWindow(e6display, dataStore[96].id);
  dataStore[96].before = 22;
  dataStore[96].next = 16;
  XReparentWindow(e6display, dataStore[16].id,
         moduleStore[42].id, 55, 218);  /* editor */
  XMapWindow(e6display, dataStore[16].id);
  dataStore[16].before = 96;
  dataStore[16].next = 92;
  XReparentWindow(e6display, dataStore[92].id,
         moduleStore[42].id, 641, 218);  /* short editor */
  XMapWindow(e6display, dataStore[92].id);
  dataStore[92].before = 16;
  dataStore[92].next = 20;
  XReparentWindow(e6display, dataStore[20].id,
         moduleStore[42].id, 55, 248);  /* isbn */
  XMapWindow(e6display, dataStore[20].id);
  dataStore[20].before = 92;
  dataStore[20].next = 60;
  XReparentWindow(e6display, dataStore[60].id,
         moduleStore[42].id, 711, 248);  /* volumes */
  XMapWindow(e6display, dataStore[60].id);
  dataStore[60].before = 20;
  dataStore[60].next = 91;

                        /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 280);
  showkeysO();  /* keys Optional */
  dataStore[91].before = 60;
  dataStore[88].next = 65;
                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 405);
  shownote();

  zeroall();        /* set all input data fields to zero */
}


/*  Function to form the window to contain minor data fields associated with
 *  multi-volume book reference type.
 */

void  mvbook2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (mv Book)";
  char *icon_name = "e6/2";
  void showeditorabcO(void);   /* in utilities.c */
  void showorigO(void);        /* in utilities.c */
  void showeprintO(void);      /* in utilities.c */
  void showlargeO1(void);      /* in utilities.c */
  void showlargeO(void);       /* in utilities.c */
  void showwordsO(void);       /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 518);
  XMapWindow(e6display, secondsW);
  XMoveWindow(e6display, moduleStore[9].id, 0, 5);
  showwordsO();      /* auxiliary information */
  dataStore[63].before = 26;
  dataStore[52].next = 10;
  showwordsO();      /* auxiliary information */
                        /* linking in editorabcO */
  XMoveWindow(e6display, moduleStore[2].id, 0, 95);
  dataStore[10].before = 52;
  dataStore[15].next = 48;
  showeditorabcO();  /* editor descriptors */
                        /* linking in origO */
  XMoveWindow(e6display, moduleStore[6].id, 0, 185);
  dataStore[48].before = 15;
  dataStore[49].next = 34;
  showorigO();       /* original publication details */
                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 274);
  showeprintO();     /* eprint information */
  XMoveWindow(e6display, moduleStore[7].id, 0, 305);
  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 335);
  showlargeO();      /* large Optionals */
  dataStore[34].before = 49;
  dataStore[26].next = 63;

}
