/* This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 * This file contains the function which handles a 'manual' citation type
 *
 * Coded by:       Ross Maloney
 * December 2012:  Initial code
 * September 2014: Minor field handling moved to periodical2()
 */
#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  periodical()
{
  void showkeysO(void);        /* in utilities.c */
  void shownote(void);         /* in utilities.c */
  void error(char *);          /* in error.c */
  void zeroall(void);          /* in texting.c */
  void removeMenus(int);       /* in mouseevents.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 705);
  removeMenus(1);   /* remove the menu train which led to this function */
  who = 67;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, moduleStore[33].id);  /* manual Required */
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);
  
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[33].id, 50, 47);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 65;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[33].id, 725, 47);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 90;
  XReparentWindow(e6display, dataStore[90].id,
         moduleStore[33].id, 55, 76);    /* editor */
  XMapWindow(e6display, dataStore[90].id);
  dataStore[90].before = 0;
  dataStore[90].next = 92;
  XReparentWindow(e6display, dataStore[92].id,
         moduleStore[33].id, 642, 76);    /* short edition */
  XMapWindow(e6display, dataStore[92].id);
  dataStore[92].before = 90;
  dataStore[92].next = 53;
  XReparentWindow(e6display, dataStore[53].id,
         moduleStore[33].id, 60, 126);    /* volume */
  XMapWindow(e6display, dataStore[53].id);
  dataStore[53].before = 92;
  dataStore[53].next = 18;
  XReparentWindow(e6display, dataStore[18].id,
         moduleStore[33].id, 275, 126);    /* number */
  XMapWindow(e6display, dataStore[18].id);
  dataStore[18].before = 53;
  dataStore[18].next = 56;
  XReparentWindow(e6display, dataStore[56].id,
         moduleStore[33].id, 80, 156);    /* publisher */
  XMapWindow(e6display, dataStore[56].id);
  dataStore[56].before = 18;
  dataStore[56].next = 44;
  XReparentWindow(e6display, dataStore[44].id,
         moduleStore[33].id, 750, 156);    /* month */
  XMapWindow(e6display, dataStore[44].id);
  dataStore[44].before = 56;
  dataStore[44].next = 22;
  XReparentWindow(e6display, dataStore[22].id,
         moduleStore[33].id, 60, 186);    /* series */
  XMapWindow(e6display, dataStore[22].id);
  dataStore[22].before = 44;
  dataStore[22].next = 96;
  XReparentWindow(e6display, dataStore[96].id,
         moduleStore[33].id, 642, 186);    /* short series */
  XMapWindow(e6display, dataStore[96].id);
  dataStore[96].before = 22;
  dataStore[96].next = 91;
  
                        /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 220);
  showkeysO();  /* keys Optional */
  dataStore[91].before = 96;
  dataStore[88].next = 65;

                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 342);
  shownote();

  zeroall();        /* set all input data fields to zero */
}




/*  Function to form the window to contain the minor data fields associated with
 *  a periodical reference type.
 */

void  periodical2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (Periodical)";
  char *icon_name = "e6/2";
  void showlargeO(void);       /* in utilities.c */
  void showeprintO(void);      /* in utilities.c */
  void showlargeO1(void);      /* in utilities.c */
  void showeditorabcO(void);   /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 344);
  XMapWindow(e6display, secondsW);

                        /* linking in editorabcO */
//  XMoveWindow(e6display, moduleStore[2].id, 340, 345);
  XMoveWindow(e6display, moduleStore[2].id, 0, 5);
  dataStore[10].before = 26;
  dataStore[15].next = 34;
  showeditorabcO();  /* editor descriptors */
                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 95);
  showeprintO();     /* eprint information */
  XMoveWindow(e6display, moduleStore[7].id, 0, 125);
  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 155);
  showlargeO();      /* large Optionals */
  dataStore[34].before = 15;
  dataStore[26].next = 10;
}
