/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains functions which store the inputted reference data.
 *
 *  Coded by:       Ross Maloney
 *  June 2012:      Initial code
 *  May 2016:       Collection reference type added
 *  May 2018        Swapped output field entries in storefield()
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"


/* Routine called to store on the currently open storage device, all reference
 * fields which currently containing text.
 */

void  storeReference()
{
  int  i, j;
  void  storefield(int);     /* this file */
  int  makechecks(void);     /* this file */
  void  clearWindows(void);  /* in do.c */
  void  shownote(void);      /* in utilities.c */
  void  zeroall(void);       /* in texting..c */
  void  error(char *);       /* in error.c */

  if ( makechecks() )  return;   /* if everything looks correct, store */
  if ( !ofp )  {  /* check reference storage file allocated */
    error("   A file for storage is required");
    return;
  }
//  printf("storeReference: OK\n");
  printf("storeReference: who = %d\n", who);
  switch (who)  {  /* put the reference type leader in place */
  case 20:
    fprintf(ofp, "\n@Book{");
    break;
  case 21:
    fprintf(ofp, "\n@Article{");
    break;
  case 22:
    fprintf(ofp, "\n@Online{");
    break;
  case 23:
    fprintf(ofp, "\n@Thesis{");
    break;
  case 24:
    fprintf(ofp, "\n@Report{");
    break;
  case 25:
    fprintf(ofp, "\n@Inproceedings{");
    break;
  case 26:
    fprintf(ofp, "\n@Incollection{");
    break;
  case 27:
    fprintf(ofp, "\n@Proceedings{");
    break;
  case 28:
    fprintf(ofp, "\n@Collection{");
    break;
  case 29:
    fprintf(ofp, "\n@Booklet{");
    break;
  case 30:
    fprintf(ofp, "\n@Manual{");
    break;
  case 31:
    fprintf(ofp, "\n@Miscellaneous{");
    break;
  case 32:
    fprintf(ofp, "\n@Unpublished{");
    break;
  case 33:
    fprintf(ofp, "\n@Periodical{");
    break;
  case 34:
    fprintf(ofp, "\n@Reference{");
    break;
  case 35:
    fprintf(ofp, "\n@InReference{");
    break;
  case 36:
    fprintf(ofp, "\n@InBook{");
    break;
  case 37:
    fprintf(ofp, "\n@mvBook{");
    break;
  case 38:
    fprintf(ofp, "\n@mvCollection{");
    break;
  case 39:
    fprintf(ofp, "\n@mvProceedings{");
    break;
  case 40:
    fprintf(ofp, "\n@Patent{");
    break;
  default:
    printf("storeReference(): Illegal reference type\n");
    return;
  }
  if ( dataStore[86].end > 0 )
    for (j=0; j<dataStore[86].end; j++)  fprintf(ofp, "%c", dataStore[86].array[j]);
  else
    fprintf(ofp, "xxx");
  fprintf(ofp, ",\n");
  for (i=0; i<86; i++)   /* store reference fields up to Keywords */
    if ( dataStore[i].end > 0 )  {
      storefield(i);
      for (j=0; j<dataStore[i].end; j++)  fprintf(ofp, "%c", dataStore[i].array[j]);
      fprintf(ofp, "},\n");
    }
  for (i=87; i<99; i++) 
    if ( dataStore[i].end > 0 )  {
      storefield(i);
      for (j=0; j<dataStore[i].end; j++)  fprintf(ofp, "%c", dataStore[i].array[j]);
      fprintf(ofp, "},\n");
    }
  fprintf(ofp, "}\n");
  fflush(ofp);  /* force this data onto the output file */
  who = 0;   /* indicate data has been stored away */
  request_flag = 0;   /* indicate the save request is done */
  clearWindows();  /* with everything stored, clear the screen record */
}


/* Routine to format each reference field for external storage.  The function is
 * called with the index of the required reference field as a parameter in the
 * call.
 * Note: sortkey (87), note (26), and addendum (24) are not handled here - they
 * are handled separate from here.
 */

void  storefield(int index)
{

//  printf("storefield():  index = %d\n", index);
  switch ( index )  {
  case 0:
//    fprintf(ofp, "  yeardate     = {");
    fprintf(ofp, "  date         = {");
    break;
  case 1:
    fprintf(ofp, "  title        = {");
    break;
  case 2:
    fprintf(ofp, "  author       = {");
    break;
  case 3:
    /*    fprintf(ofp, "  authoreditor = {");  This swap made in May 2018 */
    fprintf(ofp, "  author       = {");
    break;
  case 4:
    fprintf(ofp, "  institution  = {");
    break;
  case 5:
    fprintf(ofp, "  journaltitle = {");
    break;
  case 6:
    fprintf(ofp, "  journalsubtitle   = {");
    break;
  case 10:
    fprintf(ofp, "  editora      = {");
    break;
  case 11:
    fprintf(ofp, "  editorb      = {");
    break;
  case 12:
    fprintf(ofp, "  editorc      = {");
    break;
  case 13:
    fprintf(ofp, "  editoratype  = {");
    break;
  case 14:
    fprintf(ofp, "  editorbtype  = {");
    break;
  case 15:
    fprintf(ofp, "  editorctype  = {");
    break;
  case 16:
    fprintf(ofp, "  editor       = {");
    break;
  case 17:
    fprintf(ofp, "  editortype   = {");
    break;
  case 18:
    fprintf(ofp, "  number       = {");
    break;
  case 19:
    fprintf(ofp, "  volume       = {");
    break;
  case 20:
    fprintf(ofp, "  isbn         = {");
    break;
  case 21:
    fprintf(ofp, "  pages        = {");
    break;
  case 22:
    fprintf(ofp, "  series       = {");
    break;
  case 23:
    fprintf(ofp, "  pubstate     = {");
    break;
  case 24:
    fprintf(ofp, "  addendum     = {");
    break;
  case 25:
    fprintf(ofp, "  language     = {");
    break;
  case 26:
    /*    fprintf(ofp, "  note         = {");  This swap made in May 2018 */
    fprintf(ofp, "  annotation   = {");
    break;
  case 27:
    fprintf(ofp, "  url          = {");
    break;
  case 28:
    fprintf(ofp, "  urldate      = {");
    break;
  case 29:
    fprintf(ofp, "  titleaddon   = {");
    break;
  case 30:
    fprintf(ofp, "  subtitle     = {");
    break;
  case 31:
    fprintf(ofp, "  doi          = {");
    break;
  case 32:
    fprintf(ofp, "  library      = {");
    break;
  case 33:
    fprintf(ofp, "  location     = {");
    break;
  case 34:
    fprintf(ofp, "  eprint       = {");
    break;
  case 35:
    fprintf(ofp, "  eprintclass  = {");
    break;
  case 36:
    fprintf(ofp, "  eprinttype   = {");
    break;
  case 37:
    fprintf(ofp, "  issn         = {");
    break;
  case 38:
    fprintf(ofp, "  issue        = {");
    break;
  case 39:
    fprintf(ofp, "  issuesubtitle  = {");
    break;
  case 40:
    fprintf(ofp, "  issuetitle   = {");
    break;
  case 41:
    fprintf(ofp, "  mainsubtitle = {");
    break;
  case 42:
    fprintf(ofp, "  maintitle    = {");
    break;
  case 43:
    fprintf(ofp, "  maintitleaddon  = {");
    break;
  case 44:
    fprintf(ofp, "  month        = {");
    break;
  case 45:
    fprintf(ofp, "  nameaddon    = {");
    break;
  case 46:
    fprintf(ofp, "  organization = {");
    break;
  case 47:
    fprintf(ofp, "  origdate     = {");
    break;
  case 48:
    fprintf(ofp, "  origlanguage = {");
    break;
  case 49:
    fprintf(ofp, "  origlocation = {");
    break;
  case 50:
    fprintf(ofp, "  origpublisher = {");
    break;
  case 51:
    fprintf(ofp, "  origtitle    = {");
    break;
  case 52:
    fprintf(ofp, "  translator   = {");
    break;
  case 53:
    fprintf(ofp, "  pagetotal    = {");
    break;
  case 54:
    fprintf(ofp, "  pagination   = {");
    break;
  case 55:
    fprintf(ofp, "  part         = {");
    break;
  case 56:
    fprintf(ofp, "  publisher    = {");
    break;
  case 57:
    fprintf(ofp, "  reprinttitle = {");
    break;
  case 58:
    fprintf(ofp, "  venue        = {");
    break;
  case 59:
    fprintf(ofp, "  version      = {");
    break;
  case 60:
    fprintf(ofp, "  volumes      = {");
    break;
  case 61:
    fprintf(ofp, "  type         = {");
    break;
  case 62:
    fprintf(ofp, "  edition      = {");
    break;
  case 63:
    fprintf(ofp, "  afterword    = {");
    break;
  case 64:
    fprintf(ofp, "  foreword     = {");
    break;
  case 65:
    /*    fprintf(ofp, "  annotation   = {");  This swap was made in May 2018 */
    fprintf(ofp, "  note         = {");
    break;
  case 66:
    fprintf(ofp, "  annotator    = {");
    break;
  case 67:
    fprintf(ofp, "  authortype   = {");
    break;
  case 68:
    fprintf(ofp, "  bookauthor   = {");
    break;
  case 69:
    fprintf(ofp, "  bookpagination = {");
    break;
  case 70:
    fprintf(ofp, "  booksubtitle = {");
    break;
  case 71:
    fprintf(ofp, "  booktitle    = {");
    break;
  case 72:
    fprintf(ofp, "  booktitleaddon = {");
    break;
  case 73:
    fprintf(ofp, "  chapter      = {");
    break;
  case 74:
    fprintf(ofp, "  commentator  = {");
    break;
  case 75:
    fprintf(ofp, "  eid          = {");
    break;
  case 76:
    fprintf(ofp, "  eventdate    = {");
    break;
  case 77:
    fprintf(ofp, "  eventtitle   = {");
    break;
  case 78:
    fprintf(ofp, "  file         = {");
    break;
  case 79:
    fprintf(ofp, "  holder       = {");
    break;
  case 80:
    fprintf(ofp, "  howpublished = {");
    break;
  case 81:
    fprintf(ofp, "  indextitle   = {");
    break;
  case 82:
    fprintf(ofp, "  introduction = {");
    break;
  case 83:
    fprintf(ofp, "  isan         = {");
    break;
  case 84:
    fprintf(ofp, "  ismn         = {");
    break;
  case 85:
    fprintf(ofp, "  isrn         = {");
    break;
  case 86:
    fprintf(ofp, "  keywords     = {");
    break;
  case 87:
    fprintf(ofp, "  sortkey      = {");
    break;
  case 88:
    fprintf(ofp, "  xref         = {");
    break;
  case 89:
    fprintf(ofp, "  annotator    = {");   /* 2nd occurrence.  Why? */
    break;
  case 90:
    fprintf(ofp, "  editor       = {");  /* required */
    break;
  case 91:
    fprintf(ofp, "  shortauthor  = {");  /* short author */
    break;
  case 92:
    fprintf(ofp, "  shorteditor  = {");  /* short editor */
    break;
  case 93:
    fprintf(ofp, "  shorthand    = {");  /* short hand */
    break;
  case 94:
    fprintf(ofp, "  shorthandintro = {");  /* short hand introduction */
    break;
  case 95:
    fprintf(ofp, "  shortjournal = {");  /* short journal */
    break;
  case 96:
    fprintf(ofp, "  shortseries  = {");  /* short series */
    break;
  case 97:
    fprintf(ofp, "  shorttitle   = {");  /* short title */
    break;
//  default:
//    printf("showfield: has no %d entry\n", index);
  }
}


/*  Check the reference data input as to having all appropriate fields
 *  containing an entry */

int  makechecks()
{
  int  good;
  void  error(char *);          /* in error.c */

  good = 0;
			   /* if 'Do It' button has been pressed - store */
  if ( doit_flag )  {
    doit_flag = 0;
    return(good);
  }
                           /* check fields common to all reference types */
  if ( !dataStore[86].end )  { /* check Keyword field */
    good = 1;
    error("An entry in 'Keywords' is suggested");
    return(good);
  }
  if ( !dataStore[0].end )  {  /* check Year/Date field */
    good = 1;  /* an error */
    error("   Year/Data field entry required");
    return(good);
  }
  if ( !dataStore[1].end )  {  /* check title field */
    good = 1;  /* an error */
    error("     Title field entry required");
    return(good);
  }
  switch  ( who )  {       /* now check required fields specific to type */
  case 20:    /* book */
  case 32:    /* unpublished */
  case 37:    /* multi-volume book */
    if ( !dataStore[2].end )  {
      good = 1; /* an error */
      error("       Author entry required");
      return(good);
    }
    break;
  case 21:    /* article */
    if ( !dataStore[2].end )  {
      good = 1; /* an error */
      error("        Author entry required");
      return(good);
    }
    if ( !dataStore[5].end )  {
      good = 1; /* an error */
      error("    Journal Title entry required");
      return(good);
    }
    break;
  case 22:    /* online */
    if ( !dataStore[3].end )  {
      good = 1; /* an error */
      error("    Author/Editor entry required");
      return(good);
    }
    if ( !dataStore[27].end )  {
      good = 1; /* an error */
      error("      URL entry required");
      return(good);
    }
    break;
  case 23:    /* thesis */
  case 24:    /* report */
    if ( !dataStore[2].end )  {
      good = 1; /* an error */
      error("       Author entry required");
      return(good);
    }
    if ( !dataStore[4].end )  {
      good = 1; /* an error */
      error("     Institution entry required");
      return(good);
    }
    if ( !dataStore[61].end )  {
      good = 1; /* an error */
      error("        Type entry required");
      return(good);
    }
    break;
  case 25:    /* in proceedings */
  case 26:    /* in collection */
  case 35:    /* in reference */
    if ( !dataStore[2].end )  {
      good = 1; /* an error */
      error("       Author entry required");
      return(good);
    }
    if ( !dataStore[16].end )  {
      good = 1; /* an error */
      error("       Editor entry required");
      return(good);
    }
    if ( !dataStore[71].end )  {
      good = 1; /* an error */
      error("     Book Title entry required");
      return(good);
    }
    break;
  case 27:    /* proceedings */
  case 28:    /* collection */
  case 33:    /* periodical */
  case 34:    /* reference */
  case 38:    /* multi-volume collection */
  case 39:    /* multi-volume proceedings */
    if ( !dataStore[16].end )  {
      good = 1; /* an error */
      error("       Editor entry required");
      return(good);
    }
    break;
  case 29:    /* booklet */
  case 30:    /* manual */
  case 31:    /* miscellaneous */
    if ( !dataStore[3].end )  {
      good = 1; /* an error */
      error("    Author/Editor entry required");
      return(good);
    }
    break;
  case 36:    /* in book */
    if ( !dataStore[2].end )  {
      good = 1; /* an error */
      error("        Author entry required");
      return(good);
    }
    if ( !dataStore[71].end )  {
      good = 1; /* an error */
      error("     Book Title entry required");
      return(good);
    }
    break;
  case 40:    /* patent */
    if ( !dataStore[2].end )  {
      good = 1; /* an error */
      error("       Author entry required");
      return(good);
    }
    if ( !dataStore[18].end )  {
      good = 1; /* an error */
      error("      Number entry required");
      return(good);
    }
    break;
  }
  return(good);
}
