/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains the function to handle a 'report' citation type.
 *
 *  Coded by:       Ross Maloney
 *  January 2011:   Initial code
 *  May 2012:       Rewritten
 *  September 2014: Minor field handling moved to report2()
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  report()
{
  void showeditorabcO(void);   /* in utilities.c */
  void showkeysO(void);        /* in utilities.c */
  void shownote(void);         /* in utilities.c */
  void removeMenus(int);       /* in mouseevent.c */
  void error(char *);          /* in error.c */
  void zeroall(void);          /* in texting.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 737);
  removeMenus(1);   /* remove the menu train which led to this function */
  who = 73;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, moduleStore[24].id);  /* report Required */
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);

  XReparentWindow(e6display, dataStore[2].id,
         moduleStore[24].id, 60, 47);    /* author */
  XMapWindow(e6display, dataStore[2].id);
  dataStore[2].before = 65;
  dataStore[2].next = 1;
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[24].id, 50, 78);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 2;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[24].id, 725, 78);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 4;
  XReparentWindow(e6display, dataStore[4].id,
          moduleStore[24].id, 80, 110);
  XMapWindow(e6display, dataStore[61].id);    /* report: institution */
  dataStore[4].before = 0;
  dataStore[4].next = 61;
  XReparentWindow(e6display, dataStore[61].id,
         moduleStore[24].id, 747, 110);
  XMapWindow(e6display, dataStore[4].id);    /* report: type */
  dataStore[61].before = 4;
  dataStore[61].next = 18;
  XReparentWindow(e6display, dataStore[18].id,
         moduleStore[24].id, 65, 156);
  XMapWindow(e6display, dataStore[18].id);    /* report: number */
  dataStore[18].before = 61;
  dataStore[18].next = 59;
  XReparentWindow(e6display, dataStore[59].id,
         moduleStore[24].id, 360, 156);
  XMapWindow(e6display, dataStore[59].id);    /* report: version */
  dataStore[59].before = 18;
  dataStore[59].next = 44;
  XReparentWindow(e6display, dataStore[44].id,
         moduleStore[24].id, 863, 156);
  XMapWindow(e6display, dataStore[44].id);    /* report: month */
  dataStore[44].before = 59;
  dataStore[44].next = 53;
  XReparentWindow(e6display, dataStore[53].id,
         moduleStore[24].id, 80, 186);
  XMapWindow(e6display, dataStore[53].id);    /* report: pagetotal */
  dataStore[53].before = 44;
  dataStore[53].next = 73;
  XReparentWindow(e6display, dataStore[73].id,
         moduleStore[24].id, 365, 186);
  XMapWindow(e6display, dataStore[73].id);    /* report: chaoter */
  dataStore[73].before = 53;
  dataStore[73].next = 85;
  XReparentWindow(e6display, dataStore[85].id,
         moduleStore[24].id, 45, 216);
  XMapWindow(e6display, dataStore[85].id);    /* report: ISRN */
  dataStore[85].before = 73;
  dataStore[85].next = 21;
  XReparentWindow(e6display, dataStore[21].id,
         moduleStore[24].id, 453, 216);
  XMapWindow(e6display, dataStore[21].id);    /* report: pages */
  dataStore[21].before = 85;
  dataStore[21].next = 91;

                        /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 250);
  dataStore[91].before = 21;
  dataStore[88].next = 65;
  showkeysO();  /* keys Optional */

                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 375);
  shownote();

  zeroall();        /* set all input data fields to zero */
}




/*  Function to form the window to contain the minor data fields associated with
 *  a report reference type.
 */

void  report2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (Report)";
  char *icon_name = "e6/2";
  void showlargeO(void);       /* in utilities.c */
  void showeprintO(void);      /* in utilities.c */
  void showlargeO1(void);      /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 255);
  XMapWindow(e6display, secondsW);

                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 5);
  showeprintO();     /* eprint information */
  XMoveWindow(e6display, moduleStore[7].id, 0, 35);
  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 65);
  showlargeO();      /* large Optionals */
  dataStore[34].before = 26;
  dataStore[26].next = 34;
}
