/*  This file is part of  e6  (EndNote's Sibling In Xlib)
 *
 *  This file contains the function to handle a 'supplemental periodical' citation type.
 *
 *  Coded by:       Ross Maloney
 *  June 2018:     Initial coding from article.c
 */

#include  <X11/Xlib.h>
#include  <X11/Xutil.h>
#include  <stdio.h>
#include  "e6x11Ext.h"       /* X11 related common parts of e6 */
#include  "e6dataExt.h"      /* Common parts for processing data */

void  supperiod()
{
  void showkeysO(void);        /* in utilities.c */
  void shownote(void);         /* in utilities.c */
  void removeMenus(int);       /* in mouseevent.c */
  void error(char *);          /* in error.c */
  void zeroall(void);          /* in texting.c */

  if ( !ofp )  {
    error("  Sorry: First open an output file");
    return;
  }
  XResizeWindow(e6display, baseW, 1240, 842);
  removeMenus(1);   /* remove the menu train which led to this function */
  who = 68;
  XMapWindow(e6display, windowStore[3]);
  XMapWindow(e6display, buttonStore[0].normal);
  XMapWindow(e6display, buttonStore[1].normal);
  XMapWindow(e6display, buttonStore[2].normal);
  XMapWindow(e6display, buttonStore[7].normal);
  XMapWindow(e6display, buttonStore[8].normal);
  XMapWindow(e6display, buttonStore[9].normal);
  XReparentWindow(e6display, moduleStore[21].id, baseW, 340, 0);
  XMapWindow(e6display, moduleStore[50].id);  /* supplemental Periodical Required */

  XReparentWindow(e6display, dataStore[2].id,
         moduleStore[50].id, 60, 47);    /* author */
  XMapWindow(e6display, dataStore[2].id);
  dataStore[2].before = 65;
  dataStore[2].next = 1;
  XReparentWindow(e6display, dataStore[1].id,
         moduleStore[50].id, 50, 78);    /* title */
  XMapWindow(e6display, dataStore[1].id);
  dataStore[1].before = 2;
  dataStore[1].next = 0;
  XReparentWindow(e6display, dataStore[0].id,
         moduleStore[50].id, 725, 78);    /* date */
  XMapWindow(e6display, dataStore[0].id);
  dataStore[0].before = 1;
  dataStore[0].next = 5;
  XReparentWindow(e6display, dataStore[5].id,
         moduleStore[50].id, 94, 108);    /* journal title */
  XMapWindow(e6display, dataStore[5].id);
  dataStore[5].before = 0;
  dataStore[5].next = 6;
  XReparentWindow(e6display, dataStore[6].id,
         moduleStore[50].id, 115, 158);    /* journal subtitle */
  XMapWindow(e6display, dataStore[6].id);
  dataStore[6].before = 5;
  dataStore[6].next = 95;
  XReparentWindow(e6display, dataStore[95].id,
         moduleStore[50].id, 102, 190);  /* short journal */
  XMapWindow(e6display, dataStore[95].id);
  dataStore[95].before = 6;
  dataStore[95].next = 44;
  XReparentWindow(e6display, dataStore[44].id,
         moduleStore[50].id, 550, 190);  /* month */
  XMapWindow(e6display, dataStore[44].id);
  dataStore[44].before = 95;
  dataStore[44].next = 59;
  XReparentWindow(e6display, dataStore[59].id,
         moduleStore[50].id, 760, 190);  /* version */
  XMapWindow(e6display, dataStore[59].id);
  dataStore[59].before = 44;
  dataStore[59].next = 19;
  XReparentWindow(e6display, dataStore[19].id,
         moduleStore[50].id, 62, 220);   /* volume */
  XMapWindow(e6display, dataStore[19].id);
  dataStore[19].before = 59;
  dataStore[19].next = 18;
  XReparentWindow(e6display, dataStore[18].id,
         moduleStore[50].id, 262, 220);   /* number */
  XMapWindow(e6display, dataStore[18].id);
  dataStore[18].before = 19;
  dataStore[18].next = 21;
  XReparentWindow(e6display, dataStore[21].id,
         moduleStore[50].id, 452, 220);   /* pages */
  XMapWindow(e6display, dataStore[21].id);
  dataStore[21].before = 18;
  dataStore[21].next = 22;
  XReparentWindow(e6display, dataStore[22].id,
         moduleStore[50].id, 60, 250);  /* series */
  XMapWindow(e6display, dataStore[22].id);
  dataStore[22].before = 21;
  dataStore[22].next = 96;
  XReparentWindow(e6display, dataStore[96].id,
         moduleStore[50].id, 640, 250);  /* short series */
  XMapWindow(e6display, dataStore[96].id);
  dataStore[96].before = 22;
  dataStore[96].next = 16;
  XReparentWindow(e6display, dataStore[16].id,
         moduleStore[50].id, 55, 280);  /* editor */
  XMapWindow(e6display, dataStore[16].id);
  dataStore[16].before = 96;
  dataStore[16].next = 92;
  XReparentWindow(e6display, dataStore[92].id,
         moduleStore[50].id, 640, 280);  /* short editor */
  XMapWindow(e6display, dataStore[92].id);
  dataStore[92].before = 16;
  dataStore[92].next = 75;
  XReparentWindow(e6display, dataStore[75].id,
         moduleStore[50].id, 46, 310);  /* eid */
  XMapWindow(e6display, dataStore[75].id);
  dataStore[75].before = 92;
  dataStore[75].next = 91;

                        /* linking in keys */
  XMoveWindow(e6display, moduleStore[8].id, 340, 350);
  showkeysO();  /* keys Optional */
  dataStore[91].before = 75;
  dataStore[88].next = 65;
                       /* linking in scratchpad */
  XMoveWindow(e6display, moduleStore[46].id, 340, 480);
  shownote();

  zeroall();        /* set all input data fields to zero */
}


/*  Function to form the window to contain the minor data fields associated with
 *  an article reference type.
 */

void  supperiod2()
{
  XTextProperty  mainName, iconName;
  char *main_name = "e6 - secondary fields (supplemental Periodical)";
  char *icon_name = "e6/2";
  void showeditorabcO(void);   /* in utilities.c */
  void showlargeO(void);       /* in utilities.c */
  void showmainO(void);        /* in utilities.c */
  void showorigO(void);        /* in utilities.c */
  void showeprintO(void);      /* in utilities.c */
  void showlargeO1(void);      /* in utilities.c */
  void showissO(void);         /* in utilities.c */
  void wordsO(void);           /* in utilities.c */
  void showeventsO(void);      /* in utilities.c */
  void showwordsO(void);       /* in utilities.c */

  XStringListToTextProperty(&main_name, 1, &mainName);
  XSetWMName(e6display, secondsW, &mainName);
  XStringListToTextProperty(&icon_name, 1, &iconName);
  XSetWMIconName(e6display, secondsW, &iconName);
  XResizeWindow(e6display, secondsW, 900, 573);
  XMapWindow(e6display, secondsW);
  XMoveWindow(e6display, moduleStore[9].id, 0, 5);
  showwordsO();      /* auxiliary information */
                       /* linking in wordsO */
  dataStore[63].before = 26;
  dataStore[52].next = 38;
                        /* linking in issO */
  XMoveWindow(e6display, moduleStore[4].id, 0, 95);
  dataStore[38].before = 52;
  dataStore[39].next = 10;
  showissO();        /* issue parts */
                        /* linking in editorabcO */
  XMoveWindow(e6display, moduleStore[2].id, 0, 152);
  dataStore[10].before = 39;
  dataStore[15].next = 48;
  showeditorabcO();  /* editor descriptors */
                        /* linking in origO */
  XMoveWindow(e6display, moduleStore[6].id, 0, 242);
  dataStore[48].before = 15;
  dataStore[49].next = 34;
  showorigO();       /* original publication details */
                        /* linking in largeO, lrageO1 and eprintO combination */
  XMoveWindow(e6display, moduleStore[1].id, 0, 333);
  showeprintO();     /* eprint information */
  XMoveWindow(e6display, moduleStore[7].id, 0, 362);
  showlargeO1();     /* large Optionals 1 */
  XMoveWindow(e6display, moduleStore[0].id, 0, 392);
  showlargeO();      /* large Optionals */
  dataStore[34].before = 49;
  dataStore[26].next = 63;
}
